//----------------------------------------------------------------------
//EASTRISING TECHNOLOGY CO,.LTD.//
// Module    : ER-OLED0.76-1C    28RGB*95
// Lanuage   : C51 Code
// Create    : JAVEN
// Date      : 2023-04-21
// Drive IC  : PT6891
// INTERFACE : 4SPI
// MCU 		 : STC12LE5A60S2
// VDD		 : 3.3V   
//----------------------------------------------------------------------

#include <intrins.h>
#include <reg51.h>
#define  uchar unsigned char 
#define  uint unsigned int
#define u8  unsigned char
#define u16 unsigned int
	

sbit OLED_SCL=P1^0;//SCLK
sbit OLED_SDA=P1^1;//MOSI
sbit OLED_RES=P3^4;//RES
sbit OLED_DC =P3^3;//DC
sbit OLED_CS =P3^5; //CS


sbit	int0=P3^2;
bit log=0;

u8 x_offset=0;
#define USER_HORIZONTAL 0


#define OLED_SCLK_Clr() OLED_SCL=0//SCL=SCLK
#define OLED_SCLK_Set() OLED_SCL=1

#define OLED_MOSI_Clr() OLED_SDA=0//SDA=MOSI
#define OLED_MOSI_Set() OLED_SDA=1

#define OLED_RES_Clr() OLED_RES=0//RES
#define OLED_RES_Set() OLED_RES=1

#define OLED_DC_Clr() OLED_DC=0//DC
#define OLED_DC_Set() OLED_DC=1

#define OLED_CS_Clr()  OLED_CS=0//CS
#define OLED_CS_Set()  OLED_CS=1

#define WHITE         	 0xFFFF
#define BLACK         	 0x0000	  
#define BLUE           	 0x001F  
#define BRED             0XF81F
#define GRED 			       0XFFE0
#define GBLUE			       0X07FF
#define RED           	 0xF800
#define MAGENTA       	 0xF81F
#define GREEN         	 0x07E0
#define CYAN          	 0x7FFF
#define YELLOW        	 0xFFE0
#define BROWN 			     0XBC40 
#define BRRED 			     0XFC07 
#define GRAY  			     0X8430
#define DARKBLUE      	 0X01CF	
#define LIGHTBLUE      	 0X7D7C	 
#define GRAYBLUE       	 0X5458 
#define LIGHTGREEN     	 0X841F 
#define LGRAY 			     0XC618 
#define LGRAYBLUE        0XA651 
#define LBBLUE           0X2B12 


const unsigned char code ascii_1608[][16];



unsigned char code pic1[];
unsigned char code pic2[];
unsigned char code pic3[];
unsigned char code pic4[];
unsigned char code pic5[];
unsigned char code pic6[];


void Delay1(uint n)
{  
while(n--)
  {_nop_();
	_nop_();
	_nop_();
	_nop_(); 
 	_nop_();
	_nop_();

   }
}

void Step(void) interrupt 0 using 0
{
	Delay1(300);
	if(int0==0)	log=!log;
   while(!int0);
  return;

}



void Delay(uint n)
{while(n)
 {   
	  n--; Delay1(500) ;
 }
 	for(;log==1;)
	{
	 ;

	}


	return;
}




void OLED_Writ_Bus(u8 dat) 
{	
	u8 i;
	OLED_CS_Clr();
	for(i=0;i<8;i++)
	{			  
		OLED_SCLK_Clr();
		if(dat&0x80)
		{
		   OLED_MOSI_Set();
		}
		else
		{
		   OLED_MOSI_Clr();
		}
		OLED_SCLK_Set();
		dat<<=1;
	}	
  OLED_CS_Set();	
}



void OLED_WR_DATA8(u8 dat)
{
	OLED_Writ_Bus(dat);
}



void OLED_WR_DATA(u16 dat)
{
	OLED_Writ_Bus(dat>>8);
	OLED_Writ_Bus(dat);
}



void OLED_WR_REG(u8 dat)
{
	OLED_DC_Clr();
	OLED_Writ_Bus(dat);
	OLED_DC_Set();
}



void OLED_Address_Set(u8 x1,u8 y1,u8 x2,u8 y2)
{
	if(USER_HORIZONTAL==0)
	{
		if(y1<4)
		{
			y1+=0x18;
		}
		else
		{
			 y1-=4;
		}
		OLED_WR_REG(0x80);
		OLED_WR_DATA8(y1);  //Row Address Set		
		OLED_WR_REG(0x81);
		OLED_WR_DATA8(x1+x_offset);    //Col Address Set	  

		OLED_WR_REG(0x82);
		OLED_WR_DATA8(x2-x1-1);
		OLED_WR_REG(0x83);
 }
	else
	{
		y1+=4;
		if(y1>27)
		{
			y1-=0x18;
		}
		else
		{
			 y1+=4;
		}
		OLED_WR_REG(0x80);
		OLED_WR_DATA8(y1);  //Row Address Set		
		OLED_WR_REG(0x81);
		OLED_WR_DATA8(x1+x_offset);    //Col Address Set	  
		OLED_WR_REG(0x82);
		OLED_WR_DATA8(x2-x1-1);
		OLED_WR_REG(0x83);		
	}
}		   			 
  

void OLED_DrawPoint(u8 x,u8 y,u16 color)
{

	OLED_Address_Set(x,y,x,y);
	OLED_WR_DATA(color);
}


void OLED_Fill(u8 x1,u8 y1,u8 x2,u8 y2,u16 color)
{
	u16 i,j,dat;
	if(USER_HORIZONTAL==0)
	{
		if(y1<4)
		{
			dat=y1;
			y1+=0x18;
			OLED_WR_REG(0x80);
			OLED_WR_DATA8(y1);  //Row Address Set		
			OLED_WR_REG(0x81);
			OLED_WR_DATA8(x1+x_offset);    //Col Address Set	  
			OLED_WR_REG(0x82);
			OLED_WR_DATA8(x2-x1-1);
			OLED_WR_REG(0x83);
			for(i=0;i<(4-dat);i++)
			{
				for(j=x1;j<x2;j++)
				{
					OLED_WR_DATA(color);
				}
			}
			OLED_WR_REG(0x80);
			OLED_WR_DATA8(0x00);  //Row Address Set		
			OLED_WR_REG(0x81);
			OLED_WR_DATA8(x1+x_offset);    //Col Address Set	  
			OLED_WR_REG(0x82);
			OLED_WR_DATA8(x2-x1-1);
			OLED_WR_REG(0x83);		
		 for(i=0;i<y2-(4-dat);i++)
		 {
			for(j=x1;j<x2;j++)
			{
			 OLED_WR_DATA(color);;
			}
		 }
		}
		else
	 {
			OLED_WR_REG(0x80);
			OLED_WR_DATA8(y1-4);  //Row Address Set		
			OLED_WR_REG(0x81);
			OLED_WR_DATA8(x1+x_offset);    //Col Address Set	  
			OLED_WR_REG(0x82);
			OLED_WR_DATA8(x2-x1-1);
			OLED_WR_REG(0x83);		
		 for(i=y1;i<y2;i++)
		 {
			for(j=x1;j<x2;j++)
			{
				OLED_WR_DATA(color);
			}
		 }	
		}	
  }
	else
	{
			OLED_WR_REG(0x80);
			OLED_WR_DATA8(y1+0x04);  //Row Address Set		
			OLED_WR_REG(0x81);
			OLED_WR_DATA8(x1+x_offset);    //Col Address Set	  
			OLED_WR_REG(0x82);
			OLED_WR_DATA8(x2-x1-1);
			OLED_WR_REG(0x83);		
		 for(i=y1;i<y2;i++)
		 {
			for(j=x1;j<x2;j++)
			{
				OLED_WR_DATA(color);
			}
		 }
	}
}

void OLED_DrawLine(u16 x1,u16 y1,u16 x2,u16 y2,u16 color)
{
	u16 t; 
	int xerr=0,yerr=0,delta_x,delta_y,distance;
	int incx,incy,uRow,uCol;
	delta_x=x2-x1; // 
	delta_y=y2-y1;
	uRow=x1;//
	uCol=y1;
	if(delta_x>0)incx=1; //õ 
	else if (delta_x==0)incx=0;//ֱ 
	else {incx=-1;delta_x=-delta_x;}
	if(delta_y>0)incy=1;
	else if (delta_y==0)incy=0;//ˮƽ 
	else {incy=-1;delta_y=-delta_x;}
	if(delta_x>delta_y)distance=delta_x; //ѡȡ 
	else distance=delta_y;
	for(t=0;t<distance+1;t++)
	{
		OLED_DrawPoint(uRow,uCol,color);//
		xerr+=delta_x;
		yerr+=delta_y;
		if(xerr>distance)
		{
			xerr-=distance;
			uRow+=incx;
		}
		if(yerr>distance)
		{
			yerr-=distance;
			uCol+=incy;
		}
	}
}

void OLED_DrawRectangle(u16 x1, u16 y1, u16 x2, u16 y2,u16 color)
{
	OLED_DrawLine(x1,y1,x2,y1,color);
	OLED_DrawLine(x1,y1,x1,y2,color);
	OLED_DrawLine(x1,y2,x2,y2,color);
	OLED_DrawLine(x2,y1,x2,y2,color);
}

void Draw_Circle(u16 x0,u16 y0,u8 r,u16 color)
{
	int a,b;
	a=0;b=r;	  
	while(a<=b)
	{
		OLED_DrawPoint(x0-b,y0-a,color);             //3           
		OLED_DrawPoint(x0+b,y0-a,color);             //0           
		OLED_DrawPoint(x0-a,y0+b,color);             //1                
		OLED_DrawPoint(x0-a,y0-b,color);             //2             
		OLED_DrawPoint(x0+b,y0+a,color);             //4               
		OLED_DrawPoint(x0+a,y0-b,color);             //5
		OLED_DrawPoint(x0+a,y0+b,color);             //6 
		OLED_DrawPoint(x0-b,y0+a,color);             //7
		a++;
		if((a*a+b*b)>(r*r))
		{
			b--;
		}
	}
}

void OLED_ShowChar(u16 x,u16 y,u8 num,u16 fc,u8 sizey)
{
	u8 temp,sizex,t;
	u16 i,TypefaceNum;
	u16 x0=x;
	sizex=sizey/2;
	TypefaceNum=16;
	num=num-' ';    
	OLED_Address_Set(x,y,x+sizex-1,y+sizey-1);  
	for(i=0;i<TypefaceNum;i++)
	{ 
		if(sizey==16)temp=ascii_1608[num][i];		       //8x16
//		else if(sizey==32)temp=ascii_3216[num][i];		 //

		else return;
		for(t=0;t<8;t++)
		{
				if(temp&(0x01<<t))OLED_DrawPoint(x,y,fc);
				x++;
				if((x-x0)==sizex)
				{
					x=x0;
					y++;
					break;
				}
		}
	}   	 	  
}







void OLED_ShowString(u16 x,u16 y,const u8 *p,u16 fc,u8 sizey)
{         
	while(*p!='\0')
	{       
		OLED_ShowChar(x,y,*p,fc,sizey);
		x+=sizey/2;
		p++;
	}  
}



void OLED_ShowPicture(u16 x,u16 y,u16 length,u16 width,const u8 pic[])
{
	u16 i,j,k=0,dat;
	if(USER_HORIZONTAL==0)
	{
		if(y<4)
		{
			dat=y;
			y=y+0x18;
			OLED_WR_REG(0x80);
			OLED_WR_DATA8(y);  //Row Address Set		
			OLED_WR_REG(0x81);
			OLED_WR_DATA8(x+x_offset);    //Col Address Set	  
			OLED_WR_REG(0x82);
			OLED_WR_DATA8(length-1);
			OLED_WR_REG(0x83);
			for(i=0;i<(4-dat);i++)
			{
				for(j=0;j<length;j++)
				{
					OLED_WR_DATA8(pic[k*2]);
					OLED_WR_DATA8(pic[k*2+1]);
					k++; 
				}
			}
			OLED_WR_REG(0x80);
			OLED_WR_DATA8(0x00);  //Row Address Set		
			OLED_WR_REG(0x81);
			OLED_WR_DATA8(x+x_offset);    //Col Address Set	  
			OLED_WR_REG(0x82);
			OLED_WR_DATA8(length-1);
			OLED_WR_REG(0x83);		
		 for(i=0;i<width-(4-dat);i++)
		 {
			for(j=0;j<length;j++)
			{
				OLED_WR_DATA8(pic[k*2]);
				OLED_WR_DATA8(pic[k*2+1]);
				k++;
			}
		 }
		}
		else
		{
				OLED_WR_REG(0x80);
				OLED_WR_DATA8(y-4);  //Row Address Set		
				OLED_WR_REG(0x81);
				OLED_WR_DATA8(x+x_offset);    //Col Address Set	  
				OLED_WR_REG(0x82);
				OLED_WR_DATA8(length-1);
				OLED_WR_REG(0x83);		
			 for(i=0;i<width;i++)
			 {
				for(j=0;j<length;j++)
				{
					OLED_WR_DATA8(pic[k*2]);
					OLED_WR_DATA8(pic[k*2+1]);
					k++;
				}
			 }	
		}	
   }



}



				    
void OLED_Init(void)
{

	
	OLED_RES_Clr();
	Delay(50);
	OLED_RES_Set();
	Delay(50);


	OLED_WR_REG(0xa5);//Software Reset 
	OLED_WR_REG(0x58);//Display ON/OFF(Type_1 OFF) 
	OLED_WR_REG(0xb5);//Voltage/Current Control 
	OLED_WR_DATA8(0x87);// Enable internal IREF 
	OLED_WR_REG(0x31);//Color Mode(CM=00(RGB: 666; 262K colors)) 
	OLED_WR_REG(0x28);//G Gamma table setting 
	OLED_WR_DATA8(0x00);//0 
	OLED_WR_DATA8(0x01);//1 
	OLED_WR_DATA8(0x02);//2 
	OLED_WR_DATA8(0x03);//3 
	OLED_WR_DATA8(0x04);//4 
	OLED_WR_DATA8(0x05);//5 
	OLED_WR_DATA8(0x06);//6 
	OLED_WR_DATA8(0x07);//7 
	OLED_WR_DATA8(0x08);//8 
	OLED_WR_DATA8(0x09);//9 
	//==================== 
	OLED_WR_DATA8(0x0a);//10 
	OLED_WR_DATA8(0x0b);//11 
	OLED_WR_DATA8(0x0d);//12 
	OLED_WR_DATA8(0x0f);//13 
	OLED_WR_DATA8(0x11);//14 
	OLED_WR_DATA8(0x13);//15 
	OLED_WR_DATA8(0x16);//16 
	OLED_WR_DATA8(0x18);//17 
	OLED_WR_DATA8(0x1b);//18 
	OLED_WR_DATA8(0x1d);//19 
	//==================== 
	OLED_WR_DATA8(0x20);//20 
	OLED_WR_DATA8(0x23);//21 
	OLED_WR_DATA8(0x26);//22 
	OLED_WR_DATA8(0x29);//23 
	OLED_WR_DATA8(0x2c);//24 
	OLED_WR_DATA8(0x30);//25 
	OLED_WR_DATA8(0x33);//26 
	OLED_WR_DATA8(0x37);//27 
	OLED_WR_DATA8(0x3a);//28 
	OLED_WR_DATA8(0x3e);//29 
	//==================== 
	OLED_WR_DATA8(0x42);//30 
	OLED_WR_DATA8(0x46);//31 
	OLED_WR_DATA8(0x4a);//32 
	OLED_WR_DATA8(0x4e);//33 
	OLED_WR_DATA8(0x53);//34 
	OLED_WR_DATA8(0x57);//35 
	OLED_WR_DATA8(0x5c);//36 
	OLED_WR_DATA8(0x60);//37 
	OLED_WR_DATA8(0x65);//38 
	OLED_WR_DATA8(0x6a);//39 
	//==================== 
	OLED_WR_DATA8(0x6f);//40 
	OLED_WR_DATA8(0x74);//41 
	OLED_WR_DATA8(0x79);//42 
	OLED_WR_DATA8(0x7e);//43 
	OLED_WR_DATA8(0x83);//44 
	OLED_WR_DATA8(0x89);//45 
	OLED_WR_DATA8(0x8e);//46 
	OLED_WR_DATA8(0x94);//47 
	OLED_WR_DATA8(0x9a);//48 
	OLED_WR_DATA8(0x9f);//49 
	//==================== 
	OLED_WR_DATA8(0xa5);//50 
	OLED_WR_DATA8(0xab);//51 
	OLED_WR_DATA8(0xb1);//52 
	OLED_WR_DATA8(0xb7);//53 
	OLED_WR_DATA8(0xbe);//54 
	OLED_WR_DATA8(0xc4);//55 
	OLED_WR_DATA8(0xca);//56 
	OLED_WR_DATA8(0xd1);//57 
	OLED_WR_DATA8(0xd8);//58 
	OLED_WR_DATA8(0xde);//59 
	//==================== 
	OLED_WR_DATA8(0xe5);//60 
	OLED_WR_DATA8(0xec);//61 
	OLED_WR_DATA8(0xf3);//62 
	OLED_WR_DATA8(0xfa);//63 
	OLED_WR_REG(0x2b);//Gamma Table Update 
	//----------------------------------- 
	OLED_WR_REG(0x29);//B Gamma table setting 
	OLED_WR_DATA8(0x00);//0 
	OLED_WR_DATA8(0x01);//1 
	OLED_WR_DATA8(0x02);//2 
	OLED_WR_DATA8(0x03);//3 
	OLED_WR_DATA8(0x04);//4 
	OLED_WR_DATA8(0x05);//5 
	OLED_WR_DATA8(0x06);//6 
	OLED_WR_DATA8(0x07);//7 
	OLED_WR_DATA8(0x08);//8 
	OLED_WR_DATA8(0x09);//9 
	//==================== 
	OLED_WR_DATA8(0x0a);//10 
	OLED_WR_DATA8(0x0b);//11 
	OLED_WR_DATA8(0x0d);//12 
	OLED_WR_DATA8(0x0f);//13 
	OLED_WR_DATA8(0x11);//14 
	OLED_WR_DATA8(0x13);//15 
	OLED_WR_DATA8(0x16);//16 
	OLED_WR_DATA8(0x18);//17 
	OLED_WR_DATA8(0x1b);//18 
	OLED_WR_DATA8(0x1d);//19 
	//==================== 
	OLED_WR_DATA8(0x20);//20 
	OLED_WR_DATA8(0x23);//21
	OLED_WR_DATA8(0x26);//22 
	OLED_WR_DATA8(0x29);//23 
	OLED_WR_DATA8(0x2c);//24 
	OLED_WR_DATA8(0x30);//25 
	OLED_WR_DATA8(0x33);//26 
	OLED_WR_DATA8(0x37);//27 
	OLED_WR_DATA8(0x3a);//28 
	OLED_WR_DATA8(0x3e);//29 
	//==================== 
	OLED_WR_DATA8(0x42);//30 
	OLED_WR_DATA8(0x46);//31 
	OLED_WR_DATA8(0x4a);//32 
	OLED_WR_DATA8(0x4e);//33 
	OLED_WR_DATA8(0x53);//34 
	OLED_WR_DATA8(0x57);//35 
	OLED_WR_DATA8(0x5c);//36 
	OLED_WR_DATA8(0x60);//37 
	OLED_WR_DATA8(0x65);//38 
	OLED_WR_DATA8(0x6a);//39 
	//==================== 
	OLED_WR_DATA8(0x6f);//40 
	OLED_WR_DATA8(0x74);//41 
	OLED_WR_DATA8(0x79);//42 
	OLED_WR_DATA8(0x7e);//43 
	OLED_WR_DATA8(0x83);//44 
	OLED_WR_DATA8(0x89);//45 
	OLED_WR_DATA8(0x8e);//46 
	OLED_WR_DATA8(0x94);//47 
	OLED_WR_DATA8(0x9a);//48 
	OLED_WR_DATA8(0x9f);//49 
	//==================== 
	OLED_WR_DATA8(0xa5);//50 
	OLED_WR_DATA8(0xab);//51 
	OLED_WR_DATA8(0xb1);//52 
	OLED_WR_DATA8(0xb7);//53 
	OLED_WR_DATA8(0xbe);//54 
	OLED_WR_DATA8(0xc4);//55 
	OLED_WR_DATA8(0xca);//56 
	OLED_WR_DATA8(0xd1);//57 
	OLED_WR_DATA8(0xd8);//58 
	OLED_WR_DATA8(0xde);//59 
	//==================== 
	OLED_WR_DATA8(0xe5);//60 
	OLED_WR_DATA8(0xec);//61 
	OLED_WR_DATA8(0xf3);//62 
	OLED_WR_DATA8(0xfa);//63 
	OLED_WR_REG(0x2b);//Gamma Table Update 
	//----------------------------------- 
	OLED_WR_REG(0x2a);//R Gamma table setting 
	OLED_WR_DATA8(0x00);//0 
	OLED_WR_DATA8(0x01);//1 
	OLED_WR_DATA8(0x02);//2 
	OLED_WR_DATA8(0x03);//3 
	OLED_WR_DATA8(0x04);//4 
	OLED_WR_DATA8(0x05);//5 
	OLED_WR_DATA8(0x06);//6 
	OLED_WR_DATA8(0x07);//7 
	OLED_WR_DATA8(0x08);//8 
	OLED_WR_DATA8(0x09);//9 
	//==================== 
	OLED_WR_DATA8(0x0a);//10 
	OLED_WR_DATA8(0x0b);//11 
	OLED_WR_DATA8(0x0d);//12 
	OLED_WR_DATA8(0x0f);//13 
	OLED_WR_DATA8(0x11);//14 
	OLED_WR_DATA8(0x13);//15 
	OLED_WR_DATA8(0x16);//16 
	OLED_WR_DATA8(0x18);//17 
	OLED_WR_DATA8(0x1b);//18 
	OLED_WR_DATA8(0x1d);//19 
	//==================== 
	OLED_WR_DATA8(0x20);//20 
	OLED_WR_DATA8(0x23);//21 
	OLED_WR_DATA8(0x26);//22 
	OLED_WR_DATA8(0x29);//23 
	OLED_WR_DATA8(0x2c);//24 
	OLED_WR_DATA8(0x30);//25 
	OLED_WR_DATA8(0x33);//26 
	OLED_WR_DATA8(0x37);//27 
	OLED_WR_DATA8(0x3a);//28 
	OLED_WR_DATA8(0x3e);//29 
	//==================== 
	OLED_WR_DATA8(0x42);//30 
	OLED_WR_DATA8(0x46);//31 
	OLED_WR_DATA8(0x4a);//32 
	OLED_WR_DATA8(0x4e);//33 
	OLED_WR_DATA8(0x53);//34 
	OLED_WR_DATA8(0x57);//35 
	OLED_WR_DATA8(0x5c);//36 
	OLED_WR_DATA8(0x60);//37 
	OLED_WR_DATA8(0x65);//38 
	OLED_WR_DATA8(0x6a);//39 
	//==================== 
	OLED_WR_DATA8(0x6f);//40 
	OLED_WR_DATA8(0x74);//41 
	OLED_WR_DATA8(0x79);//42 
	OLED_WR_DATA8(0x7e);//43 
	OLED_WR_DATA8(0x83);//44 
	OLED_WR_DATA8(0x89);//45 
	OLED_WR_DATA8(0x8e);//46 
	OLED_WR_DATA8(0x94);//47 
	OLED_WR_DATA8(0x9a);//48 
	OLED_WR_DATA8(0x9f);//49 
	//==================== 
	OLED_WR_DATA8(0xa5);//50 
	OLED_WR_DATA8(0xab);//51 
	OLED_WR_DATA8(0xb1);//52 
	OLED_WR_DATA8(0xb7);//53 
	OLED_WR_DATA8(0xbe);//54 
	OLED_WR_DATA8(0xc4);//55 
	OLED_WR_DATA8(0xca);//56 
	OLED_WR_DATA8(0xd1);//57
	OLED_WR_DATA8(0xd8);//58 
	OLED_WR_DATA8(0xde);//59 
	//==================== 
	OLED_WR_DATA8(0xe5);//60 
	OLED_WR_DATA8(0xec);//61 
	OLED_WR_DATA8(0xf3);//62 
	OLED_WR_DATA8(0xfa);//63 
	OLED_WR_REG(0x2b);//Gamma Table Update 
	//----------------------------------- 
	OLED_WR_REG(0xe0);//COM Number 
	OLED_WR_DATA8(0x1B); 
	OLED_WR_REG(0xe1);//Display Row Setting 
	OLED_WR_DATA8(0x00); 
	OLED_WR_REG(0xe2);//Display Column Setting 
	OLED_WR_DATA8(0x00); 
	OLED_WR_REG(0xe6);//Dummy Scan 
	
	OLED_WR_REG(0x44);//Clock Divider 
	OLED_WR_REG(0x4A);//OSC Trimming 
	
	OLED_WR_DATA8(0x08); 
	OLED_WR_REG(0xd8);//COM Pulse Width 
	OLED_WR_DATA8(0x25); 
	OLED_WR_DATA8(0x01);	
	OLED_WR_REG(0xe5);//Blank Period 
	OLED_WR_DATA8(0x0a); 
	OLED_WR_REG(0xb4);//SEG EVEN/ODD Swap 
	OLED_WR_DATA8(0x00); 
	OLED_WR_REG(0xb3);//SEG Output Type 
	//0110  10HV
	if(USER_HORIZONTAL==0)
	{
	  x_offset=0;
	  OLED_WR_REG(0x6A);//Vertical and Horizontal Mirror 

	}
	else
	{
		x_offset=0x21;
	  OLED_WR_REG(0x69);//Vertical and Horizontal Mirror 		
	}
	OLED_WR_REG(0xbC);//Cathode Scan Direction 
	OLED_WR_REG(0xbe);//Anode Trimming 
	OLED_WR_DATA8(0x08); 
	OLED_WR_REG(0xb8);//Brightness(VHA=15V) 
	OLED_WR_DATA8(0x2b);//R 
	OLED_WR_DATA8(0x0e);//G 
	OLED_WR_DATA8(0x1a);//B 
	OLED_WR_REG(0xc8);//PRE-CHARGE PERIOD 
	OLED_WR_DATA8(0x0a); 
	OLED_WR_REG(0xd0);//PRE-CHARGE CURRENT 
	OLED_WR_DATA8(0x00); 
	OLED_WR_REG(0x43);//INT Setting 
	OLED_WR_REG(0x5b);//Display ON/OFF(Normally display) 

}


int main(void)
{	

	IE=0x81;
	IP=0x01;
	TCON=0x01;
	int0=1;

	

	OLED_Init();
	while(1) 
	{ 		OLED_Fill(0,0,95,28,BLACK);
		OLED_ShowString(5,6,"OLED0.76-1C",RED,16); 

		Delay(1000);
		
		OLED_ShowPicture(0,0,95,28,pic1);		
		Delay(1000);		
		OLED_ShowPicture(0,0,95,28,pic2);		
		Delay(1000);
		OLED_ShowPicture(0,0,95,28,pic3);		
		Delay(1000);		
		OLED_ShowPicture(0,0,95,28,pic4);		
		Delay(1000);		
		OLED_ShowPicture(0,0,95,28,pic5);		
		Delay(1000);
		OLED_ShowPicture(0,0,95,28,pic6);		
		Delay(1000);		
						
			
		OLED_Fill(0,0,95,28,RED);
 		Delay(1000);
		OLED_Fill(0,0,95,28,GREEN);
 		Delay(1000);
		OLED_Fill(0,0,95,28,BLUE);
 		Delay(1000);
		OLED_Fill(0,0,95,28,WHITE);
 		Delay(1000);
		OLED_Fill(0,0,95,28,GBLUE);
 		Delay(1000);
		OLED_Fill(0,0,95,28,YELLOW);
 		Delay(1000);
		OLED_Fill(0,0,95,28,MAGENTA);
 		Delay(1000);

			
		OLED_ShowPicture(0,0,95,28,pic1);		
		Delay(1000);
		




	}
}



const unsigned char code ascii_1608[][16]={
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},/*" ",0*/
{0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x18,0x18,0x00,0x00},/*"!",1*/
{0x00,0x48,0x6C,0x24,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},/*""",2*/
{0x00,0x00,0x00,0x24,0x24,0x24,0x7F,0x12,0x12,0x12,0x7F,0x12,0x12,0x12,0x00,0x00},/*"#",3*/
{0x00,0x00,0x08,0x1C,0x2A,0x2A,0x0A,0x0C,0x18,0x28,0x28,0x2A,0x2A,0x1C,0x08,0x08},/*"$",4*/
{0x00,0x00,0x00,0x22,0x25,0x15,0x15,0x15,0x2A,0x58,0x54,0x54,0x54,0x22,0x00,0x00},/*"%",5*/
{0x00,0x00,0x00,0x0C,0x12,0x12,0x12,0x0A,0x76,0x25,0x29,0x11,0x91,0x6E,0x00,0x00},/*"&",6*/
{0x00,0x06,0x06,0x04,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},/*"'",7*/
{0x00,0x40,0x20,0x10,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x10,0x10,0x20,0x40,0x00},/*"(",8*/
{0x00,0x02,0x04,0x08,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x08,0x04,0x02,0x00},/*")",9*/
{0x00,0x00,0x00,0x00,0x08,0x08,0x6B,0x1C,0x1C,0x6B,0x08,0x08,0x00,0x00,0x00,0x00},/*"*",10*/
{0x00,0x00,0x00,0x00,0x08,0x08,0x08,0x08,0x7F,0x08,0x08,0x08,0x08,0x00,0x00,0x00},/*"+",11*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x04,0x03},/*",",12*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFE,0x00,0x00,0x00,0x00,0x00,0x00,0x00},/*"-",13*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x06,0x00,0x00},/*".",14*/
{0x00,0x00,0x80,0x40,0x40,0x20,0x20,0x10,0x10,0x08,0x08,0x04,0x04,0x02,0x02,0x00},/*"/",15*/
{0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x24,0x18,0x00,0x00},/*"0",16*/
{0x00,0x00,0x00,0x08,0x0E,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3E,0x00,0x00},/*"1",17*/
{0x00,0x00,0x00,0x3C,0x42,0x42,0x42,0x20,0x20,0x10,0x08,0x04,0x42,0x7E,0x00,0x00},/*"2",18*/
{0x00,0x00,0x00,0x3C,0x42,0x42,0x20,0x18,0x20,0x40,0x40,0x42,0x22,0x1C,0x00,0x00},/*"3",19*/
{0x00,0x00,0x00,0x20,0x30,0x28,0x24,0x24,0x22,0x22,0x7E,0x20,0x20,0x78,0x00,0x00},/*"4",20*/
{0x00,0x00,0x00,0x7E,0x02,0x02,0x02,0x1A,0x26,0x40,0x40,0x42,0x22,0x1C,0x00,0x00},/*"5",21*/
{0x00,0x00,0x00,0x38,0x24,0x02,0x02,0x1A,0x26,0x42,0x42,0x42,0x24,0x18,0x00,0x00},/*"6",22*/
{0x00,0x00,0x00,0x7E,0x22,0x22,0x10,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00},/*"7",23*/
{0x00,0x00,0x00,0x3C,0x42,0x42,0x42,0x24,0x18,0x24,0x42,0x42,0x42,0x3C,0x00,0x00},/*"8",24*/
{0x00,0x00,0x00,0x18,0x24,0x42,0x42,0x42,0x64,0x58,0x40,0x40,0x24,0x1C,0x00,0x00},/*"9",25*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00},/*":",26*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x04},/*";",27*/
{0x00,0x00,0x00,0x40,0x20,0x10,0x08,0x04,0x02,0x04,0x08,0x10,0x20,0x40,0x00,0x00},/*"<",28*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0x00,0x00,0x00,0x7F,0x00,0x00,0x00,0x00,0x00},/*"=",29*/
{0x00,0x00,0x00,0x02,0x04,0x08,0x10,0x20,0x40,0x20,0x10,0x08,0x04,0x02,0x00,0x00},/*">",30*/
{0x00,0x00,0x00,0x3C,0x42,0x42,0x46,0x40,0x20,0x10,0x10,0x00,0x18,0x18,0x00,0x00},/*"?",31*/
{0x00,0x00,0x00,0x1C,0x22,0x5A,0x55,0x55,0x55,0x55,0x2D,0x42,0x22,0x1C,0x00,0x00},/*"@",32*/
{0x00,0x00,0x00,0x08,0x08,0x18,0x14,0x14,0x24,0x3C,0x22,0x42,0x42,0xE7,0x00,0x00},/*"A",33*/
{0x00,0x00,0x00,0x1F,0x22,0x22,0x22,0x1E,0x22,0x42,0x42,0x42,0x22,0x1F,0x00,0x00},/*"B",34*/
{0x00,0x00,0x00,0x7C,0x42,0x42,0x01,0x01,0x01,0x01,0x01,0x42,0x22,0x1C,0x00,0x00},/*"C",35*/
{0x00,0x00,0x00,0x1F,0x22,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x1F,0x00,0x00},/*"D",36*/
{0x00,0x00,0x00,0x3F,0x42,0x12,0x12,0x1E,0x12,0x12,0x02,0x42,0x42,0x3F,0x00,0x00},/*"E",37*/
{0x00,0x00,0x00,0x3F,0x42,0x12,0x12,0x1E,0x12,0x12,0x02,0x02,0x02,0x07,0x00,0x00},/*"F",38*/
{0x00,0x00,0x00,0x3C,0x22,0x22,0x01,0x01,0x01,0x71,0x21,0x22,0x22,0x1C,0x00,0x00},/*"G",39*/
{0x00,0x00,0x00,0xE7,0x42,0x42,0x42,0x42,0x7E,0x42,0x42,0x42,0x42,0xE7,0x00,0x00},/*"H",40*/
{0x00,0x00,0x00,0x3E,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3E,0x00,0x00},/*"I",41*/
{0x00,0x00,0x00,0x7C,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x11,0x0F},/*"J",42*/
{0x00,0x00,0x00,0x77,0x22,0x12,0x0A,0x0E,0x0A,0x12,0x12,0x22,0x22,0x77,0x00,0x00},/*"K",43*/
{0x00,0x00,0x00,0x07,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x02,0x42,0x7F,0x00,0x00},/*"L",44*/
{0x00,0x00,0x00,0x77,0x36,0x36,0x36,0x36,0x2A,0x2A,0x2A,0x2A,0x2A,0x6B,0x00,0x00},/*"M",45*/
{0x00,0x00,0x00,0xE3,0x46,0x46,0x4A,0x4A,0x52,0x52,0x52,0x62,0x62,0x47,0x00,0x00},/*"N",46*/
{0x00,0x00,0x00,0x1C,0x22,0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x22,0x1C,0x00,0x00},/*"O",47*/
{0x00,0x00,0x00,0x3F,0x42,0x42,0x42,0x42,0x3E,0x02,0x02,0x02,0x02,0x07,0x00,0x00},/*"P",48*/
{0x00,0x00,0x00,0x1C,0x22,0x41,0x41,0x41,0x41,0x41,0x4D,0x53,0x32,0x1C,0x60,0x00},/*"Q",49*/
{0x00,0x00,0x00,0x3F,0x42,0x42,0x42,0x3E,0x12,0x12,0x22,0x22,0x42,0xC7,0x00,0x00},/*"R",50*/
{0x00,0x00,0x00,0x7C,0x42,0x42,0x02,0x04,0x18,0x20,0x40,0x42,0x42,0x3E,0x00,0x00},/*"S",51*/
{0x00,0x00,0x00,0x7F,0x49,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x1C,0x00,0x00},/*"T",52*/
{0x00,0x00,0x00,0xE7,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x3C,0x00,0x00},/*"U",53*/
{0x00,0x00,0x00,0xE7,0x42,0x42,0x22,0x24,0x24,0x14,0x14,0x18,0x08,0x08,0x00,0x00},/*"V",54*/
{0x00,0x00,0x00,0x6B,0x49,0x49,0x49,0x49,0x55,0x55,0x36,0x22,0x22,0x22,0x00,0x00},/*"W",55*/
{0x00,0x00,0x00,0xE7,0x42,0x24,0x24,0x18,0x18,0x18,0x24,0x24,0x42,0xE7,0x00,0x00},/*"X",56*/
{0x00,0x00,0x00,0x77,0x22,0x22,0x14,0x14,0x08,0x08,0x08,0x08,0x08,0x1C,0x00,0x00},/*"Y",57*/
{0x00,0x00,0x00,0x7E,0x21,0x20,0x10,0x10,0x08,0x04,0x04,0x42,0x42,0x3F,0x00,0x00},/*"Z",58*/
{0x00,0x78,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x78,0x00},/*"[",59*/
{0x00,0x00,0x02,0x02,0x04,0x04,0x08,0x08,0x08,0x10,0x10,0x20,0x20,0x20,0x40,0x40},/*"\",60*/
{0x00,0x1E,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x1E,0x00},/*"]",61*/
{0x00,0x38,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},/*"^",62*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF},/*"_",63*/
{0x00,0x06,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},/*"`",64*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3C,0x42,0x78,0x44,0x42,0x42,0xFC,0x00,0x00},/*"a",65*/
{0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x1A,0x26,0x42,0x42,0x42,0x26,0x1A,0x00,0x00},/*"b",66*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x02,0x02,0x02,0x44,0x38,0x00,0x00},/*"c",67*/
{0x00,0x00,0x00,0x60,0x40,0x40,0x40,0x78,0x44,0x42,0x42,0x42,0x64,0xD8,0x00,0x00},/*"d",68*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3C,0x42,0x7E,0x02,0x02,0x42,0x3C,0x00,0x00},/*"e",69*/
{0x00,0x00,0x00,0xF0,0x88,0x08,0x08,0x7E,0x08,0x08,0x08,0x08,0x08,0x3E,0x00,0x00},/*"f",70*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7C,0x22,0x22,0x1C,0x02,0x3C,0x42,0x42,0x3C},/*"g",71*/
{0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x3A,0x46,0x42,0x42,0x42,0x42,0xE7,0x00,0x00},/*"h",72*/
{0x00,0x00,0x00,0x0C,0x0C,0x00,0x00,0x0E,0x08,0x08,0x08,0x08,0x08,0x3E,0x00,0x00},/*"i",73*/
{0x00,0x00,0x00,0x30,0x30,0x00,0x00,0x38,0x20,0x20,0x20,0x20,0x20,0x20,0x22,0x1E},/*"j",74*/
{0x00,0x00,0x00,0x03,0x02,0x02,0x02,0x72,0x12,0x0A,0x16,0x12,0x22,0x77,0x00,0x00},/*"k",75*/
{0x00,0x00,0x00,0x0E,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3E,0x00,0x00},/*"l",76*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0x92,0x92,0x92,0x92,0x92,0xB7,0x00,0x00},/*"m",77*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3B,0x46,0x42,0x42,0x42,0x42,0xE7,0x00,0x00},/*"n",78*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3C,0x42,0x42,0x42,0x42,0x42,0x3C,0x00,0x00},/*"o",79*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1B,0x26,0x42,0x42,0x42,0x22,0x1E,0x02,0x07},/*"p",80*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x44,0x42,0x42,0x42,0x44,0x78,0x40,0xE0},/*"q",81*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x77,0x4C,0x04,0x04,0x04,0x04,0x1F,0x00,0x00},/*"r",82*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7C,0x42,0x02,0x3C,0x40,0x42,0x3E,0x00,0x00},/*"s",83*/
{0x00,0x00,0x00,0x00,0x00,0x08,0x08,0x3E,0x08,0x08,0x08,0x08,0x08,0x30,0x00,0x00},/*"t",84*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x63,0x42,0x42,0x42,0x42,0x62,0xDC,0x00,0x00},/*"u",85*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE7,0x42,0x24,0x24,0x14,0x08,0x08,0x00,0x00},/*"v",86*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xEB,0x49,0x49,0x55,0x55,0x22,0x22,0x00,0x00},/*"w",87*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x76,0x24,0x18,0x18,0x18,0x24,0x6E,0x00,0x00},/*"x",88*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE7,0x42,0x24,0x24,0x14,0x18,0x08,0x08,0x07},/*"y",89*/
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7E,0x22,0x10,0x08,0x08,0x44,0x7E,0x00,0x00},/*"z",90*/
{0x00,0xC0,0x20,0x20,0x20,0x20,0x20,0x10,0x20,0x20,0x20,0x20,0x20,0x20,0xC0,0x00},/*"{",91*/
{0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10},/*"|",92*/
{0x00,0x06,0x08,0x08,0x08,0x08,0x08,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x06,0x00},/*"}",93*/
{0x0C,0x32,0xC2,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},/*"~",94*/
};



unsigned char code pic1[]=
{
/* 0X10,0X10,0X00,0X5F,0X00,0X1C,0X01,0X1B, */
0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X79,0X54,0XBA,0X44,0X36,0X1C,0XB0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X64,0XAB,0XDC,0X62,0XFC,0X60,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XEC,0X61,0X7C,0XA9,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X0C,0XB4,
0X05,0XBD,0X05,0XBD,0X05,0X7C,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X7D,
0X06,0X3F,0X05,0XBD,0X0B,0XD0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X4C,0X38,
0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X54,0X79,0X54,0X7A,0X24,0X70,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0XA4,0XA6,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X20,0XFC,0X20,0XFC,0X20,0XFC,0X20,0XFC,0X20,
0XFC,0X20,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XBC,0XA5,
0X2C,0XEF,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X14,0XF1,0X05,0X3A,0X05,0XFF,0X05,0X7C,
0X05,0X3B,0X05,0X3B,0X05,0X7B,0X05,0X3B,0X05,0X3B,0X05,0X7B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0XBD,0X06,0X7F,0X0C,0X75,0X14,0XAF,0X1C,0XF0,0X1C,0XF0,0X4C,0X38,0X4C,0X38,
0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X79,0X54,0X7A,0X24,0X70,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X24,0XF0,0XD4,0X63,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,
0XFC,0X60,0XFC,0X20,0XFC,0X20,0XFC,0X20,0XFC,0X20,0XFC,0X20,0XFC,0X20,0XFC,0X20,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XE4,0X62,
0X3C,0XEE,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X15,0X33,0X05,0X7C,0X05,0X7D,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X7C,0X04,0XFB,0X05,0X3B,0X1D,0X7C,0X05,0X3B,0X05,0X7C,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X06,0X3F,0X05,0X7B,0X14,0X6F,0X1C,0XF0,0X54,0X78,0X43,0XD8,0X33,0X97,
0X33,0X97,0X44,0X38,0X4C,0X78,0X4C,0X38,0X4C,0X38,0X54,0X79,0X54,0XBA,0X1C,0XB0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0XDC,0X62,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0XC0,
0XFD,0XEE,0XFF,0X7B,0XFF,0X7A,0XFF,0X7A,0XFF,0X7A,0XFF,0X7B,0XFE,0X31,0XFB,0XC0,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XF4,0X61,
0X34,0XEE,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X14,0XF1,0X05,0XBE,0X05,0X7C,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X4D,0XBC,0XDF,0X7E,0XFF,0XFF,0X0D,0X3B,0X04,0XFB,0X05,0X7B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X06,0X3F,0X05,0X7B,0X1C,0XAF,0X23,0X57,0X64,0XB9,0X75,0X3A,0X74,0XFA,
0X54,0X78,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X54,0X7A,0X4C,0X77,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0XCC,0X64,0XFC,0X60,0XFC,0X60,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0X80,0XFF,0X38,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7C,0XFB,0XC0,0XFC,0X20,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XE4,0X62,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X05,0X7B,
0X05,0X7C,0X05,0X3B,0X05,0X3B,0X05,0X7B,0X05,0X3B,0X04,0XBB,0X15,0X3B,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XAE,0XFE,0X04,0XBB,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X06,0X3F,0X04,0XB6,0X4C,0X38,0XA6,0X3C,0XFF,0XFF,0XFF,0XFF,0X8D,0X7A,
0X33,0X97,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X54,0XBB,0X2B,0XD2,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X8C,0XA8,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,
0XFB,0XC0,0XFC,0X20,0XFC,0X60,0XFC,0X60,0XFC,0X20,0XFB,0XC0,0XFF,0X3A,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XBD,0XFC,0X20,0XFC,0X20,0XFC,0X60,
0XFC,0X60,0XFC,0X20,0XFB,0XC0,0XFC,0X20,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XAC,0XA5,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X0D,0X38,0X05,0X7D,0X05,0X3B,
0X05,0X3B,0X05,0X7B,0X05,0X3B,0X04,0XFB,0X86,0X7D,0X76,0X7D,0XBF,0X3E,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X35,0XBC,0X04,0XFB,0X05,0X7B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X06,0XBF,0XEF,0X7E,0XE7,0X7E,0XFF,0XFF,0XFF,0XFF,0X8D,0X7B,0X33,0X97,
0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X78,0X54,0XBA,0X1C,0X70,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X3C,0XEE,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X20,0XFC,0XE6,
0XFC,0X61,0XFB,0X80,0XFB,0XC0,0XFB,0X40,0XFC,0X62,0XFF,0XBD,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XE6,0XFB,0X40,0XFB,0XC0,0XFB,0X80,
0XFC,0X20,0XFC,0XE6,0XFC,0X20,0XFC,0X20,0XFC,0X60,0XFC,0X60,0XFC,0X60,0X5C,0XEC,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X15,0X33,0X05,0X7C,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X04,0XFB,0X96,0XBD,0XFF,0XFF,0XEF,0XBF,0X4D,0XFC,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XD7,0X7E,0X04,0XFB,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X7D,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X85,0X7A,0X2B,0X97,0X4C,0X38,
0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X54,0XBB,0X34,0X34,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0XB4,0XA5,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0X80,0XFD,0X28,0XFF,0XFF,0XFF,0X7C,
0XFD,0XF0,0XFC,0X64,0XFD,0X6B,0XFF,0XBD,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XFD,0XEE,0XFC,0X64,0XFD,0XAE,0XFF,0X3A,
0XFF,0XFF,0XFD,0XAD,0XFB,0X40,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XDC,0X63,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X05,0X7A,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X04,0XFB,
0X3D,0XBC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7E,0X7D,0X86,0XBD,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0X56,0X3C,0X04,0XBB,0X05,0X7B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0XBE,0X7C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X8D,0X7A,0X1B,0X16,0X4C,0X38,0X4C,0X38,
0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X79,0X4C,0X79,0X1C,0XB0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X3C,0XEE,0XFC,0X60,
0XFC,0X60,0XFC,0X60,0XFC,0X20,0XFB,0XC0,0XFF,0XBC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFC,0X62,0XFB,0XC0,0XFC,0X60,0XFC,0X60,0XFC,0X60,0X54,0XEC,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X15,0X33,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X04,0XBB,0X8E,0XBD,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF7,0XFF,0X45,0XFC,0XE7,0XBF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0X1D,0X7B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X02,0X95,
0X85,0X7A,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X85,0X7A,0X23,0X56,0X43,0XD8,0X4C,0X78,
0X4C,0X38,0X4C,0X38,0X4C,0X38,0X54,0XBB,0X24,0X31,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X94,0XA8,0XFC,0X60,0XFC,0X60,
0XFC,0X60,0XFB,0X40,0XFD,0XEF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFE,0XB4,0XFB,0X40,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XB4,0XA5,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X0D,0X37,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X04,0XBB,0X96,0XBD,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XA6,0XFD,0X66,0X3C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0X35,0XBC,0X04,0XFB,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0XC6,0XBD,0X13,0X16,
0X54,0X78,0XF7,0XBF,0XFF,0XFF,0XFF,0XFF,0XA6,0X3B,0X2B,0X97,0X3B,0XD7,0X54,0X78,
0X4C,0X38,0X4C,0X38,0X54,0X7A,0X3C,0X34,0X1C,0XB0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0XE4,0X62,0XFC,0X60,0XFC,0X60,0XFB,0XC0,
0XFC,0XA5,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XFE,0XB5,0XFD,0XEF,0XFE,0X74,0XFF,0XBC,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFD,0X28,0XFB,0XC0,0XFC,0X60,0XFC,0X60,0XFC,0X60,0X2C,0XEF,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF1,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X04,0XFB,0X66,0X3C,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X86,0X7D,0XCF,0X3E,0XCF,0X7E,0X35,0XBC,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0XFF,0XFF,0XEF,0XBE,0X3B,0XD8,
0X23,0X56,0XD6,0XFD,0XFF,0XFF,0XFF,0XFF,0XCE,0XFD,0X4C,0X38,0X43,0XD8,0X4C,0X38,
0X4C,0X38,0X4C,0X79,0X44,0X36,0X24,0X72,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X44,0XED,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0X80,0XFE,0XB3,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFE,0XB5,0XFC,0X22,0XFB,0X80,0XFB,0X80,0XFB,0X80,0XFB,0XC1,0XFE,0X72,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X79,
0XFB,0X80,0XFC,0X20,0XFC,0X60,0XFC,0X60,0X5C,0XEB,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X15,0X33,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X04,0XFB,0X35,0XBC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X5E,0X3C,0X04,0XFB,0X05,0X3B,0X04,0XFB,0X05,0X7C,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7D,0X3A,
0X02,0XD5,0X9D,0XFB,0XFF,0XFF,0XFF,0XFF,0XCE,0XFD,0X3B,0XD7,0X4C,0X38,0X4C,0X38,
0X4C,0X78,0X4C,0X37,0X2C,0X73,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X64,0XAB,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X20,0XFC,0X64,0XFE,0XF7,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XF8,0XFB,0X80,
0XFB,0XC0,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0XC0,0XFB,0X40,0XFE,0XB4,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7A,0XFC,0XA6,0XFC,0X20,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0X84,0XA9,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X15,0X34,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X0D,0X7B,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XBF,0X3E,0X04,0XBB,0X05,0X3B,0X05,0X3B,0X05,0X7B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XB6,0X7C,
0X13,0X16,0X7D,0X3A,0XFF,0XFF,0XAE,0X3C,0X3B,0XD7,0X4C,0X38,0X4C,0X38,0X4C,0X38,
0X4C,0X38,0X34,0X74,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X8C,0XA8,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0XC0,0XFB,0X80,0XFE,0X31,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XE5,0XFB,0X80,0XFC,0X60,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0XC0,0XFC,0X61,0XFF,0XBE,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XB4,0XFB,0XC0,0XFB,0X80,0XFC,0X60,0XFC,0X60,
0XFC,0X60,0XFC,0X60,0X9C,0XA7,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X0D,0X36,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X04,0XFB,0XAE,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X9E,0XFD,
0X04,0XFB,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC6,0XBD,
0X23,0X56,0X3B,0XD7,0X3B,0XD7,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,
0X3C,0XB5,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0XA4,0XA6,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X20,0XFB,0X40,0XFF,0X39,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X3A,0XFB,0XC0,0XFC,0X20,0XFC,0X60,0XFC,0X60,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0X80,0XFE,0XB5,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0X7C,0XFB,0XC0,0XFB,0XC0,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,
0XFC,0X60,0XA4,0XA6,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X0D,0X37,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X04,0XBB,0X4E,0X3C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XB7,0X3E,0X04,0XFB,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XDF,0X7E,0X43,0XD8,
0X43,0XD8,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X34,0X75,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0XAC,0XA6,0XFC,0X60,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0X80,0XFE,0XF7,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFE,0XF6,0XFB,0X80,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0X80,0XFE,0X73,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X7B,0XFB,0X80,0XFC,0X20,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,
0XA4,0XA6,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X0D,0X37,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X0D,0X3B,0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,0XEF,0XBF,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XDF,0X3E,0X43,0XD8,0X4C,0X38,
0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X78,0X4C,0X38,0X2C,0X73,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X94,0XA8,0XFC,0X60,0XFC,0X60,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0X80,0XFC,0X22,0XFF,0X7B,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XBD,0XFC,0X20,0XFC,0X20,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,
0XFC,0X60,0XFC,0X20,0XFB,0XC0,0XFF,0X39,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XBD,
0XFC,0XA4,0XFB,0X40,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0X9C,0XA7,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X0D,0X36,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X7B,
0X04,0XBB,0X86,0XBD,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X66,0X3D,0X04,0XBB,0X05,0X7B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XDF,0X3D,0X43,0XD8,0X4C,0X38,0X4C,0X38,
0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X79,0X44,0X37,0X2C,0X72,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X6C,0XAA,0XFC,0X60,0XFC,0X60,0XFC,0X60,
0XFC,0X60,0XFB,0X80,0XFC,0XA7,0XFF,0XBC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFD,0XAC,0XFB,0X40,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,
0XFB,0X40,0XFC,0XE6,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,
0XFD,0X2A,0XFB,0X80,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0X8C,0XA8,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X15,0X34,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X15,0X7B,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XDF,0X7E,0X04,0XFB,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X7B,0X05,0X3B,0X04,0XFB,0X04,0XFB,0X05,0X3B,0X05,0X7B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XDF,0X3E,0X43,0XD8,0X4C,0X38,0X4C,0X38,0X4C,0X38,
0X4C,0X38,0X4C,0X38,0X54,0X79,0X3C,0X34,0X24,0XB1,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X4C,0XED,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0XC0,
0XFD,0XAD,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XBE,0XFC,0XA5,0XFB,0X40,0XFB,0XC0,0XFC,0X20,0XFC,0X20,0XFB,0X40,0XFC,0X22,
0XFF,0X7C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFE,0X32,0XFB,0XC0,0XFC,0X60,0XFC,0X60,0XFC,0X60,0X6C,0XAB,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X15,0X33,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X7C,0X04,0XBB,
0X7E,0X7D,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7E,0XBD,0X04,0XBB,0X05,0X3B,0X05,0X3B,
0X05,0X7B,0X05,0X3B,0X04,0XFB,0X7E,0X7D,0X8E,0XBD,0X04,0XFB,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XDF,0X3E,0X43,0XD8,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,
0X4C,0X38,0X54,0XBB,0X2C,0X31,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X24,0XF0,0XF4,0X60,0XFC,0X60,0XFC,0X60,0XFB,0X80,0XFE,0X70,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFD,0XAE,0XFC,0X63,0XFC,0X20,0XFC,0X63,0XFD,0X6C,0XFF,0XBC,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XF6,
0XFB,0X80,0XFC,0X60,0XFC,0X60,0XFC,0X60,0X3C,0XEE,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF1,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X04,0XFB,
0XEF,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X5E,0X3C,0X04,0XBB,0X04,0XFB,0X04,0XFB,
0X15,0X3B,0XD7,0X7E,0XFF,0XFF,0XFF,0XFF,0X45,0XFC,0X04,0XBB,0X05,0X7B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XDF,0X3E,0X43,0XD8,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,
0X54,0X7A,0X1C,0XB0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0XAC,0XA6,0XFC,0X60,0XFC,0X60,0XFC,0X20,0XFB,0X80,0XFF,0X3A,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0X7C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XBD,0XFC,0X20,0XFC,0X20,
0XFC,0X60,0XFC,0X60,0XD4,0X63,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X0D,0X38,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X7B,0X04,0XBB,0X4D,0XFC,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7E,0X7D,0X1D,0X7B,0X1D,0X3B,0X3D,0XBC,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XDF,0XBE,0X04,0XFB,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XDF,0X3E,0X43,0XD8,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X54,0XBA,0X3C,0X35,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X4C,0XEC,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0X80,0XFC,0XE6,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFD,0XAB,0XFB,0X40,0XFC,0X60,0XFC,0X60,
0XFC,0X60,0X74,0XAA,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X15,0X33,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X04,0XBB,0XA6,0XFE,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X96,0XBD,0X86,0X7D,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X76,0X7D,0X04,0XBB,0X05,0X7B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XDF,0X3E,
0X43,0XD8,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X54,0XBA,0X24,0X70,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0XD4,0X63,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0X40,0XFE,0XB4,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFE,0X75,0XFF,0X7B,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XFE,0X75,0XFF,0XBE,
0XFF,0XFF,0XFF,0XFF,0XFF,0X39,0XFB,0X80,0XFC,0X20,0XFC,0X60,0XFC,0X60,0XEC,0X61,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X05,0X3A,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X7B,0X05,0X3B,0X04,0XFB,0XDF,0XBE,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X4D,0XFC,0XD7,0X7E,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X05,0X3B,0X04,0XFB,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0XD6,0XFD,0XC6,0XBD,0XC6,0XBD,0XC6,0XBD,0XD6,0XFD,0XAE,0X3C,0X44,0X38,
0X4C,0X38,0X4C,0X38,0X4C,0X38,0X54,0XBB,0X34,0X33,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X5C,0XEB,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0XC0,0XFC,0X62,0XFE,0XF7,0XFE,0X30,
0XFC,0XA4,0XFB,0X40,0XFC,0X22,0XFE,0X31,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XB4,0XFC,0X64,0XFB,0X40,0XFC,0X63,0XFD,0XAD,
0XFE,0XF7,0XFC,0XE6,0XFB,0XC0,0XFC,0X60,0XFC,0X60,0XFC,0X60,0X7C,0XA9,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X15,0X34,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X7C,0X04,0XFB,0X25,0X7B,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XAF,0X3E,0X5E,0X3C,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X9E,0XFD,0X04,0XFB,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X33,0X97,0X33,0X97,0X33,0X97,0X33,0X97,0X33,0X97,0X3B,0XD7,0X4C,0X38,0X4C,0X38,
0X4C,0X38,0X54,0X79,0X4C,0X79,0X1C,0XB0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0XBC,0X64,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X20,0XFB,0XC0,0XFB,0X80,0XFB,0XC0,
0XFC,0X60,0XFB,0XC0,0XFB,0X80,0XFF,0X7C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFC,0X20,0XFB,0X80,0XFC,0X60,0XFC,0X20,0XFB,0X80,0XFB,0XC0,
0XFC,0X20,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XDC,0X62,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X05,0X39,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X7C,0X04,0XBB,0X3D,0XBC,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X5D,0XFC,0XAE,0XFE,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X25,0XBC,0X04,0XFB,0X05,0X3B,0X05,0X3B,0X05,0XFF,0X4C,0X38,
0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X79,
0X54,0XBB,0X24,0X70,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X24,0XF0,
0XF4,0X61,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X20,0XFC,0X60,0XFC,0X60,0XFC,0X60,
0XFC,0X20,0XFB,0XC0,0XFF,0X38,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X7C,0XFC,0X20,0XFC,0X20,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X20,0XFC,0X60,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0X3C,0XEE,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X15,0X31,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X7C,0X04,0XBB,0X45,0XBC,0XF7,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XD7,0X7E,0X5E,0X3C,0XFF,0XFF,0XFF,0XFF,
0XA6,0XFD,0X15,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X7C,0X05,0XFF,0X4C,0X38,0X4C,0X38,
0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X38,0X4C,0X79,0X54,0XBB,0X24,0X31,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X44,0XED,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,
0XFB,0X80,0XFE,0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7B,
0XFB,0XC0,0XFC,0X20,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,
0XFC,0X60,0X64,0XEB,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X15,0X33,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X7C,0X04,0XBB,0X25,0X7B,0XCF,0X3E,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X86,0X7D,0X65,0XFC,0X4D,0XFC,0X04,0XBB,
0X05,0X3B,0X05,0X7B,0X05,0X7C,0X05,0XBE,0X14,0X71,0X4C,0X38,0X4C,0X38,0X4C,0X38,
0X4C,0X38,0X4C,0X38,0X4C,0X38,0X54,0XBA,0X54,0XBB,0X24,0X30,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X54,0XEC,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFB,0XC0,
0XFD,0X27,0XFE,0X30,0XFE,0X30,0XFE,0X30,0XFE,0X30,0XFE,0X30,0XFD,0X69,0XFB,0XC0,
0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XFC,0X60,0X6C,0XAA,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,0X1C,0XF0,
0X1C,0XF0,0X15,0X35,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,
0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X3B,0X05,0X7C,0X04,0XFB,0X04,0XFB,0X66,0X3C,
0XBF,0X3E,0XB7,0X3E,0X5E,0X3C,0X15,0X7B,0X04,0XBB,0X04,0XFB,0X05,0X7C,0X05,0X3B,
0X05,0X7C,0X05,0XBD,0X0D,0X36,0X1C,0XF0,
};

unsigned char code pic2[]=
{
/* 0X10,0X10,0X00,0X5F,0X00,0X1C,0X01,0X1B, */
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XB5,0X75,0XFF,0XFF,
0XFF,0XFF,0XFF,0XBD,0XF7,0XBE,0XF7,0XBE,0XF7,0XBE,0XF7,0XBE,0XE7,0X3D,0XEF,0X7E,
0XFF,0XBF,0XBD,0XFC,0X42,0X0B,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X39,0XC7,0XFF,0XFF,0XFF,0XFF,0XFF,0XBD,
0XFF,0X7D,0XF7,0X7D,0XF7,0X7D,0XEF,0X7D,0XE7,0X3D,0XE6,0XFC,0XDE,0XFC,0XD6,0XBC,
0XD6,0X7D,0XB5,0XFD,0X31,0X89,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0XAD,0X34,0XFF,0XFF,0XFF,0XBC,0XFF,0X7D,0XF7,0X7D,
0XF7,0XBE,0XEF,0X3C,0XE6,0XFC,0XDE,0XBB,0XCE,0X7A,0XCE,0X7A,0XCE,0X7A,0XC6,0X39,
0XC6,0X3A,0XAD,0XBB,0X29,0X47,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0XBD,0X72,0XFF,0XFB,0XFF,0X3A,0XF7,0X7C,0XF7,0X7D,0XC5,0XF7,
0X94,0X71,0X9C,0XB4,0XAD,0X35,0XAD,0X35,0XB5,0X36,0XC6,0X39,0XD6,0X7A,0XCE,0X3A,
0XC6,0X3A,0XA5,0X38,0X10,0X83,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X10,0X41,0X29,0X45,0X21,0X04,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X5A,0XC9,0XD5,0XF2,0XEE,0XB7,0XEF,0X3C,0XD6,0X78,0X41,0X86,0X00,0X00,
0X08,0X00,0X8C,0X30,0XD6,0X7A,0XCE,0X3A,0XC5,0XF8,0XC5,0XF9,0XC5,0XF8,0XAD,0X36,
0XBD,0XBA,0X62,0XCE,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X52,0X8A,
0XA5,0X33,0XEF,0X39,0XFF,0XFC,0XFF,0XFB,0XDE,0XB7,0X9C,0XF2,0X39,0XC6,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X2A,0X0A,0X6C,0XFA,0X74,0X35,0XDE,0X78,0XCD,0XF6,0X62,0XCB,0X08,0X41,0X4A,0X07,
0XD6,0X39,0XE6,0XFD,0XCE,0X7B,0XC5,0XF9,0XC5,0XF9,0XC5,0XF9,0XB5,0XB8,0XA4,0XF6,
0X8C,0X76,0X21,0X06,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XA5,0X72,0XFF,0XFF,0XFF,0XFD,
0XFF,0XFA,0XFF,0XFB,0XFF,0XFB,0XFF,0XFC,0XFF,0XFC,0XFF,0XFA,0X62,0XC9,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X5A,0X47,
0XA5,0X35,0X84,0X77,0XE6,0XFB,0XEF,0X3B,0XEF,0X3C,0XD6,0X78,0XE6,0XFB,0XDE,0XFC,
0XCE,0X3A,0XC6,0X3A,0XC6,0X3B,0XB5,0XB9,0XB5,0X78,0XBD,0XF8,0XA4,0XF5,0X8C,0X75,
0X6B,0X51,0X08,0X41,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0XB5,0XB3,0XFF,0XFF,0XFF,0XB6,0XFF,0XB7,0XFF,0XF7,
0XFF,0XF8,0XFF,0XF8,0XFF,0XB3,0XFF,0X2E,0XFF,0XB2,0XFF,0XB5,0X39,0X85,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X8B,0X83,0XF6,0XB0,
0XFF,0XFF,0XFF,0XFF,0XD6,0X7A,0XE6,0XFB,0XFF,0XFF,0XE7,0X3C,0XD6,0XBB,0XD6,0XBB,
0XD6,0X7B,0XBD,0XF9,0XA5,0X37,0X94,0X73,0X9C,0XB4,0X94,0XB5,0X6B,0X50,0X6B,0X51,
0X39,0XCA,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X5A,0XCA,0XFF,0XFF,0XF7,0XBB,0XE7,0X39,0XEF,0X7C,0XF7,0X7C,0XFF,0XB5,
0XFF,0XB1,0XFE,0XE8,0XFE,0X63,0XF6,0X69,0XFF,0XF4,0XAC,0XAB,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X31,0X87,0XDE,0X2C,0XF7,0X38,0XFF,0XFF,
0XFF,0XFF,0X9C,0XF5,0X39,0XCB,0XD6,0X39,0XE7,0X3C,0XE6,0XFC,0XDE,0XFC,0XD6,0XBB,
0XC5,0XFA,0XAD,0X37,0X94,0X74,0X83,0XD3,0X8C,0X74,0X63,0X10,0X63,0X10,0X63,0X10,
0X08,0X42,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X18,0XC2,
0XE7,0X7B,0XF7,0XFF,0XEF,0X7D,0XEF,0X3C,0X73,0X8E,0X42,0X0A,0XCE,0X34,0XFE,0XED,
0XED,0XE1,0XBC,0X20,0XBC,0XEA,0XD5,0XEF,0X62,0XC6,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X8C,0X71,0XFF,0XFE,0XF7,0XBE,0XEF,0X7E,0XF7,0XBE,
0XD6,0XBA,0X41,0XCC,0X42,0X0E,0XBD,0XB8,0XE7,0X3C,0XDE,0XFC,0XCE,0X3B,0XA5,0X37,
0X94,0XB6,0X8C,0X34,0X73,0X91,0X8C,0X74,0X73,0X51,0X41,0XCA,0X5A,0X8D,0X5A,0XCE,
0X08,0X42,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X7C,0X70,0XFF,0XFF,
0XDF,0X3C,0XDE,0XFA,0XFF,0XBC,0X6B,0X0C,0X00,0X00,0X9C,0X72,0XAC,0XAD,0X94,0X26,
0X83,0X8C,0X9C,0X30,0X93,0XCD,0X10,0X82,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X73,0X8E,0XFF,0XFF,0XEF,0X7D,0XE7,0X3C,0XE7,0X3C,0XFF,0XFE,
0XC6,0X39,0X10,0X88,0X6B,0X50,0XE6,0XFD,0XCE,0X3B,0XC6,0X3B,0X8C,0X76,0X6B,0X53,
0X6B,0X52,0X73,0X53,0X84,0X35,0X63,0X10,0X39,0XCC,0X5A,0XCE,0X7B,0XD3,0X63,0X0F,
0X08,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X21,0X45,0XE7,0XBD,0XEF,0XBE,0XDE,0XFB,
0XDE,0XB8,0XE7,0X38,0XE6,0XF8,0XBD,0X74,0XB5,0X74,0X94,0X2D,0X52,0X49,0X7C,0X32,
0XA4,0XAF,0X83,0X4B,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X29,0X04,0XCE,0X79,0XFF,0XFF,0XEF,0X7E,0XDE,0XBA,0XDE,0XFB,0XEF,0X3D,
0X83,0XD0,0X9C,0XB5,0XD6,0XBE,0XB5,0XBB,0XA5,0X3A,0X7C,0X35,0X73,0X93,0X84,0X35,
0X6B,0X54,0X7B,0XD4,0X73,0X93,0X63,0X52,0X63,0X51,0X63,0X51,0X7C,0X36,0X42,0X4E,
0X08,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0XAD,0XF5,0XE7,0XFE,0XCE,0XFC,0XDE,0XFC,0XDE,0XFA,
0XCE,0X74,0XF7,0X36,0XFF,0XB8,0XEF,0X37,0XE6,0XB2,0XB5,0X2D,0X7B,0X8C,0X8C,0X2C,
0X8B,0XC9,0X18,0XC1,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X18,0XC4,0XBD,0XB8,0XC6,0X38,0XCE,0X39,0XB5,0X75,0X83,0X8D,0X9C,0X30,0XCE,0X7B,
0XCE,0X7D,0XB5,0XFC,0X9D,0X3A,0X94,0XF9,0X9D,0X3A,0X94,0XFA,0X84,0X37,0X6B,0X94,
0X52,0XD1,0X5B,0X12,0X6B,0X53,0X6B,0X52,0X5B,0X11,0X22,0X52,0X23,0X1A,0X33,0X15,
0X08,0X84,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X4A,0X47,0XD7,0XFD,0XAE,0XFD,0XBE,0XFC,0XCF,0X3C,0XC6,0XBA,0XCE,0X76,
0XBD,0XF8,0X94,0XF8,0X73,0XD7,0XEE,0XF0,0XFF,0XF2,0XC5,0XB1,0X8C,0X2C,0XAC,0XEC,
0X4A,0X02,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X10,0X82,
0X6B,0X4E,0XB5,0X76,0X7B,0X4C,0X83,0X8D,0X6A,0XCB,0X52,0X08,0XAD,0X79,0XC6,0X7D,
0X9D,0X7B,0X94,0XFA,0X9D,0X3B,0X94,0XFB,0X7C,0X78,0X6B,0XD7,0X5B,0X56,0X43,0X15,
0X4B,0X14,0X42,0XD3,0X2A,0X93,0X12,0X13,0X02,0X13,0X0A,0X95,0X3B,0X59,0X33,0X17,
0X00,0X43,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X95,0XF5,0XB7,0XBD,0XA6,0XBB,0XC7,0X3D,0XB7,0X3C,0XCF,0X7B,0XCE,0XB9,0X11,0X53,
0X00,0X10,0X6B,0X8E,0XFF,0XAB,0XFF,0X6E,0XB5,0X2C,0X7B,0X8C,0X9C,0XAC,0X62,0XC4,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X18,0XC3,
0XAD,0XB8,0X9C,0XB3,0X7B,0X0D,0X9C,0XF6,0X7C,0X76,0X7C,0X77,0X84,0XBA,0X74,0X7A,
0X7C,0XBA,0X6C,0X7B,0X74,0X7A,0X6C,0X7A,0X64,0X39,0X64,0X39,0X53,0XD9,0X4B,0X98,
0X13,0X17,0X02,0X55,0X02,0X14,0X02,0X14,0X0A,0X53,0X32,0X50,0X3A,0X92,0X32,0X4F,
0X00,0X42,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X32,0XCA,0X8F,0XBC,
0X86,0XBB,0XA6,0XFC,0XB7,0X3C,0XA6,0XFB,0XC7,0X7A,0XCE,0X72,0X73,0X8C,0XCE,0X30,
0XFF,0X6D,0XF7,0X2C,0XE6,0XA9,0XA4,0XA7,0X41,0X85,0X7B,0X87,0X8C,0X26,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X21,0X04,
0X94,0XF9,0X74,0X77,0X7C,0X77,0X5B,0XD7,0X43,0X16,0X53,0XD8,0X6C,0X7A,0X64,0X3A,
0X64,0X7A,0X84,0XFB,0X74,0XBA,0X5C,0X7A,0X64,0X7A,0X4B,0X98,0X43,0X57,0X23,0X56,
0X02,0X95,0X01,0XD2,0X01,0XD1,0X01,0XD1,0X1A,0X10,0X52,0X8F,0X4A,0X8F,0X11,0X07,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X3A,0X48,0X67,0XFC,0X6F,0X39,0X9E,0XFB,
0XA6,0XFB,0X9E,0XFB,0X9E,0XBA,0XA6,0XB8,0XDF,0X75,0XFF,0X6C,0XC5,0XAA,0XEE,0XF1,
0XFF,0X2A,0XAC,0XE5,0X5A,0X83,0X41,0X83,0X7B,0X44,0XB5,0X68,0X42,0X87,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X18,0X82,0X3B,0X98,
0X12,0XD7,0X2A,0XD4,0X32,0XD4,0X53,0XD8,0X64,0X7B,0X64,0XBB,0X64,0X7A,0X64,0X7A,
0X64,0X7A,0X64,0X39,0X5B,0XD9,0X4B,0X97,0X2B,0X15,0X12,0X95,0X02,0X94,0X02,0X12,
0X01,0XD1,0X01,0XD0,0X01,0X8F,0X01,0X8F,0X4B,0X14,0X52,0X8F,0X18,0XC4,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X18,0XC3,0X66,0XF8,0X37,0XFA,0X7F,0X38,0XAF,0X7A,0XA7,0X3B,
0X96,0XB9,0X9E,0XB8,0X96,0XB8,0XA6,0XF5,0XD6,0XA9,0X5A,0X00,0XAC,0XA5,0XDE,0X24,
0X9C,0X65,0X31,0X86,0X6B,0X09,0X8B,0X86,0X9C,0X66,0X55,0X2F,0X09,0X04,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X3A,0X0B,0X34,0XBF,0X02,0XD8,
0X13,0X16,0X3B,0X98,0X4C,0X3B,0X54,0X7A,0X43,0XD9,0X43,0XD9,0X4B,0XD9,0X4B,0XD9,
0X4B,0X97,0X3B,0X57,0X22,0XD6,0X0A,0X94,0X02,0X53,0X02,0X12,0X01,0XD1,0X01,0X8F,
0X01,0X8E,0X01,0X8E,0X01,0X4D,0X11,0XCF,0X63,0X12,0X20,0XC4,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X34,0X6F,0X2F,0XFA,0X0E,0X74,0X66,0XB6,0X8E,0XF8,0X9E,0XF9,0X96,0XB7,
0X96,0XB7,0X76,0X76,0X76,0X33,0X9E,0X2F,0XAD,0XA7,0XBD,0X23,0XA4,0X65,0X73,0X05,
0X4B,0X0B,0X64,0X2E,0X5B,0X48,0X4B,0X07,0X1C,0X2D,0X0A,0X89,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X53,0XD7,0X2C,0X7E,0X03,0X1A,0X0B,0X59,
0X1B,0X59,0X03,0X18,0X33,0X98,0X23,0X58,0X03,0X17,0X23,0X57,0X2B,0X58,0X33,0X56,
0X22,0XD5,0X1A,0X94,0X12,0X94,0X0A,0X94,0X02,0X52,0X01,0XD1,0X01,0X8F,0X01,0X8D,
0X01,0X4C,0X01,0X4C,0X01,0X0B,0X4A,0X8F,0X31,0X46,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X41,
0X1E,0X34,0X0F,0X37,0X06,0X74,0X16,0X74,0X66,0X75,0X76,0XB5,0X76,0XB5,0X76,0X75,
0X5D,0XF3,0X55,0XB2,0X4C,0XEF,0X6C,0XEC,0X8C,0XE9,0X53,0X05,0X2A,0X47,0X23,0XCC,
0X1B,0X4B,0X12,0XC7,0X02,0X89,0X03,0X8C,0X0B,0X8B,0X08,0X41,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X22,0X0D,0X5D,0X3F,0X23,0XDB,0X0B,0X9A,0X03,0X59,0X03,0X59,
0X2B,0X99,0X43,0X98,0X1B,0X18,0X0B,0X17,0X02,0XD6,0X02,0XD6,0X12,0X94,0X1A,0X52,
0X12,0X93,0X12,0XD5,0X02,0X54,0X02,0X12,0X02,0X11,0X01,0XCF,0X01,0X8D,0X01,0X4C,
0X01,0X0A,0X01,0X0A,0X3A,0X4E,0X41,0XC9,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X85,0X06,0XF7,
0X06,0XB5,0X1E,0X34,0X15,0XF2,0X1E,0X32,0X2E,0X33,0X1D,0XF3,0X3D,0XB2,0X4D,0X6F,
0X2C,0XAD,0X1C,0X2C,0X23,0X8A,0X1A,0XC8,0X02,0X48,0X03,0X4A,0X03,0X8A,0X03,0X08,
0X02,0X87,0X02,0X89,0X03,0X8C,0X04,0X6D,0X09,0X44,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X3B,0X55,0X4C,0XBE,0X13,0X9A,0X03,0X5A,0X03,0X59,0X03,0X59,0X2B,0XDA,
0X43,0X99,0X0B,0X58,0X13,0X58,0X0A,0XD6,0X02,0X54,0X12,0X52,0X12,0X52,0X02,0X53,
0X02,0X94,0X02,0X12,0X01,0XD1,0X01,0XD1,0X01,0XCF,0X09,0XCE,0X09,0X8D,0X01,0X4B,
0X01,0X0A,0X32,0X0D,0X4A,0X0A,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X02,0XCA,0X0F,0X38,0X06,0X74,
0X1E,0X73,0X26,0X33,0X05,0XF2,0X0D,0XB2,0X05,0X30,0X05,0X2F,0X1D,0X2F,0X04,0XAF,
0X04,0X2D,0X03,0X8A,0X03,0X09,0X03,0X09,0X03,0X4A,0X03,0X4A,0X03,0X49,0X03,0X09,
0X03,0X0A,0X03,0XCC,0X0B,0XCD,0X09,0X45,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X2B,0X56,0X3C,0X7D,0X34,0X3B,0X0B,0X9A,0X0B,0X9A,0X0B,0X59,0X03,0X59,0X0B,0X59,
0X0B,0X59,0X0B,0X58,0X02,0XD5,0X02,0X13,0X12,0X52,0X22,0XD4,0X0A,0X94,0X02,0X12,
0X02,0X12,0X02,0X11,0X01,0XD0,0X01,0X8D,0X09,0XCD,0X09,0XCD,0X09,0X4B,0X01,0X0A,
0X32,0X0D,0X41,0XC9,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X0A,0XC9,0X0E,0XF6,0X06,0X74,0X06,0X31,
0X05,0XF2,0X05,0XF2,0X05,0XB1,0X05,0X2E,0X04,0XED,0X04,0XEF,0X04,0X6E,0X04,0X2E,
0X04,0X2D,0X03,0XCD,0X03,0XCB,0X03,0X4A,0X03,0X49,0X02,0XC8,0X03,0X09,0X03,0X8B,
0X03,0XCD,0X03,0X0C,0X00,0XC3,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X83,0X23,0X98,
0X3C,0X7D,0X3C,0X3B,0X1B,0XDB,0X1B,0XDA,0X0B,0X59,0X03,0X59,0X03,0X58,0X03,0X18,
0X02,0XD7,0X02,0X54,0X02,0X13,0X0A,0XD5,0X23,0X16,0X0A,0X93,0X02,0X52,0X02,0X52,
0X02,0X11,0X01,0XCF,0X01,0X4D,0X01,0X4C,0X01,0X4B,0X01,0X0A,0X09,0X0A,0X29,0X8B,
0X4A,0X4D,0X19,0X05,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X0A,0X88,0X06,0XF6,0X0E,0XB5,0X0E,0X33,0X05,0XB1,
0X05,0XB0,0X05,0X70,0X05,0X2F,0X04,0XAE,0X04,0XAD,0X04,0X6D,0X04,0XAE,0X04,0X6E,
0X04,0X2E,0X03,0X8B,0X03,0X09,0X02,0X87,0X02,0X87,0X03,0X09,0X03,0X8B,0X03,0X8D,
0X0B,0X4C,0X08,0XC2,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X11,0X8A,0X2C,0X3A,0X2C,0X3B,
0X24,0X3B,0X34,0X3B,0X0B,0X59,0X03,0X59,0X03,0X59,0X03,0X18,0X02,0X96,0X02,0X95,
0X02,0X53,0X02,0X53,0X02,0XD5,0X02,0X54,0X02,0X12,0X0A,0X93,0X02,0X94,0X02,0X11,
0X01,0X4D,0X01,0X4B,0X01,0X4C,0X01,0X4B,0X09,0X4B,0X19,0X4A,0X21,0X4A,0X5A,0XD0,
0X31,0X87,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X03,0X0A,0X06,0XB5,0X16,0X75,0X0D,0XF4,0X05,0XF2,0X05,0X6F,
0X05,0X30,0X05,0X6F,0X04,0XAF,0X04,0X6D,0X04,0X6C,0X04,0X2C,0X03,0XCB,0X03,0X4B,
0X03,0X0A,0X02,0X47,0X02,0X06,0X02,0X87,0X02,0XC8,0X03,0X8B,0X04,0X2D,0X0B,0X8B,
0X09,0X03,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X02,0X12,0X91,0X14,0X3B,0X03,0X9A,0X0B,0XDA,
0X24,0X3A,0X13,0X9A,0X03,0X59,0X0B,0X58,0X02,0XD6,0X02,0X96,0X02,0X95,0X02,0X94,
0X02,0X53,0X02,0X11,0X01,0XD0,0X02,0X52,0X0A,0X93,0X02,0X52,0X01,0X8E,0X01,0X0A,
0X01,0X0A,0X01,0X4B,0X01,0X4C,0X01,0X4B,0X09,0X4A,0X29,0X8B,0X52,0X8E,0X21,0X05,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X02,0X07,0X06,0X74,0X06,0X33,0X05,0XB3,0X05,0XB2,0X05,0XB1,0X05,0X70,
0X04,0XEF,0X04,0XAD,0X04,0X6D,0X03,0X8A,0X03,0X4A,0X03,0X4A,0X03,0X0A,0X02,0XC9,
0X02,0X86,0X02,0X87,0X02,0X87,0X03,0X09,0X03,0XCC,0X04,0X6D,0X03,0XCC,0X09,0X03,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X01,0X09,0XCD,0X03,0X9A,0X03,0X5A,0X03,0X59,0X03,0X99,
0X0B,0X9A,0X03,0X99,0X03,0X18,0X02,0XD6,0X02,0XD5,0X02,0X95,0X02,0X53,0X02,0X53,
0X02,0X10,0X02,0X10,0X0A,0X92,0X02,0X51,0X01,0X8E,0X01,0X4C,0X01,0X4B,0X01,0X4C,
0X01,0X4B,0X01,0X4B,0X09,0X4B,0X11,0X4A,0X3A,0X0C,0X4A,0X4C,0X10,0X84,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X11,0X04,0X15,0XB2,0X05,0XF3,0X05,0X31,0X04,0XF0,0X05,0XB1,0X05,0X70,0X04,0XEE,
0X04,0X6D,0X03,0X8B,0X03,0X09,0X03,0X8B,0X03,0XCC,0X03,0X4A,0X03,0X09,0X03,0X08,
0X02,0XC8,0X02,0X88,0X03,0XCB,0X04,0X6E,0X03,0XCC,0X13,0X8C,0X11,0X03,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X08,0X84,0X0B,0X15,0X03,0X59,0X03,0X18,0X03,0X58,0X03,0X59,
0X03,0X58,0X03,0X58,0X03,0X17,0X02,0XD5,0X02,0X53,0X02,0X12,0X02,0X11,0X01,0XCF,
0X02,0X52,0X02,0X52,0X01,0X8E,0X01,0X4D,0X01,0X8D,0X01,0X8D,0X01,0X4C,0X01,0X4C,
0X01,0X4B,0X09,0X4A,0X19,0X49,0X42,0X4D,0X5A,0XCE,0X21,0X04,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X21,0X45,
0X24,0XF1,0X04,0XF0,0X04,0X2D,0X04,0X2D,0X05,0X31,0X05,0X70,0X05,0X2F,0X04,0X6D,
0X03,0X4A,0X0B,0X8B,0X04,0X2C,0X03,0X8B,0X03,0X09,0X02,0XC9,0X02,0X88,0X02,0X47,
0X02,0X47,0X03,0XCB,0X05,0X31,0X03,0X4D,0X12,0X48,0X10,0XC2,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X10,0X00,0X1A,0XD3,0X03,0X5A,0X03,0X18,0X03,0X17,0X03,0X17,0X03,0X58,
0X0B,0X58,0X03,0X17,0X02,0XD5,0X02,0X52,0X02,0X12,0X01,0XCE,0X01,0X4D,0X02,0X12,
0X02,0X11,0X01,0X8E,0X01,0XCF,0X01,0X8F,0X01,0X4D,0X01,0X4C,0X01,0X4B,0X01,0X4A,
0X09,0X09,0X19,0X49,0X4A,0X4E,0X63,0X10,0X18,0XC3,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
};


unsigned char code pic3[]=
{/* 0X10,0X10,0X00,0X5F,0X00,0X1C,0X01,0X1B, */
0X53,0XC6,0X53,0XC6,0X54,0X26,0X5C,0X67,0X64,0X67,0X6C,0XE8,0X75,0X69,0X85,0XE9,
0X96,0XAA,0X9E,0XEC,0X7D,0XAA,0X4B,0X87,0X5B,0X05,0XA3,0X81,0XB3,0X40,0X72,0X83,
0XCE,0X35,0XE6,0XAA,0XF6,0XA8,0XE5,0XA2,0X9A,0XC0,0X62,0X87,0XA5,0X7B,0XBE,0X3C,
0XE7,0X3E,0XF7,0XFF,0XDF,0X3D,0X00,0X00,0X00,0X00,0X08,0X41,0X4A,0X8B,0X6B,0X4E,
0X39,0XC8,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X18,0X86,0X7A,0X1A,
0X69,0X97,0X49,0X18,0X8A,0X8F,0XDD,0X20,0XED,0XA0,0XF6,0XE6,0XF7,0X6A,0XFF,0XAB,
0XF7,0XAA,0XF7,0XAA,0XFF,0XE9,0XCE,0X67,0XBD,0XA6,0XFF,0XE5,0XF7,0X24,0XEE,0XA5,
0XF6,0XA5,0XDD,0X62,0XE5,0XA1,0XE5,0X22,0X72,0XC1,0X00,0X01,0XB5,0XA8,0XFF,0XED,
0XFF,0XEB,0XF7,0XAB,0XFF,0X6A,0XF6,0XA4,0XED,0XA0,0XAC,0X26,0X7C,0XB9,0XAD,0XBA,
0XDE,0XFE,0XFF,0XFF,0XFF,0XFF,0XEF,0X7D,0XE7,0X3E,0XEF,0XFF,0XF7,0XFF,0XF2,0XCB,
0XD9,0X05,0X99,0X02,0X39,0X00,0X2A,0X83,0X43,0X44,0X1A,0X01,0X11,0X01,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X33,0X05,
0X3B,0X05,0X3B,0X04,0X33,0X04,0X3B,0X05,0X3B,0X45,0X43,0XC5,0X4C,0X26,0X54,0X66,
0X64,0XE8,0X7D,0XA9,0X8E,0X6A,0X75,0XEA,0X64,0X65,0X8B,0XC7,0XFF,0XBF,0XFF,0XFF,
0XC6,0X31,0XCE,0X2F,0XFF,0XFC,0XBC,0XE7,0XA4,0X69,0XA5,0X7B,0XBE,0X3C,0XDF,0X3E,
0XDE,0XFE,0XBE,0X3C,0X00,0X00,0X63,0X4C,0XDF,0X3C,0XEF,0X7F,0XE7,0X7F,0XE7,0X3F,
0X84,0X33,0X08,0X42,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X39,0X0D,0X69,0XD7,
0X51,0X57,0X69,0XCF,0XCC,0XA0,0XD5,0X20,0XED,0XE1,0XEE,0X62,0XEE,0X65,0XF6,0XE8,
0XFF,0XE9,0XF7,0X29,0XE5,0XE7,0XBD,0XA7,0XC6,0X26,0XFF,0XE5,0XF7,0X65,0XEE,0XA4,
0XDD,0XA2,0XE6,0X60,0XD5,0XA0,0X5A,0X80,0X95,0XA8,0XFF,0XED,0XFF,0XEA,0XF7,0XAA,
0XFF,0XAA,0XEE,0XA6,0XED,0XE2,0XE5,0X60,0XA3,0XC3,0X84,0X76,0XBD,0XFB,0XE7,0X3E,
0XEF,0X7D,0XE7,0X3E,0XF7,0XFF,0XFF,0XFF,0XDD,0X77,0XBA,0X4A,0X70,0X40,0X41,0X00,
0X09,0XC1,0X01,0XC2,0X3A,0X83,0X21,0X81,0X11,0X01,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X2A,0X03,0X2A,0X44,
0X32,0X84,0X3B,0X05,0X43,0X45,0X4B,0XC6,0X4C,0X26,0X43,0XC5,0X3B,0X85,0X3B,0X44,
0X43,0X85,0X54,0X26,0X64,0XA7,0X6D,0X28,0X65,0X29,0X95,0XB1,0XFF,0XFF,0XFF,0XFF,
0X9C,0X22,0XCE,0X78,0XCE,0XFF,0X9D,0X36,0X8C,0X76,0XBE,0X3B,0XD6,0XBE,0XB5,0XBA,
0X84,0X76,0XA5,0X75,0XFF,0XFF,0XFF,0XFF,0XDF,0X3E,0XC6,0X3C,0XC6,0X3C,0XFF,0XFF,
0X63,0X4E,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X18,0X85,0X28,0XC8,
0X00,0X06,0X31,0X05,0XB3,0XC4,0XD5,0X20,0XDD,0XE0,0XEE,0X62,0XF7,0XA3,0XDD,0XA5,
0XD1,0X03,0XE8,0X04,0XE1,0XC5,0X93,0XC5,0XC6,0XE6,0XFF,0XE5,0XEE,0X65,0XE5,0XE3,
0XE4,0X64,0XD2,0X83,0XBA,0X87,0XFD,0XEF,0XFF,0XEA,0XF7,0XA9,0XF7,0XAA,0XF7,0X27,
0XE5,0XE3,0XF5,0XE2,0XD4,0XE0,0XA3,0XC4,0X8C,0X77,0XBD,0XFB,0XD6,0XBC,0XDE,0XFF,
0XEF,0X7F,0XD5,0XB8,0X9A,0X49,0XA2,0X06,0X8B,0X08,0X1A,0X43,0X0A,0X03,0X00,0XC0,
0X19,0X41,0X08,0XC0,0X00,0X40,0X00,0X00,0X00,0X00,0X08,0X42,0X00,0X01,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X08,0X41,0X10,0XC1,0X19,0X42,0X2A,0X44,0X32,0XC4,0X3B,0X45,0X4B,0XC6,0X3B,0X85,
0X32,0XC4,0X32,0XC4,0X43,0X05,0X4B,0X85,0X33,0X01,0X6C,0X29,0XF7,0XFF,0XCD,0XF1,
0XA4,0XAC,0XBE,0X7F,0X8C,0XB8,0X73,0XD4,0X8C,0X75,0XBE,0X3C,0X84,0X76,0XA5,0X37,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XEF,0XBE,0XDE,0XFE,0XE7,0X7F,0XBE,0X3B,0X29,0X46,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X40,
0X20,0X91,0X31,0X16,0X72,0XCB,0XD3,0X84,0XE4,0X63,0XD4,0X62,0XC0,0X02,0XE8,0X05,
0XE0,0X04,0XE0,0X04,0XD1,0XC3,0X8B,0XC4,0XE9,0XC6,0XF0,0XC6,0XE1,0XC6,0XF8,0X09,
0XE0,0X08,0XF0,0X4C,0XF3,0X8B,0XF7,0XE9,0XFF,0XA9,0XF7,0X27,0XEE,0X23,0XFE,0X22,
0XE5,0XA3,0XC4,0X60,0X9C,0X28,0X7C,0X37,0XAD,0X39,0XA5,0X7A,0XB6,0X39,0X95,0X2D,
0X4A,0X80,0X42,0XC0,0X75,0X6A,0X7E,0X2C,0X75,0X29,0X7D,0X29,0X75,0X28,0X64,0X67,
0X2A,0X43,0X08,0X81,0X31,0XC4,0X6C,0X6A,0X8C,0XED,0X5A,0X4A,0X21,0X04,0X10,0XC1,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X81,0X19,0X83,0X2A,0X44,0X3A,0XC5,
0X2A,0X84,0X19,0XC3,0X2A,0X04,0X32,0X44,0X22,0X00,0X43,0X07,0XBE,0X38,0XBD,0XB2,
0XD6,0XBD,0XA5,0X39,0X8C,0XB6,0X7B,0XD4,0X94,0XF7,0X84,0X35,0XDE,0XFC,0XFF,0XFF,
0XF7,0XBE,0XF7,0XBE,0XFF,0XFF,0XDF,0XBF,0X5B,0X90,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X8B,0X62,0X17,
0X99,0X4E,0XB8,0XCD,0XF1,0X8A,0XA8,0X03,0XA0,0X03,0XE0,0X04,0XE8,0X44,0XB8,0X03,
0XF8,0X05,0XC0,0X84,0X80,0X02,0XD8,0X05,0XB8,0X04,0XF0,0X08,0XE0,0X07,0XD0,0X08,
0XF2,0X8D,0XF7,0X2A,0XFF,0X67,0XFE,0XE4,0XFE,0X62,0XFE,0X22,0XF5,0XA1,0XCC,0X60,
0XC4,0X60,0X7B,0X4D,0X63,0X54,0X73,0XD1,0X6C,0XAB,0X5C,0X64,0X5C,0X26,0X74,0XEE,
0XB6,0X79,0X6C,0X2C,0X00,0X00,0X2A,0X01,0X3A,0XC3,0X3A,0XC4,0X4B,0X85,0X4B,0X46,
0X53,0XC7,0X85,0X6C,0X85,0X2B,0X85,0X2A,0X9C,0X32,0XBC,0X78,0X8B,0X11,0X28,0X84,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X10,0XC1,0X4A,0XC5,
0X5B,0X86,0X09,0X00,0X19,0X42,0X21,0XC4,0X11,0X40,0X3A,0X87,0XBE,0X35,0XE7,0X7D,
0XB5,0XFC,0X94,0XF8,0X8C,0X76,0X84,0X76,0X9D,0X38,0XEF,0X7E,0XF7,0XBE,0XF7,0XBF,
0XFF,0XFF,0XAD,0XF9,0X41,0XC7,0X40,0X01,0X48,0X82,0X28,0X41,0X50,0X83,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X48,0XC3,0X79,0X07,0XB1,0X49,0XF9,0XC6,
0XF9,0X04,0XE1,0X47,0X98,0X02,0XB0,0X03,0XF0,0X45,0XB8,0X03,0XC8,0X04,0XF8,0X45,
0X70,0X02,0X70,0X02,0XA0,0X03,0XA8,0X04,0XE0,0X46,0XB0,0X05,0XD0,0X88,0XFE,0XEA,
0XFF,0XE6,0XDE,0X24,0XC6,0X26,0XB5,0XE6,0XA5,0XA6,0X94,0XA4,0XB4,0XE2,0X93,0X88,
0X4A,0X10,0X5B,0X8B,0X64,0XA5,0X5C,0X26,0X63,0X8D,0X8C,0X75,0XAD,0X7B,0XCE,0X3E,
0X7C,0X31,0X42,0X88,0X4B,0X07,0X08,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X63,0X0A,
0X6C,0X2A,0X5C,0XA8,0XB7,0X6D,0XA5,0X30,0X92,0X94,0X69,0X50,0X92,0X8D,0X51,0X84,
0X00,0X00,0X00,0X00,0X19,0X41,0X08,0X81,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X20,0XC1,0X94,0XAC,
0X7C,0XB1,0X19,0X82,0X08,0XC0,0X21,0X43,0X08,0XC0,0X42,0X86,0XE7,0X3D,0XD6,0XFF,
0XA5,0X79,0X94,0XB7,0X94,0XF7,0XAD,0XB9,0XD6,0XBD,0XDF,0XBF,0XDF,0XFF,0X5C,0XB2,
0X00,0X00,0XC0,0X84,0XFB,0X4E,0XFA,0X4B,0XF1,0X06,0XF9,0X89,0X80,0X03,0X68,0X42,
0X00,0X00,0X48,0X42,0XC9,0X46,0XF9,0X87,0XF9,0X87,0XD0,0X43,0XF1,0X46,0XF1,0X06,
0XE1,0X06,0X90,0X02,0XB8,0X03,0XD8,0X44,0XA0,0X03,0XE8,0X05,0XB0,0X04,0X28,0X00,
0XB0,0XC5,0X99,0X05,0X80,0X02,0XB0,0X05,0XA8,0X04,0XFA,0XC7,0XEF,0X65,0X95,0X66,
0X64,0XE8,0X44,0XA8,0X34,0XA8,0X34,0X67,0X34,0XA8,0X44,0XA7,0X44,0X29,0X53,0XC8,
0X5B,0XC6,0X53,0X09,0X5A,0XCE,0X7B,0X94,0X8C,0X76,0X8C,0X75,0X84,0X75,0X9C,0XF8,
0X9D,0X39,0X8C,0X77,0X7C,0X34,0X3A,0X0A,0X00,0X00,0X00,0X00,0X5A,0X4A,0X63,0X89,
0X84,0XAC,0XCD,0XF5,0X83,0X8E,0XB5,0X75,0X92,0X52,0XA2,0XCD,0XF6,0X38,0X51,0XCA,
0X00,0X00,0X09,0X41,0X19,0XC2,0X21,0XC2,0X11,0X01,0X08,0X01,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X94,0XB6,
0XBE,0X3C,0X4A,0X89,0X08,0XC0,0X10,0XC1,0X00,0X80,0X5B,0X4B,0XDE,0XFF,0XC6,0X7D,
0XBE,0X3B,0XB5,0XB9,0XAD,0XBA,0XB6,0XBF,0XDD,0XBA,0XB2,0X4C,0X20,0X00,0X98,0X01,
0XFA,0X0A,0XFB,0X4D,0XFA,0X4B,0XF8,0XC6,0XE9,0XC9,0XD0,0X04,0XF8,0X05,0X90,0X43,
0X58,0X01,0XE9,0X46,0XD9,0X05,0XE1,0X06,0XC0,0X84,0XD8,0XC5,0XE8,0XC5,0XE0,0XC5,
0X90,0X02,0XB8,0X04,0XC0,0X03,0XA0,0X03,0XE0,0X04,0X50,0X82,0X30,0X01,0XC1,0X06,
0X58,0XC3,0X68,0X02,0X98,0X04,0XC0,0X04,0XBA,0X44,0X4C,0X25,0X33,0XC7,0X3C,0X66,
0X43,0X84,0X53,0X02,0X5B,0X02,0X5B,0X02,0X53,0X03,0X43,0XC4,0X3C,0XA4,0X3B,0X46,
0X49,0XCD,0X6B,0X10,0X8C,0X74,0X8C,0XB6,0X8C,0X75,0XAD,0XB9,0XB5,0XBB,0XA5,0X39,
0X94,0XB7,0X94,0XB8,0X94,0XB8,0X21,0X07,0X00,0X00,0X42,0X07,0X7C,0X2A,0X72,0XCC,
0XB3,0X9A,0X9A,0X56,0X8A,0X94,0XBA,0XCE,0XF5,0X6C,0XFF,0X3F,0X8C,0XBE,0X08,0X44,
0X2A,0X83,0X19,0X81,0X11,0X41,0X22,0X02,0X2A,0X02,0X19,0X42,0X08,0X41,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X10,0X82,0X42,0X08,0X08,0X41,0X00,0X00,0X8C,0X34,
0XB5,0XBC,0X6B,0X90,0X19,0X43,0X08,0XC0,0X08,0XC0,0X6B,0XD0,0XCE,0X7F,0XCE,0X7C,
0XBE,0X7C,0X9E,0X3B,0XB5,0XB9,0XF9,0XC9,0XE8,0X00,0XF0,0X04,0XF8,0X06,0XE9,0X47,
0XFB,0X8D,0XFA,0X8B,0XF0,0XC6,0XF2,0X0A,0XB0,0X44,0XD0,0X03,0XF0,0X44,0X88,0X02,
0XA0,0XC4,0XD1,0X05,0XD0,0X84,0XB8,0X84,0XB8,0X84,0XE0,0X85,0XE0,0XC5,0X98,0X43,
0XB0,0X04,0XA8,0X03,0XA8,0X03,0XA8,0X84,0X19,0X43,0X60,0X82,0X68,0X43,0X30,0X00,
0X70,0X02,0X90,0X03,0XB8,0X04,0X49,0X03,0X0A,0X84,0X43,0XC5,0X52,0XC3,0X59,0XC0,
0X6A,0X00,0X82,0X80,0X93,0X00,0XAB,0X40,0X9B,0X40,0X52,0X84,0X2B,0X87,0X4B,0XC9,
0X8C,0X75,0X9D,0X38,0X9D,0X38,0XB5,0XFB,0XC6,0X7D,0XC6,0X7D,0XC6,0X7D,0XBD,0XFB,
0X9C,0XF8,0X94,0XF9,0X42,0X0C,0X00,0X00,0X08,0X01,0X39,0X08,0X39,0X06,0X62,0X8B,
0X71,0XCF,0X81,0X89,0XF5,0X72,0XFF,0XFC,0XEF,0XFF,0X8D,0XFF,0X10,0X86,0X42,0XC3,
0X3B,0X03,0X3A,0X83,0X21,0XC2,0X11,0X81,0X22,0X02,0X2A,0X02,0X21,0X82,0X10,0XC1,
0X00,0X00,0X00,0X00,0X84,0X33,0XFF,0XFF,0XBE,0X3B,0X7C,0X32,0X63,0X50,0X8C,0XB7,
0X94,0XF9,0X7B,0XD3,0X32,0X06,0X08,0XC0,0X19,0X41,0X84,0X75,0XAD,0XFD,0XAE,0X7E,
0XAC,0XB5,0XF2,0X09,0XFA,0X49,0XF9,0X08,0XD8,0X03,0XE8,0X04,0XF0,0XC6,0XFB,0X8D,
0XFA,0X8B,0XF8,0XC5,0XF2,0X0A,0XB0,0X84,0XC0,0X03,0XE0,0X04,0XA8,0X03,0X88,0X43,
0XC8,0XC4,0XB8,0X44,0XC0,0X44,0XA0,0X43,0XC8,0X84,0XE0,0X85,0XA0,0X43,0XA0,0X03,
0X98,0X03,0XA0,0X03,0X68,0X42,0X00,0X81,0X58,0X82,0X60,0X43,0X70,0X43,0X60,0X01,
0X88,0X03,0X98,0X03,0X31,0X03,0X2B,0X44,0X5A,0XC2,0X49,0X00,0X59,0XC1,0X6A,0X81,
0X83,0X01,0X9B,0X81,0XB4,0X62,0XBC,0X21,0XBB,0X80,0X72,0XC7,0X4B,0XCC,0X74,0XB0,
0XA5,0X37,0XA5,0X79,0X7C,0X36,0X8C,0XB7,0XB5,0XBA,0XD6,0XFE,0XF7,0XFF,0XEF,0XBF,
0X9C,0XF8,0X29,0X47,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X01,
0X30,0XC2,0X83,0X0B,0X94,0X7A,0X7D,0X3D,0X42,0XD1,0X00,0X00,0XB1,0XC7,0X19,0XC2,
0X2A,0XC3,0X53,0X85,0X4B,0X44,0X2A,0X02,0X11,0X41,0X19,0XC2,0X22,0X42,0X19,0X40,
0X08,0XC0,0X9D,0X77,0XD6,0XFF,0XD6,0XFE,0XBE,0X3D,0X9D,0X3A,0X6B,0X94,0X63,0X52,
0X73,0XD4,0X73,0X94,0X3A,0X08,0X00,0XC0,0X0A,0X46,0X93,0XD4,0XEB,0X0E,0XE9,0X48,
0XF1,0XC8,0XFB,0X4D,0XF9,0XC9,0XD8,0X04,0XE0,0X04,0XF0,0X86,0XF2,0XCB,0XF2,0X8B,
0XF8,0XC5,0XFA,0X09,0XB8,0XC5,0XB8,0X02,0XD0,0X03,0XB8,0X03,0X78,0X02,0XB0,0X84,
0XA8,0X43,0XB8,0X43,0X98,0X03,0XA8,0X43,0XD0,0X84,0XA8,0X43,0X88,0X03,0X88,0X02,
0X90,0X02,0X28,0X00,0X00,0X00,0X68,0X43,0X80,0X84,0X68,0X42,0X60,0X02,0X78,0X02,
0X88,0X02,0X41,0XC4,0X19,0X82,0X49,0X80,0X62,0X41,0X62,0X41,0X72,0X41,0X8B,0X01,
0XA3,0XC2,0XB4,0X63,0XC4,0XA3,0XD4,0XE1,0XBB,0X80,0X7A,0X47,0X6B,0X92,0XB6,0X3A,
0XE7,0X3E,0XBD,0XF9,0X6B,0X93,0X84,0X35,0XAD,0XBA,0XAD,0XB7,0X73,0XCF,0X18,0XC2,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X01,0X00,0X02,0X00,0X00,0X00,0X00,0XF2,0X8A,0X73,0X06,0X0A,0X82,
0X19,0XC1,0X43,0X04,0X64,0X26,0X53,0X84,0X22,0X02,0X09,0X41,0X11,0XC0,0X11,0X81,
0X5A,0XCF,0XBE,0X3C,0XD7,0X3C,0XC6,0X3C,0XAD,0XBB,0X94,0XF8,0X84,0X37,0X6B,0X95,
0X63,0X12,0X5B,0X12,0X1A,0X08,0X51,0XC4,0XDA,0X8B,0XF9,0X88,0XF9,0X88,0XF2,0X0A,
0XF2,0XCC,0XFB,0X0C,0XE0,0X86,0XD0,0X03,0XF0,0X45,0XF2,0X4A,0XFA,0X8A,0XF0,0XC6,
0XF9,0XC9,0XB8,0XC5,0XB0,0X02,0XC0,0X43,0XB8,0X03,0X70,0X02,0X88,0X42,0X90,0X43,
0XB0,0X43,0X90,0X03,0X88,0X03,0XB8,0X43,0XA8,0X43,0X78,0X02,0X78,0X02,0X68,0X02,
0X18,0X01,0X50,0X82,0X80,0X43,0X78,0X84,0X60,0X42,0X50,0X01,0X78,0X02,0X98,0X43,
0X41,0X03,0X00,0X00,0X08,0X00,0X51,0XC1,0X82,0XC0,0X7A,0XC0,0X82,0XC1,0X93,0X01,
0XAB,0XC1,0XC4,0XA2,0XCC,0XE3,0XC4,0XA2,0XAB,0X40,0X82,0XC6,0XA5,0X79,0XDF,0X3E,
0XFF,0XFF,0XD6,0XFB,0X21,0X04,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X29,0X8D,0X19,0X07,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XE2,0X09,0X9C,0X69,0X5D,0XA7,0X4C,0X24,
0X22,0X81,0X1A,0X02,0X43,0X44,0X64,0X65,0X4B,0X83,0X21,0XC3,0X30,0X8E,0X38,0X50,
0X61,0XD6,0XBD,0XFC,0XE7,0XBF,0XC6,0X3D,0XB5,0XBA,0X94,0XF9,0X6B,0X94,0X3A,0X4E,
0X31,0XCD,0XBA,0X8D,0XFB,0X8D,0XFB,0X0C,0XF1,0X07,0XE8,0XC6,0XFA,0X8B,0XF2,0X4B,
0XFB,0X0D,0XF1,0X89,0XC8,0X03,0XE0,0X04,0XF2,0X09,0XFA,0X8B,0XF0,0X86,0XF9,0X88,
0XB8,0XC5,0XA0,0X02,0XB8,0X03,0XB8,0X03,0X70,0X02,0X68,0X42,0X78,0X42,0X98,0X42,
0X90,0X03,0X70,0X02,0X90,0X42,0X98,0X03,0X68,0X02,0X58,0X01,0X20,0X00,0X88,0XC4,
0XA8,0XC4,0X70,0X42,0X80,0X84,0X58,0X02,0X50,0X01,0X88,0X03,0X98,0X44,0X20,0X01,
0X00,0X00,0X00,0X00,0X00,0X01,0X4A,0X43,0X83,0X42,0X93,0X41,0X9B,0X40,0XA3,0X40,
0XAB,0XC0,0XBC,0X61,0XCC,0XA1,0XDC,0XE0,0XBB,0XC0,0X94,0XB4,0XCE,0XBE,0XDE,0XFD,
0XFF,0XFF,0XBE,0X38,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X31,0XCD,0X4A,0XDB,0X19,0X0B,0X10,0XC4,0X31,0XD0,
0X18,0XC7,0X00,0X00,0X00,0X00,0XE1,0X88,0X9C,0XA6,0X5C,0XEA,0X51,0XD0,0X53,0XC8,
0X3B,0XC2,0X11,0XC1,0X22,0X02,0X54,0X24,0X6C,0X67,0X51,0X13,0X50,0X95,0X50,0X58,
0X69,0X9B,0XA5,0XB6,0XD7,0X3C,0XC6,0X7D,0X8C,0XF5,0X74,0X33,0X4B,0X92,0X9A,0X8D,
0XFA,0X08,0XFA,0X4A,0XF2,0XCB,0XF9,0X89,0XD8,0X04,0XE9,0X47,0XFA,0X8B,0XF2,0X4B,
0XFA,0X8B,0XD0,0X04,0XD0,0X02,0XF1,0X48,0XFA,0X4A,0XE8,0X85,0XF9,0X47,0XC0,0XC5,
0X90,0X02,0XB0,0X03,0XA8,0X02,0X70,0X02,0X48,0X01,0X60,0X02,0X78,0X02,0X80,0X02,
0X58,0X02,0X70,0X02,0X80,0X02,0X50,0X01,0X20,0X00,0X70,0X01,0XE9,0X06,0X78,0X83,
0X90,0X84,0X78,0X43,0X48,0X02,0X68,0X02,0X98,0X04,0XA0,0X04,0X18,0X01,0X00,0X00,
0X00,0X00,0X09,0X02,0X3B,0X06,0X19,0X03,0X39,0X01,0X6A,0X41,0X82,0X81,0X93,0X01,
0X9B,0X01,0X92,0XC1,0X61,0XC0,0X41,0XC3,0X8C,0XB5,0XC6,0X3C,0XE7,0X7E,0XDF,0X3E,
0XFF,0XFF,0X63,0X4F,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X41,0X00,0X00,0X00,0X00,
0X00,0X00,0X08,0X42,0X31,0XD2,0X29,0XD4,0X10,0X8C,0X4B,0X5B,0X4A,0XDA,0X00,0X01,
0X08,0X83,0X00,0X00,0XE9,0X86,0XA3,0X88,0X39,0X90,0X38,0X13,0X49,0X4F,0X5C,0XA6,
0X44,0X22,0X1A,0X41,0X09,0X80,0X3B,0XC0,0X5A,0XCC,0X48,0X95,0X61,0X59,0X60,0X9C,
0X30,0X8F,0X32,0XC3,0X5B,0X4C,0X73,0X17,0X7B,0X17,0X32,0X50,0X9A,0X4A,0XFA,0X09,
0XF0,0X45,0XF1,0X88,0XF9,0X89,0XF0,0X86,0XD0,0X03,0XF2,0X09,0XFA,0X09,0XFA,0X8B,
0XD8,0XC5,0XC0,0X02,0XF0,0XC6,0XF9,0XC8,0XE0,0X84,0XF9,0X06,0XC0,0XC5,0X78,0X01,
0XA8,0X02,0X98,0X02,0X70,0X02,0X38,0X01,0X48,0X01,0X60,0X01,0X68,0X42,0X48,0X01,
0X50,0X01,0X50,0X01,0X20,0X00,0X78,0X01,0XF9,0X48,0XB1,0X05,0X68,0X02,0XA0,0X85,
0X68,0X42,0X48,0X01,0X70,0X03,0XB0,0X05,0XA0,0X44,0X08,0X00,0X00,0X00,0X08,0X00,
0X42,0X44,0X3A,0X45,0X00,0X00,0X00,0X00,0X00,0X01,0X08,0X01,0X08,0X00,0X08,0X00,
0X10,0XC2,0X01,0X02,0X00,0XC0,0X5B,0X4C,0XCE,0X7D,0XD6,0XBC,0XCE,0XBD,0XBD,0XFD,
0X8C,0XF5,0X11,0X01,0X00,0X00,0X19,0X42,0X3A,0X85,0X31,0X46,0X00,0X00,0X31,0XD1,
0X39,0X94,0X28,0XD2,0X31,0X93,0X18,0XCF,0X5C,0X3D,0X32,0X52,0X32,0X12,0X29,0X8B,
0X00,0X00,0X98,0X40,0XC2,0X0B,0X41,0X14,0X49,0X12,0X48,0X53,0X49,0X8E,0X54,0X66,
0X3B,0XC2,0X2A,0X44,0X29,0X48,0X2A,0X84,0X41,0X4E,0X50,0XD6,0X61,0X1A,0X50,0XD7,
0X08,0X83,0X28,0X8B,0X68,0X9C,0X48,0XD7,0X30,0X96,0X68,0X88,0XF1,0X45,0XF8,0X45,
0XE8,0X04,0XF0,0XC6,0XF0,0XC6,0XD8,0X04,0XD8,0XC5,0XF9,0XC9,0XF9,0XC9,0XE9,0X48,
0XB0,0X02,0XD8,0X85,0XF9,0X46,0XD0,0X44,0XF0,0X85,0XD8,0X84,0X60,0X01,0X80,0X43,
0X70,0X42,0X58,0XC4,0X20,0X82,0X30,0X41,0X38,0XC4,0X40,0X01,0X40,0X00,0X20,0X00,
0X20,0X00,0X90,0X83,0XFA,0X8B,0XF2,0X09,0X48,0X41,0X90,0X43,0X90,0X84,0X58,0X42,
0X48,0X01,0X98,0X04,0XC0,0X06,0X78,0X03,0X28,0X00,0X30,0X01,0X40,0X01,0X50,0X41,
0X50,0X01,0X50,0X02,0X20,0X01,0X00,0X00,0X00,0X00,0X00,0X81,0X11,0X83,0X11,0X42,
0X11,0X01,0X00,0X00,0X00,0X00,0X94,0XF6,0XCE,0XBE,0XA5,0X79,0XAD,0XBB,0X9D,0X36,
0X19,0X81,0X08,0XC0,0X22,0X03,0X53,0X05,0X49,0X84,0X28,0X87,0X42,0X5B,0X4B,0X1C,
0X39,0XD8,0X51,0XD7,0X3A,0X13,0X43,0X17,0X32,0X13,0X21,0X51,0X18,0XC9,0X18,0XC5,
0X78,0XC2,0X98,0X83,0X69,0X55,0X51,0X59,0X59,0X16,0X38,0X90,0X59,0X54,0X7A,0X18,
0X62,0XD1,0X6A,0X92,0X59,0X95,0X41,0X0F,0X30,0X8C,0X48,0XD4,0X40,0XD3,0X38,0X8F,
0X61,0X1C,0X59,0X1F,0X69,0X1C,0X60,0XCE,0X58,0X00,0X90,0X01,0XD8,0X85,0XD8,0X04,
0XE0,0X04,0XE0,0X85,0XE0,0X45,0XC8,0X03,0XE1,0X06,0XF9,0X87,0XF9,0X88,0XB0,0X03,
0XA8,0X03,0XE8,0XC5,0XC8,0X44,0XB8,0X43,0XC0,0X84,0X68,0X01,0X40,0XC4,0X40,0XC4,
0X38,0XC3,0X28,0X41,0X21,0X44,0X20,0XC3,0X30,0X82,0X10,0X82,0X20,0X00,0XD0,0XC5,
0XFA,0X0A,0XE2,0X8B,0X50,0X82,0X50,0X01,0XA0,0X84,0X78,0X43,0X48,0X01,0X70,0X03,
0XC0,0X46,0X98,0X04,0X40,0X01,0X38,0X01,0X40,0X01,0X40,0X01,0X40,0X00,0X50,0X01,
0X78,0X02,0X78,0X42,0X38,0X01,0X11,0X82,0X2B,0X05,0X19,0X42,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X21,0X04,0XCE,0XBE,0XAD,0XBA,0XDE,0XFF,0X7B,0XD2,0X00,0X00,
0X22,0X03,0X22,0X03,0X2A,0X02,0X62,0X00,0X38,0XCD,0X29,0X15,0X5C,0X7C,0X5C,0XBF,
0X39,0X95,0X29,0X0F,0X42,0X96,0X5B,0XD9,0X21,0X0D,0X3A,0X12,0X32,0X0C,0XD2,0X08,
0XA1,0X43,0X90,0XC9,0X69,0X59,0X61,0X59,0X49,0X13,0X69,0X1B,0X89,0X5F,0X81,0X9E,
0X62,0XCF,0X52,0X4F,0X48,0XD5,0X30,0X8D,0X20,0X89,0X30,0X8F,0X30,0X8F,0X38,0X9B,
0X99,0X56,0XEA,0X4C,0XD9,0X04,0X98,0X01,0X60,0X01,0X78,0X02,0XB0,0X43,0XC0,0X03,
0XD8,0X04,0XD0,0X44,0XC0,0X03,0XC8,0X44,0XF1,0X06,0XF9,0X07,0XC8,0X85,0X88,0X01,
0XC8,0X43,0XC0,0X43,0X98,0X43,0XA0,0XC4,0X38,0X42,0X20,0XC4,0X31,0XC6,0X31,0X03,
0X20,0XC4,0X21,0X45,0X10,0X82,0X01,0X03,0X00,0X82,0X70,0X01,0XB0,0X84,0X78,0X83,
0X48,0X01,0X38,0X00,0X80,0X43,0X90,0X44,0X58,0X02,0X48,0X02,0XB0,0X45,0XA8,0X05,
0X50,0X01,0X30,0X00,0X40,0X01,0X48,0X01,0X58,0X01,0X68,0X02,0X80,0X42,0X90,0X43,
0XB0,0X84,0XD8,0XC5,0XCA,0X47,0X18,0XC1,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X52,0X4C,0XE7,0X3F,0XAD,0X7A,0X10,0X43,0X00,0X00,0X21,0XC3,
0X42,0XC4,0X42,0X83,0X5A,0X87,0X18,0X48,0X10,0X0A,0X4B,0X17,0X64,0XFF,0X42,0XD7,
0X08,0X06,0X3A,0X12,0X64,0X7B,0X6C,0XBB,0X64,0X38,0X32,0X54,0X69,0X14,0X59,0X0F,
0X58,0XCA,0X69,0X0E,0X51,0X14,0X49,0X13,0X79,0X5D,0X81,0X9F,0X79,0X5F,0X79,0X1F,
0X59,0X96,0X51,0XD3,0X59,0X18,0X30,0X8E,0X28,0X8B,0X10,0X50,0X78,0XCF,0XFB,0X0B,
0XFB,0X4A,0XFA,0X09,0XF9,0X08,0XD0,0X44,0X78,0X02,0X70,0X01,0X90,0X02,0XA8,0X03,
0XC8,0X04,0XC0,0X44,0XA8,0X03,0XC0,0X84,0XE8,0XC5,0XE0,0X85,0X88,0X02,0X70,0X83,
0X78,0X83,0X60,0X83,0X60,0X85,0X49,0X46,0X63,0X45,0X8C,0XA8,0X5A,0XC7,0X21,0X04,
0X11,0X03,0X00,0XC2,0X50,0X01,0XD0,0X44,0XE1,0X46,0X30,0X01,0X38,0X00,0X60,0X02,
0X70,0X42,0X78,0X43,0X68,0X02,0X40,0X01,0X88,0X43,0XA8,0X44,0X50,0X01,0X30,0X00,
0X48,0X01,0X58,0X01,0X60,0X01,0X60,0X02,0X70,0X02,0X80,0X42,0X98,0X43,0XB8,0X84,
0XE1,0X05,0XF9,0X48,0XB9,0X47,0X20,0X82,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X08,0X41,0X00,0X40,0X52,0XCA,0X29,0X45,0X00,0X00,0X10,0X81,0X10,0XC3,0X18,0XC3,
0X18,0X00,0X29,0XD5,0X4B,0X59,0X29,0X4C,0X29,0XD2,0X3A,0X55,0X42,0X95,0X32,0X12,
0X43,0X57,0X42,0X54,0X4B,0X16,0X31,0X8D,0X08,0X48,0X49,0X17,0X59,0X5A,0X59,0X5B,
0X51,0X55,0X40,0XCF,0X38,0XCD,0X49,0X12,0X71,0X5D,0X71,0X5E,0X71,0X5E,0X71,0X1F,
0X59,0X19,0X49,0X15,0X48,0XD7,0X28,0X91,0X20,0X0E,0XDA,0X4B,0XFC,0X6D,0XFA,0XCC,
0XF2,0X09,0XF9,0XC9,0XF9,0X08,0XE0,0X44,0X88,0X02,0X70,0X02,0X80,0X02,0X90,0X02,
0XB0,0X03,0XA0,0X03,0X98,0X02,0XB8,0X43,0XE8,0X44,0XA8,0X43,0X28,0XC3,0X48,0XC4,
0X38,0X84,0X49,0XC5,0X6B,0X84,0XC6,0X67,0X94,0XE9,0X32,0X46,0X3B,0X88,0X01,0X44,
0X68,0X02,0XF9,0X48,0XFA,0X0A,0X68,0XC3,0X38,0X01,0X90,0X43,0X80,0X02,0X70,0X42,
0X68,0X42,0X48,0X01,0X58,0X42,0X98,0X43,0X48,0X01,0X20,0X00,0X40,0X01,0X50,0X01,
0X50,0X01,0X50,0X01,0X58,0X01,0X70,0X02,0X80,0X02,0X98,0X43,0XA8,0X43,0XC8,0X84,
0XD8,0XC5,0XF9,0XC9,0XE9,0XC9,0X10,0XC2,0X19,0X83,0X3A,0X44,0X4B,0X46,0X5C,0X27,
0X64,0X67,0X54,0X24,0X64,0XA6,0X75,0X29,0X6C,0XE8,0X64,0X68,0X53,0X47,0X39,0XC3,
0X42,0XD2,0X5C,0XBF,0X21,0X95,0X00,0X08,0X08,0X8A,0X42,0XD6,0X6D,0X7F,0X5C,0XFE,
0X63,0XD9,0X29,0X4B,0X00,0X01,0X08,0X04,0X59,0X15,0X79,0X9D,0X71,0X9C,0X69,0X5A,
0X61,0X58,0X40,0XD0,0X28,0X89,0X38,0X8E,0X48,0XD5,0X51,0X17,0X51,0X18,0X50,0XD9,
0X38,0X93,0X30,0X91,0X20,0X57,0X60,0X92,0XFA,0X89,0XFA,0XCB,0XFB,0X0B,0XF1,0XC9,
0XF1,0X47,0XF9,0X48,0XF9,0X07,0XE0,0X44,0X88,0X02,0X70,0X02,0X78,0X02,0X80,0X02,
0X98,0X03,0X78,0X02,0X88,0X42,0XC0,0X02,0XB0,0X42,0X29,0X05,0X28,0X83,0X83,0X46,
0X9D,0X25,0X74,0X24,0X84,0X69,0X52,0XC8,0X22,0X87,0X1A,0X87,0X91,0X45,0XF9,0X06,
0XF1,0X88,0X50,0X83,0X00,0X00,0X50,0X02,0X90,0X43,0X68,0X02,0X60,0X02,0X50,0X02,
0X40,0X01,0X78,0X41,0X48,0X01,0X18,0X00,0X38,0X01,0X38,0X01,0X38,0X00,0X48,0X01,
0X68,0X02,0X78,0X02,0X88,0X02,0X98,0X03,0XA8,0X43,0XC8,0X44,0XB0,0X43,0X60,0X02,
0X68,0X01,0XB8,0X03,0X79,0XC5,0X33,0X46,0X4B,0X46,0X4B,0X86,0X53,0XC6,0X5C,0X26,
0X64,0XA7,0X6D,0X28,0X7D,0XA9,0X8E,0X2A,0X96,0XAB,0X96,0XAA,0X8E,0X29,0X7D,0XA9,
0X6C,0XED,0X3A,0X89,0X10,0XC5,0X08,0X8D,0X29,0XD5,0X4B,0X58,0X4B,0X57,0X6C,0X7A,
0X4B,0X13,0X42,0X12,0X3A,0X14,0X49,0X11,0X51,0X14,0X59,0X56,0X59,0X55,0X49,0X12,
0X30,0XCB,0X30,0X8B,0X28,0X8A,0X20,0X4A,0X20,0X49,0X20,0X49,0X30,0X8E,0X30,0X90,
0X20,0X4B,0X00,0X0C,0X91,0X4E,0XFA,0X89,0XF9,0X07,0XF9,0XC8,0XFA,0X09,0XF1,0X06,
0XE0,0X85,0XF0,0XC6,0XF8,0X87,0XE0,0X44,0X78,0X02,0X68,0X02,0X70,0X02,0X68,0X01,
0X68,0X02,0X58,0X01,0X78,0X42,0X78,0XC4,0X40,0X83,0X4A,0X47,0X95,0X29,0XC6,0X69,
0X74,0X28,0X29,0XC7,0X09,0X85,0X09,0XC4,0XB1,0X87,0XFA,0X0A,0XC1,0X06,0X48,0X01,
0X38,0X01,0X38,0X01,0X48,0X02,0X70,0X02,0X58,0X02,0X48,0X01,0X30,0X01,0X50,0X01,
0X50,0X01,0X18,0X00,0X28,0X00,0X30,0X00,0X38,0X01,0X48,0X01,0X60,0X01,0X70,0X02,
0X78,0X02,0X88,0X02,0X90,0X03,0XB8,0X03,0X98,0X43,0X31,0X43,0X11,0X84,0X11,0X43,
0X20,0XC2,0X60,0XC3,0X31,0X84,0X21,0XC4,0X2A,0X04,0X2A,0X44,0X32,0X84,0X32,0XC4,
0X3B,0X05,0X43,0X85,0X54,0X26,0X64,0XA7,0X6D,0X28,0X7D,0XA9,0X85,0XE9,0X8E,0X27,
0X8E,0X27,0X7D,0XA9,0X5C,0X2A,0X43,0X11,0X3A,0XD8,0X21,0X10,0X3A,0X11,0X4B,0X15,
0X4B,0X11,0X21,0X48,0X49,0X11,0X49,0X12,0X51,0X13,0X40,0XCF,0X40,0XCF,0X49,0X12,
0X51,0X14,0X48,0XD2,0X38,0XD0,0X38,0X8F,0X30,0X8D,0X30,0X8C,0X20,0X49,0X18,0X49,
0X00,0X06,0XA9,0XC9,0XFA,0X49,0XE8,0X85,0XE8,0X04,0XF8,0X86,0XF9,0X07,0XE8,0XC6,
0XC8,0X04,0XC8,0X44,0XF8,0X45,0XE0,0X44,0X70,0X01,0X48,0X01,0X58,0X02,0X48,0X01,
0X40,0X01,0X38,0X41,0X50,0XC4,0X70,0X41,0X6A,0XC8,0X3A,0XC8,0X42,0X86,0X4B,0X49,
0X4B,0XCA,0X1B,0X07,0X70,0XC3,0XF9,0X06,0XFA,0X09,0X28,0X41,0X10,0X00,0X60,0X02,
0X50,0X02,0X38,0X01,0X50,0X01,0X40,0X01,0X30,0X01,0X30,0X01,0X40,0X01,0X20,0X00,
0X20,0X00,0X28,0X00,0X38,0X01,0X40,0X01,0X48,0X01,0X58,0X01,0X68,0X02,0X78,0X02,
0X88,0X02,0XB8,0X03,0XA8,0X03,0X19,0X43,0X09,0XC3,0X19,0X83,0X19,0X83,0X11,0XC4,
0X21,0XC4,0X29,0XC4,0X29,0XC4,0X2A,0X04,0X32,0X44,0X32,0X84,0X32,0X84,0X32,0XC4,
0X32,0XC4,0X33,0X04,0X3B,0X44,0X43,0X85,0X4C,0X26,0X54,0X67,0X6C,0XE8,0X75,0X69,
0X85,0XE9,0X8E,0X27,0X7D,0X66,0X6D,0X2F,0X3B,0X14,0X21,0X53,0X64,0X3A,0X53,0X53,
0X00,0X00,0X51,0X14,0X49,0X12,0X38,0XCE,0X30,0X8C,0X69,0X59,0X59,0X16,0X48,0XD2,
0X49,0X13,0X49,0X12,0X50,0XD7,0X59,0X19,0X40,0XD2,0X30,0X8D,0X20,0X8B,0X08,0X07,
0XC2,0X09,0XFA,0X09,0XE8,0X44,0XE0,0X04,0XE0,0X04,0XE0,0X04,0XE0,0X85,0XE0,0X44,
0XC8,0X04,0XC0,0X03,0XD8,0X44,0XC8,0X43,0X78,0X02,0X40,0X01,0X48,0X01,0X38,0X82,
0X18,0XC2,0X20,0X41,0X40,0XC3,0X42,0X45,0X22,0X05,0X2A,0X06,0X1A,0X07,0X01,0XC4,
0X88,0XC4,0XE0,0X03,0XC0,0X44,0X70,0X42,0X18,0X00,0X38,0X01,0X40,0X01,0X50,0X01,
0X30,0X01,0X30,0X01,0X38,0X01,0X28,0X01,0X30,0X01,0X30,0X00,0X20,0X00,0X30,0X00,
0X40,0X01,0X48,0X01,0X58,0X01,0X68,0X02,0X78,0X02,0X88,0X02,0X90,0X02,0XB8,0X03,
0XB8,0X44,0X39,0X03,0X01,0X83,0X19,0X02,0X10,0XC2,0X10,0XC2,0X10,0XC2,0X11,0X02,
0X19,0X02,0X19,0X42,0X19,0X43,0X21,0X83,0X29,0XC4,0X2A,0X44,0X32,0XC4,0X3B,0X05,
0X43,0X85,0X43,0X84,0X3B,0X43,0X3B,0X44,0X3B,0X44,0X3B,0X45,0X43,0XC5,0X5C,0X67,
0X6C,0XA8,0X7D,0X68,0X85,0XA5,0X6C,0XE7,0X53,0XD0,0X4B,0X58,0X64,0X7B,0X29,0X8A,
0X51,0X13,0X30,0XCD,0X20,0X88,0X38,0XCE,0X61,0X57,0X51,0X13,0X61,0X17,0X61,0X19,
0X48,0XD3,0X30,0X8E,0X48,0XD4,0X50,0XD9,0X48,0XD6,0X40,0XD3,0X10,0X8A,0XC1,0X46,
0XF8,0XC6,0XD8,0X04,0XD0,0X04,0XC8,0X04,0XC8,0X04,0XC8,0X04,0XD0,0X04,0XD8,0X44,
0XD0,0X04,0XB8,0X03,0XC0,0X03,0XB8,0X03,0X78,0X02,0X50,0X01,0X40,0X01,0X29,0X45,
0X11,0X04,0X08,0X83,0X21,0X43,0X32,0X85,0X1A,0X04,0X00,0XC2,0X91,0XC7,0XF9,0X89,
0XA8,0X03,0X10,0X00,0X18,0X00,0X40,0X01,0X48,0X01,0X38,0X01,0X38,0X01,0X30,0X01,
0X20,0X01,0X28,0X01,0X20,0X01,0X30,0X00,0X30,0X00,0X30,0X00,0X30,0X01,0X30,0X01,
0X38,0X01,0X38,0X01,0X48,0X01,0X68,0X02,0X90,0X02,0XA8,0X03,0XA0,0X03,0X20,0X41,
0X00,0X40,0X08,0X41,0X08,0X41,0X08,0X41,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X41,0X10,0X81,0X19,0X02,0X21,0X83,
0X32,0XC7,0X43,0X88,0X43,0XC5,0X43,0XC3,0X43,0X83,0X3B,0X44,0X33,0X04,0X3B,0X05,
0X4B,0X86,0X6C,0XA7,0X85,0XA7,0X8D,0XE7,0X53,0X48,0X08,0X86,0X19,0X07,0X30,0XCB,
0X28,0X89,0X20,0X48,0X38,0X8E,0X71,0X9A,0X79,0X9F,0X79,0X9E,0X69,0X5C,0X59,0X18,
0X30,0X8D,0X18,0X48,0X38,0X92,0X50,0XDB,0X40,0XD5,0X10,0X8C,0X50,0X45,0XA8,0X02,
0XB0,0X03,0XA8,0X43,0XA8,0X03,0XA8,0X03,0XB0,0X03,0XB0,0X03,0XB0,0X03,0XC0,0X03,
0XC8,0X03,0XB8,0X03,0XA8,0X02,0XA0,0X02,0X70,0X01,0X48,0X01,0X30,0XC4,0X21,0X04,
0X10,0X82,0X08,0X82,0X09,0X42,0X01,0X83,0X68,0XC3,0XFA,0X0A,0XFA,0X8B,0X58,0X42,
0X08,0X00,0X38,0X01,0X38,0X01,0X40,0X01,0X38,0X01,0X30,0X01,0X28,0X01,0X18,0X00,
0X10,0X00,0X18,0X00,0X20,0X00,0X10,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X08,0XC1,0X19,0X02,0X30,0X41,0X48,0X01,0X20,0X01,0X00,0X81,0X29,0XC3,
0X3A,0XC5,0X43,0X45,0X43,0X45,0X3B,0X05,0X32,0X84,0X29,0XC3,0X19,0X02,0X00,0X40,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X18,0XCA,
0X63,0XDA,0X5C,0X33,0X3A,0X89,0X3A,0XC6,0X3B,0X43,0X3B,0X42,0X3B,0X44,0X32,0XC4,
0X3B,0X05,0X53,0XC6,0X75,0X27,0X8D,0XE7,0X42,0X83,0X00,0X00,0X38,0XCC,0X38,0X8F,
0X20,0X4A,0X59,0X54,0X89,0X9F,0X81,0X9F,0X79,0X5E,0X69,0X5D,0X48,0XD6,0X28,0X8C,
0X10,0X45,0X10,0X45,0X28,0X8E,0X30,0X8F,0X18,0X8C,0X40,0X46,0X88,0X01,0X70,0X02,
0X78,0X02,0X78,0X02,0X78,0X01,0X68,0X01,0X68,0X01,0X68,0X01,0X70,0X02,0X70,0X02,
0X70,0X01,0X68,0X01,0X60,0X01,0X50,0X00,0X30,0XC3,0X19,0X03,0X20,0X41,0X08,0XC2,
0X10,0XC3,0X18,0X41,0X80,0X83,0XF9,0X48,0XD1,0X07,0X78,0XC4,0X20,0X00,0X30,0X01,
0X38,0X01,0X38,0X01,0X38,0X01,0X30,0X01,0X20,0X01,0X18,0X00,0X10,0X00,0X18,0X00,
0X20,0X00,0X20,0X00,0X20,0X01,0X30,0X01,0X30,0X01,0X10,0X00,0X00,0X40,0X01,0X01,
0X19,0X42,0X08,0XC1,0X00,0X00,0X00,0X00,0X01,0X01,0X3B,0X04,0X54,0X26,0X54,0X26,
0X53,0XC6,0X53,0XC7,0X43,0X85,0X3B,0X04,0X43,0X05,0X42,0XC7,0X3A,0XC5,0X22,0X03,
0X08,0X41,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X42,0X19,0X07,
0X10,0X46,0X20,0XCF,0X42,0X14,0X5C,0X37,0X43,0X0D,0X32,0XC4,0X3B,0X84,0X3B,0X05,
0X32,0X84,0X43,0X05,0X6C,0XA7,0X96,0X6A,0X42,0XC5,0X48,0XD4,0X40,0X52,0XAD,0X39,
0X7A,0XD6,0X38,0X12,0X79,0X9E,0X79,0X9F,0X69,0X1C,0X48,0XD3,0X10,0X46,0X10,0X46,
0X20,0X4A,0X18,0X48,0X20,0X4A,0X00,0X02,0X70,0X00,0XC8,0X03,0X98,0X02,0X90,0X02,
0X90,0X02,0X90,0X02,0X88,0X02,0X88,0X02,0X80,0X02,0X78,0X01,0X68,0X01,0X50,0X01,
0X48,0X01,0X38,0X01,0X30,0X00,0X28,0X82,0X18,0X82,0X08,0X81,0X60,0X42,0X70,0X43,
0X88,0X42,0XC0,0X03,0X88,0X84,0X28,0X00,0X10,0X00,0X30,0X01,0X30,0X01,0X38,0X01,
0X30,0X01,0X28,0X01,0X18,0X00,0X10,0X00,0X18,0X00,0X28,0X00,0X38,0X00,0X40,0X01,
0X48,0X01,0X48,0X01,0X50,0X01,0X68,0X01,0X78,0X02,0X58,0X42,0X21,0X01,0X00,0X80,
0X00,0X00,0X00,0X00,0X11,0X02,0X32,0X84,0X43,0X45,0X4B,0X86,0X4B,0X86,0X43,0X46,
0X43,0X46,0X4B,0X87,0X4B,0X87,0X3B,0X43,0X32,0X44,0X3A,0X48,0X4B,0X48,0X3B,0X05,
0X08,0X41,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X83,
0X21,0X08,0X3A,0X50,0X5B,0XDB,0X18,0X8B,0X42,0XD5,0X3A,0XCB,0X32,0X82,0X43,0X46,
0X32,0X84,0X32,0X84,0X64,0XA7,0X8E,0X29,
};

unsigned char code pic4[]=
{/* 0X10,0X10,0X00,0X5F,0X00,0X1C,0X01,0X1B, */
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X18,0X41,
0XFD,0XA1,0XFE,0XE0,0XE4,0XA1,0XF4,0XA0,0XFD,0X20,0XFC,0XA0,0X92,0X01,0X5A,0X01,
0XF5,0XE0,0XFD,0X60,0XF4,0XA0,0XFD,0X20,0XFD,0X20,0XEB,0XC0,0XCB,0X40,0XDB,0XC0,
0XEC,0X60,0XEC,0X60,0XF4,0XA0,0XEC,0X60,0XD3,0X80,0XE4,0X20,0XDB,0X80,0XDB,0X40,
0XD3,0X00,0XE3,0XC0,0XFC,0X60,0XFD,0X20,0XFD,0X60,0XFD,0X60,0XE3,0X40,0XF4,0XE0,
0X19,0X00,0X08,0X00,0XD3,0X40,0XB2,0XC0,0XCB,0X40,0XEC,0X20,0XF4,0X60,0XF4,0XE0,
0XFC,0XE0,0XFD,0X60,0XE5,0X20,0XE5,0X20,0XFD,0XE0,0XFD,0XA0,0XFD,0X60,0XDC,0X20,
0XDC,0XA1,0X31,0X41,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X72,0X81,0XDD,0XA1,0XED,0X20,
0XFD,0XE0,0XFE,0X20,0XFC,0XE0,0XF4,0XE0,0XEC,0XA0,0XFC,0XA0,0XF3,0XC0,0XF4,0XA0,
0XFD,0X60,0XF4,0XE0,0XF4,0XA0,0XFD,0X60,0XF4,0X60,0XD3,0X00,0XDB,0XC0,0XE3,0XC0,
0XE4,0X20,0XEC,0X60,0XEC,0X60,0XD3,0X40,0XDB,0XC0,0XDB,0X80,0XD3,0X00,0XCA,0XC0,
0XE3,0X80,0XFC,0XA0,0XFD,0X20,0XFD,0X60,0XFC,0XA0,0XEB,0X80,0XCC,0X20,0X00,0X41,
0X8A,0X01,0XCA,0XC0,0XBB,0X00,0XE4,0X20,0XF4,0X60,0XFC,0XE0,0XFC,0XE0,0XFC,0XE0,
0XF5,0X20,0XE4,0XA0,0XFC,0XE0,0XFD,0X20,0XF5,0X60,0XD3,0XC0,0XFD,0X60,0XAC,0X21,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X9B,0X41,0XFF,0XE0,0XFD,0XA0,0XFC,0XA0,
0XFD,0XA0,0XFD,0X60,0XF4,0X60,0XF4,0XE0,0XE4,0X60,0XEB,0XC0,0XFC,0X60,0XFC,0XE0,
0XFC,0XE0,0XEC,0XA0,0XFC,0XE0,0XFC,0XE0,0XDB,0X40,0XCB,0X40,0XDB,0XC0,0XDB,0XC0,
0XE4,0X20,0XEC,0X60,0XCB,0X40,0XD3,0XC0,0XDB,0X80,0XC2,0X80,0XCA,0X80,0XE3,0X40,
0XFC,0XA0,0XFD,0X20,0XFD,0X20,0XEB,0XC0,0XFC,0X20,0X83,0X01,0X38,0X81,0XD3,0X00,
0XB2,0X80,0XDB,0XC0,0XF4,0X60,0XFC,0XA0,0XFD,0X20,0XFC,0XA0,0XF4,0XE0,0XEC,0XE0,
0XFC,0XE0,0XFC,0XE0,0XFD,0X60,0XDC,0X20,0XF4,0X60,0XD4,0XA1,0X18,0X81,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X41,0XC1,
0X73,0X01,0X41,0X41,0X08,0X41,0XAB,0X81,0XFF,0XA0,0XFE,0X20,0XFC,0XA0,0XFC,0XA0,
0XFD,0X60,0XF4,0XE0,0XF4,0X20,0XF4,0XA0,0XE4,0X60,0XE3,0X40,0XF4,0X20,0XFC,0XA0,
0XF4,0XA0,0XEC,0X60,0XFC,0XE0,0XE3,0XC0,0XC2,0X80,0XDB,0XC0,0XDB,0X80,0XDB,0X80,
0XEC,0X60,0XD3,0X40,0XD3,0X80,0XD3,0X40,0XC2,0X80,0XCA,0XC0,0XE3,0X80,0XFC,0X60,
0XFC,0XE0,0XFC,0XE0,0XE3,0X80,0XEC,0X20,0X51,0XC1,0X81,0X80,0XC2,0X80,0XCB,0X40,
0XF4,0X60,0XFC,0XA0,0XFD,0X20,0XFC,0XA0,0XFC,0XA0,0XF5,0X20,0XFC,0XE0,0XFC,0XE0,
0XFD,0XA0,0XFD,0X60,0XEC,0X20,0XFD,0X61,0X29,0X41,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X39,0XC1,0XFF,0XE1,
0XFE,0X20,0XE4,0XE1,0XE4,0XE1,0XFE,0X20,0XFE,0XA0,0XFD,0XA0,0XFC,0XA0,0XFC,0XA0,
0XFD,0X60,0XEC,0X60,0XEB,0XC0,0XEC,0XA0,0XDB,0X40,0XE3,0X80,0XF4,0X20,0XF4,0XA0,
0XEC,0X60,0XEC,0X60,0XEC,0XA0,0XC2,0X40,0XCA,0XC0,0XD3,0XC0,0XD3,0X40,0XE4,0X20,
0XDB,0X80,0XCB,0X40,0XD3,0X40,0XBA,0X40,0XCA,0XC0,0XE3,0X80,0XFC,0XA0,0XFC,0XE0,
0XF4,0XA0,0XEB,0X80,0XB3,0X41,0X59,0X41,0XBA,0X40,0XBA,0XC0,0XE4,0X20,0XFC,0XA0,
0XFD,0X20,0XFC,0XE0,0XF4,0X60,0XFC,0XE0,0XFD,0X20,0XFC,0XE0,0XFC,0XA0,0XFC,0XE0,
0XFC,0XE0,0XFE,0X60,0X8A,0XC1,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X31,0X41,0X18,0X81,0X93,0X82,0XFE,0XA0,
0XFE,0X20,0XFD,0XE0,0XFD,0X60,0XFD,0XA0,0XFD,0XE0,0XFD,0X60,0XFC,0X60,0XFC,0XA0,
0XFD,0X60,0XE3,0XC0,0XE3,0XC0,0XEC,0X60,0XDB,0X40,0XDB,0X40,0XEB,0XC0,0XEC,0X60,
0XDC,0X20,0XEC,0XA0,0XCB,0X00,0XB1,0XC0,0XD3,0XC0,0XCB,0X40,0XD3,0X80,0XDB,0XC0,
0XCB,0X00,0XCB,0X40,0XB2,0X40,0XC2,0XC1,0XEB,0XC0,0XFC,0XA0,0XFC,0XE0,0XEB,0XC0,
0XE3,0X40,0X82,0X41,0X81,0X80,0XBA,0X80,0XD3,0X80,0XFC,0X60,0XFD,0X20,0XFC,0XE0,
0XF4,0X60,0XFC,0XE0,0XFC,0XE0,0XFC,0XE0,0XFC,0X60,0XFC,0X20,0XFB,0XC0,0XFD,0X60,
0XB4,0X61,0X00,0X01,0X08,0X40,0X20,0XC1,0X20,0XC1,0X10,0X81,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X41,0XCC,0XE1,0XFE,0X20,0XFD,0X60,0XDC,0XA1,0XF5,0X60,0XFD,0XA0,
0XFD,0XA0,0XFE,0X20,0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,0XFD,0X20,0XFC,0X60,0XFC,0XE0,
0XF4,0XE0,0XDB,0X80,0XE3,0XC0,0XE3,0XC0,0XDB,0X00,0XDB,0X40,0XE4,0X20,0XDC,0X20,
0XDC,0X20,0XDC,0X20,0XB1,0X80,0XC2,0X80,0XD3,0X80,0XCB,0X00,0XDC,0X20,0XCB,0X00,
0XC2,0XC0,0XB2,0X40,0XC2,0XC1,0XEC,0X20,0XFC,0X60,0XFC,0XE0,0XE3,0X40,0XB2,0X40,
0X69,0X81,0XB2,0X40,0XBA,0XC0,0XEC,0X20,0XFC,0XA0,0XFD,0X20,0XF4,0XA0,0XFC,0XA0,
0XFC,0XE0,0XFC,0XA0,0XFC,0X20,0XFC,0X60,0XFC,0X60,0XFC,0X60,0XF5,0X60,0X92,0XC1,
0X92,0X81,0XCB,0XC1,0XDC,0XA1,0XDC,0XE1,0XCC,0XA1,0XBC,0X21,0XAB,0X81,0X49,0X81,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X83,0X41,0XFE,0X20,0XFD,0XA0,0XFE,0X60,0XFD,0XE0,0XFD,0X20,0XFD,0X20,
0XFD,0X60,0XFD,0XE0,0XFD,0XE0,0XFD,0XA0,0XFD,0X60,0XFC,0XE0,0XF4,0X20,0XFC,0XE0,
0XEC,0XA0,0XDB,0X40,0XDC,0X20,0XDB,0X80,0XD2,0XC0,0XDB,0X80,0XDC,0X20,0XD3,0XC0,
0XDC,0X20,0XBA,0X80,0XA9,0X41,0XCB,0X80,0XB2,0X00,0XCA,0XC0,0XCB,0X40,0XBA,0XC0,
0XA9,0XC0,0XBA,0X00,0XEB,0XC0,0XF4,0X20,0XF4,0X60,0XE2,0XC0,0X69,0X40,0X69,0X80,
0XDB,0X40,0XC3,0X00,0XF4,0X60,0XFD,0X20,0XFC,0XE0,0XF4,0X60,0XFC,0XA0,0XFC,0X60,
0XFC,0X20,0XFC,0XE0,0XFD,0X20,0XF4,0X20,0XFC,0XE0,0XEC,0XA0,0XEB,0X80,0XF4,0X60,
0XDB,0XC0,0XCB,0X80,0XCB,0X80,0XC3,0X40,0XA2,0X81,0X7A,0X01,0X30,0XC1,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X10,0X40,
0X21,0X01,0XCC,0XE1,0XFD,0XE0,0XFD,0X60,0XFE,0X60,0XFE,0X20,0XFC,0XE0,0XFD,0X60,
0XFD,0X20,0XFD,0XA0,0XFD,0XE0,0XFD,0XA0,0XFD,0X20,0XFC,0XA0,0XF4,0X20,0XF4,0XE0,
0XE4,0X60,0XD3,0X40,0XDC,0X20,0XD3,0X00,0XCB,0X00,0XDC,0X20,0XD3,0XC0,0XD3,0XC0,
0XCB,0X80,0X99,0X00,0XB2,0X40,0XD4,0X21,0XC2,0XC0,0XE4,0XA0,0XF5,0XA1,0XDC,0XA1,
0XCB,0X81,0XDB,0X80,0XE3,0XC0,0XCA,0X40,0XA9,0X40,0X30,0X81,0X92,0X00,0XD3,0X00,
0XD3,0X40,0XFC,0XA0,0XFD,0X20,0XF4,0XA0,0XEC,0X20,0XFC,0X60,0XFC,0X20,0XFD,0X60,
0XFD,0X60,0XF3,0XC0,0XFC,0X60,0XFD,0X60,0XDB,0X80,0XCB,0X00,0XC3,0X40,0XC3,0X40,
0XCB,0XC0,0XD4,0X60,0XD4,0X61,0XA3,0X41,0X82,0XC1,0X49,0XC0,0X28,0XC0,0X10,0X40,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0XD4,0XA2,
0XFC,0XE0,0XFD,0X20,0XFD,0XA0,0XFD,0XE0,0XFE,0X60,0XFD,0XA0,0XFC,0XE0,0XFD,0X60,
0XFD,0X20,0XFD,0X60,0XFD,0XA0,0XFD,0XA0,0XFC,0XE0,0XF4,0X20,0XEC,0X20,0XF5,0X20,
0XDB,0XC0,0XCB,0X00,0XD3,0XC0,0XC2,0X40,0XCB,0X00,0XD3,0X80,0XBA,0XC0,0XCB,0X80,
0XCB,0XC1,0XDC,0XA1,0XFE,0XA1,0XCC,0X61,0XCC,0X21,0XFE,0XA0,0XF6,0X20,0XCC,0X61,
0XE5,0X61,0XE4,0XE0,0XBA,0X41,0X71,0X41,0X18,0X41,0XBA,0X80,0XC2,0X80,0XDB,0X80,
0XFC,0XE0,0XFC,0XA0,0XE3,0X41,0XF3,0XC0,0XFC,0X20,0XFD,0X60,0XFD,0X60,0XF3,0X80,
0XFC,0X60,0XFD,0X60,0XDB,0X40,0XCA,0X80,0XCB,0X00,0XDB,0X80,0XEC,0X60,0XF5,0X20,
0XEC,0XE0,0XE4,0XE0,0XFD,0XA0,0XFE,0XE0,0XFF,0X20,0XED,0XA1,0X72,0XC1,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X49,0X81,0X92,0XC1,0XD4,0X21,0XFD,0X60,
0XFC,0XE0,0XFC,0XE0,0XFD,0X20,0XFD,0XA0,0XFE,0X60,0XFD,0X60,0XFC,0XA0,0XFD,0X20,
0XFD,0X20,0XFC,0XE0,0XFD,0X60,0XFD,0X60,0XF4,0XA0,0XDB,0X80,0XE4,0X20,0XF5,0X20,
0XD3,0X40,0XCB,0X00,0XCB,0X00,0XC2,0XC1,0XCB,0X80,0XCB,0XC0,0XD4,0XA1,0XED,0XE1,
0XED,0XE0,0XDD,0X60,0XBC,0X21,0XD5,0X21,0XDD,0X61,0XC4,0XA1,0XB3,0XC1,0XC4,0X60,
0XCC,0XE1,0XDD,0X21,0XCC,0XA0,0XAB,0X41,0X91,0X40,0XAA,0X00,0XDC,0X20,0XF4,0X60,
0XD2,0XC0,0XEB,0X80,0XFC,0X60,0XFD,0X20,0XFD,0X60,0XF3,0X80,0XFC,0X60,0XFD,0X20,
0XDB,0X00,0XD2,0XC0,0XE4,0X61,0XF5,0X60,0XFD,0XA0,0XFD,0XA0,0XF5,0X20,0XC4,0X20,
0XA3,0XC0,0X93,0XC0,0X73,0X00,0X5A,0X40,0X31,0X40,0X10,0X80,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X20,0XC1,0XFD,0X61,0XFE,0X20,0XFD,0X60,0XFD,0X60,0XFD,0XA0,
0XFD,0XA0,0XFD,0X60,0XFD,0X60,0XFD,0XA0,0XFE,0X20,0XFD,0XA0,0XFC,0XA0,0XFC,0XE0,
0XFD,0X60,0XFC,0XE0,0XFD,0X20,0XFD,0X20,0XEC,0X60,0XCB,0X00,0XDC,0X20,0XEC,0XA0,
0XBA,0X80,0XD4,0X21,0XE5,0X61,0XDD,0X21,0XDD,0X61,0XDD,0XA0,0XB3,0XC0,0XA3,0X01,
0XB3,0X41,0XCC,0X61,0XB3,0X41,0XAB,0X01,0X8A,0X01,0XB4,0X21,0X9B,0X01,0XAB,0X81,
0XED,0XA0,0XBB,0XC0,0XAA,0X41,0X70,0X81,0X89,0X00,0XC2,0XC0,0XA9,0X80,0XCA,0X80,
0XFC,0XA0,0XFC,0XE0,0XFD,0X20,0XF3,0XC0,0XFC,0X60,0XF4,0XA0,0XE3,0X40,0XEB,0XC0,
0XFD,0XE0,0XFE,0X60,0XFE,0X60,0XFD,0XA0,0XD4,0XE1,0XDC,0XE1,0XC4,0X61,0X7A,0XC1,
0X39,0X01,0X10,0X41,0X00,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X82,0XC2,0XFD,0XE1,0XFD,0X20,0XFD,0X60,0XFD,0X60,0XFD,0XA0,0XFD,0XE0,
0XFE,0X60,0XFD,0XE0,0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,0XFC,0XA0,0XFC,0X60,
0XFD,0X20,0XFD,0X20,0XFC,0XE0,0XFD,0X20,0XE3,0XC0,0XBA,0XC0,0XD4,0X20,0XD4,0X21,
0XED,0X61,0XED,0XE0,0XC4,0X60,0XB3,0XC1,0XB3,0XC1,0XB4,0X21,0X82,0X01,0X40,0XC1,
0X79,0XC1,0X38,0X40,0X51,0X41,0X82,0X01,0XB3,0XC1,0XC4,0XA2,0XC4,0XA1,0XBC,0X60,
0XCC,0X61,0XAA,0XC1,0XAB,0X01,0X89,0X81,0X58,0X00,0X80,0X80,0XDB,0XC0,0XFC,0XE0,
0XFC,0XE0,0XEB,0XC0,0XFC,0X20,0XF4,0X20,0XEC,0X20,0XF4,0XE0,0XFD,0XE0,0XFD,0XE0,
0XFD,0XA0,0XFD,0X60,0XEC,0XA0,0XD3,0X81,0XDC,0X20,0XDC,0XA0,0XD4,0XA1,0XE5,0X21,
0XE4,0XE1,0X82,0XC1,0X10,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X62,0X82,0XFE,0XA1,0XFD,0XA0,0XFD,0XE0,0XFD,0XE0,0XFD,0X60,0XFD,0X20,0XFD,0XA0,
0XFE,0X20,0XFE,0X20,0XFD,0XA0,0XFD,0X60,0XFD,0X20,0XFD,0XA0,0XFC,0XA0,0XF3,0XC0,
0XF4,0XA0,0XFD,0X20,0XF4,0XE0,0XF4,0XE0,0XCB,0X40,0XB2,0XC1,0XDC,0XE0,0XE5,0X60,
0XCC,0XE1,0XCC,0XE1,0X9B,0X41,0X58,0XC1,0X7A,0X01,0X40,0X80,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X30,0X81,0X79,0XC1,0XCC,0XA1,0XF6,0X61,0XBC,0X21,0XA3,0X41,
0XCC,0X61,0XC3,0XC0,0XBB,0X41,0X61,0X01,0X58,0X81,0XDB,0XC0,0XF4,0X60,0XEB,0XC0,
0XEB,0XC0,0XEC,0X61,0XEC,0XA0,0XFD,0X20,0XFD,0XA0,0XFD,0X20,0XFC,0XE0,0XF4,0X60,
0XE3,0X80,0XDB,0X80,0XDB,0XC0,0XCC,0X20,0XB3,0X41,0XBB,0XC1,0X93,0X01,0X28,0XC1,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X72,0X81,0XFE,0X61,0XFE,0X60,0XFE,0X20,0XFE,0X20,0XFD,0XA0,0XFC,0XE0,0XFD,0X20,
0XFD,0XA0,0XFD,0XE0,0XFD,0XA0,0XFC,0XE0,0XFC,0XA0,0XFD,0X20,0XF4,0XE0,0XE3,0XC0,
0XDB,0X80,0XE4,0XA0,0XDC,0X20,0XBA,0X80,0XB2,0XC1,0XE5,0X21,0XBB,0XC1,0XBC,0X61,
0XDD,0XE0,0X59,0X41,0X51,0X41,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X72,0X81,0XDD,0X21,0XAB,0X81,0XBB,0XC1,0XBC,0X21,0XC4,0X61,
0XBB,0X80,0XC3,0X40,0X61,0X01,0X58,0X41,0XC2,0XC0,0XD3,0X80,0XDB,0X80,0XEC,0X61,
0XF4,0XE0,0XFD,0X20,0XFC,0XE0,0XFC,0XA0,0XEC,0X20,0XE3,0X80,0XDB,0X40,0XDB,0X80,
0XDB,0XC0,0XD4,0X20,0XCC,0X20,0XCC,0X20,0XC4,0X20,0X93,0X01,0X6A,0X41,0X59,0XC1,
0X08,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X5A,0X01,0XFD,0XE1,0XFE,0X20,0XFD,0XE0,0XFE,0X60,0XFE,0X20,0XFD,0X20,0XFC,0XA0,
0XFD,0X20,0XFD,0XA0,0XFD,0X60,0XFC,0XA0,0XFC,0X20,0XFC,0X60,0XFD,0X20,0XD3,0X41,
0XA9,0XC0,0XA1,0X80,0X99,0X40,0XE5,0X21,0XDD,0XA0,0XA3,0X01,0X92,0X81,0X93,0X01,
0X59,0X81,0X31,0X41,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X4A,0X01,0XE5,0XA1,0X82,0X42,0X9A,0X81,0XDD,0X61,0XBC,0X20,0XB3,0X41,
0XA2,0XC1,0X28,0X41,0X50,0X00,0X99,0X00,0XBA,0XC1,0XEC,0XA1,0XFD,0X60,0XFC,0XE0,
0XF4,0X60,0XF4,0X20,0XEB,0X80,0XEB,0X40,0XEB,0XC0,0XEC,0X60,0XEC,0X60,0XEC,0XA0,
0XE4,0XA0,0XCC,0X20,0XCC,0X20,0XC4,0X20,0XBC,0X20,0XF5,0X60,0XBC,0X61,0X10,0X81,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X39,0X41,0XD4,0XE1,0XFE,0X20,0XFD,0XA0,0XFE,0X20,0XFE,0XA0,0XFD,0XE0,0XFC,0XE0,
0XFC,0X60,0XFC,0XE0,0XFD,0X20,0XF4,0XA0,0XF3,0X80,0XEB,0X80,0XDB,0XC0,0XA1,0XC0,
0X78,0X41,0XB3,0X01,0XD4,0X61,0XC4,0X21,0XB4,0X21,0XC4,0XE1,0X93,0X01,0X62,0X01,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X62,0X81,0XDD,0X21,0XBC,0X62,0XBC,0X21,0XC4,0X61,0XA3,0X41,0XA2,0X41,0X9A,0X01,
0X38,0X81,0X18,0X00,0X58,0X81,0XEC,0X61,0XFD,0X60,0XEC,0X20,0XEB,0XC0,0XF3,0X80,
0XF3,0X80,0XF4,0X20,0XFC,0XA0,0XFC,0XA0,0XFC,0XA0,0XF4,0XA0,0XE4,0X60,0XCB,0XC0,
0XC3,0XC0,0XC3,0XC0,0XBB,0X40,0XBB,0X40,0X8A,0XC1,0X10,0X80,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X01,0X9B,0XC1,0XFE,0X21,0XFE,0X20,0XFD,0XA0,0XFE,0X20,0XFE,0X60,0XFD,0X60,
0XFC,0X60,0XFC,0XA0,0XFC,0XA0,0XEC,0XA0,0XDB,0XC0,0XC2,0XC0,0XA9,0XC0,0XC3,0X81,
0XD4,0XE1,0XC3,0XC1,0XD4,0XE1,0XBC,0X61,0XC4,0XE1,0XC4,0XA1,0X49,0X81,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X83,0X02,
0XC4,0X21,0XCC,0XE1,0XB4,0X60,0XA2,0XC1,0XCC,0XA1,0XAA,0XC1,0X58,0X81,0X40,0X41,
0X18,0X41,0X7A,0X41,0XDB,0XC1,0XDB,0X01,0XEB,0X40,0XF3,0XC0,0XFC,0X60,0XFC,0XE0,
0XFC,0XE0,0XFD,0X20,0XFD,0X60,0XFC,0XE0,0XE4,0X21,0XC3,0X40,0XCB,0X80,0XDC,0X20,
0XBB,0X01,0X82,0X00,0X41,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X31,0X41,0XC4,0XA1,0XFE,0X60,0XFD,0XA0,0XFD,0X60,0XFD,0XE0,0XFD,0XA0,
0XFC,0XE0,0XFC,0X60,0XE4,0X20,0XD3,0XC0,0XBA,0XC0,0X88,0XC0,0XB2,0XC1,0XDC,0XA0,
0XE5,0X21,0XDD,0XA1,0XCC,0XE1,0XD5,0X21,0X9B,0X01,0X10,0X41,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X40,0X83,0X02,0X9A,0XC1,
0XC4,0X61,0XC4,0X21,0X9A,0X81,0XAB,0X01,0XE5,0X21,0X7A,0X01,0X28,0X01,0X28,0X40,
0X68,0XC1,0XBA,0X81,0XF4,0X20,0XFC,0XE0,0XFD,0X20,0XFD,0X60,0XFD,0XA0,0XFD,0XA0,
0XFD,0X60,0XFD,0X60,0XFD,0X60,0XFD,0X20,0XE4,0X61,0X92,0X41,0X59,0X40,0X20,0X80,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X28,0XC1,0X93,0X41,0XBB,0XC1,0XBB,0XC1,0XA3,0X81,0X7A,0XC1,0X5A,0X01,0X31,0X41,
0X00,0X00,0X00,0X01,0X62,0XC2,0XC4,0XE1,0XF5,0X61,0XFD,0X60,0XFD,0X60,0XFD,0X60,
0XFD,0X20,0XEC,0X20,0XBA,0XC0,0XA1,0X80,0XA1,0X80,0XCB,0X80,0XD4,0X21,0XE5,0X21,
0XB3,0X81,0XCC,0XA1,0XE5,0XE0,0X69,0X81,0X62,0X41,0X31,0X81,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X40,0XB4,0XA2,0XD4,0XE1,0X61,0X81,
0X39,0X01,0X82,0X01,0XAA,0X81,0X69,0X81,0X28,0X41,0X28,0X01,0X10,0X01,0XAA,0X80,
0XFD,0X20,0XFD,0X60,0XFD,0X60,0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,0XFD,0X60,0XFD,0X20,
0XFD,0X20,0XEC,0XE0,0XE4,0XE0,0XFD,0X60,0X8A,0XC1,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X72,0XC1,0XFE,0XE1,
0XFE,0X21,0XFD,0XA0,0XFD,0XA0,0XFD,0XE0,0XFD,0XE0,0XFD,0XE0,0XFD,0X61,0XF4,0XE1,
0XCC,0X20,0X9B,0X01,0XAB,0X81,0XE5,0X21,0XFD,0X60,0XFD,0X20,0XFC,0XE0,0XFC,0XA0,
0XF4,0X60,0XCB,0X00,0X99,0X80,0X91,0X00,0XA2,0X40,0XC3,0XC1,0XED,0X61,0XCC,0X61,
0XB3,0XC1,0XAB,0XC2,0XC4,0XE1,0XDD,0XA1,0XAB,0XC2,0X5A,0X42,0X49,0XC1,0X00,0X00,
0X00,0X01,0X00,0X00,0X00,0X00,0X39,0X01,0XB3,0XC1,0XFE,0X60,0X72,0X81,0X49,0X81,
0X61,0X01,0X81,0X81,0X28,0X01,0X18,0X01,0X08,0X00,0X79,0X81,0XFC,0XE0,0XFD,0X20,
0XFD,0X20,0XFD,0X20,0XFC,0XE0,0XFC,0XE0,0XFC,0XA0,0XFC,0XA0,0XEC,0X60,0XDC,0X20,
0XD3,0XC0,0XCB,0XC0,0XF5,0X20,0X62,0X41,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X20,0XC1,0XD4,0XE2,0X5A,0X00,0X08,0X01,
0X51,0XC1,0XAB,0X81,0XC4,0X21,0XDC,0XE1,0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,0XFD,0XE0,
0XFE,0X20,0XFD,0XE0,0XFD,0XA0,0XFD,0X60,0XFD,0XA0,0XFD,0X20,0XFC,0X60,0XE3,0X80,
0XD3,0X40,0XB2,0X40,0X88,0XC0,0X58,0X01,0XC3,0X81,0XDC,0X60,0XDD,0X20,0X9B,0X00,
0X9A,0XC1,0XCC,0XE1,0XB4,0X61,0XA3,0X41,0XB4,0X62,0XF6,0X21,0X49,0XC1,0X72,0XC2,
0X7A,0XC1,0X31,0X01,0X7A,0X42,0X72,0X01,0XBC,0XA1,0XD5,0X21,0XC4,0X21,0X7A,0X01,
0X50,0XC1,0X38,0X41,0X20,0X41,0X20,0X01,0XC2,0XC0,0XFD,0X60,0XFC,0XE0,0XFC,0XE0,
0XFC,0XE0,0XFC,0XE0,0XFC,0XE0,0XFC,0XE0,0XF4,0XA0,0XEC,0X60,0XE4,0X20,0XDC,0X20,
0XDB,0XC0,0XCB,0X81,0X49,0X41,0X29,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X10,0X80,0X00,0X00,0X00,0X01,0X83,0X81,0XDD,0XE0,
0XFE,0X20,0XF5,0XE0,0XF5,0XE0,0XFE,0X20,0XFE,0X20,0XFD,0XE0,0XFD,0XE0,0XFD,0XE0,
0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,0XFD,0X60,0XFD,0X20,0XF4,0X60,0XCB,0X40,0XAA,0X00,
0X99,0X00,0X70,0X80,0X68,0XC1,0XD4,0X21,0XD4,0X21,0XAB,0X01,0X9B,0X41,0XAB,0X41,
0XA3,0X41,0X9B,0X41,0XD4,0XE1,0XB3,0X40,0X9B,0X80,0X7A,0X41,0XA3,0X41,0XFD,0XE1,
0XA3,0X81,0X9B,0X41,0X8B,0X01,0X8A,0X41,0XA3,0X01,0XDC,0X61,0XA2,0X41,0X30,0X01,
0X28,0X41,0X18,0X41,0X20,0X00,0XA2,0X40,0XCB,0X40,0XDB,0X41,0XEB,0X81,0XEC,0X20,
0XEC,0XA0,0XEC,0XA0,0XEC,0X60,0XE4,0X20,0XE4,0X20,0XEC,0XA0,0XEC,0XE0,0XDC,0XA0,
0XBB,0X40,0XBA,0XC0,0XC3,0X41,0XBB,0XC1,0X31,0X01,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X73,0X02,0XDD,0XA1,0XFE,0X21,0XFD,0XE1,0XFD,0XE0,
0XFE,0X20,0XFE,0X20,0XFE,0X20,0XFD,0XE0,0XFD,0XE0,0XFD,0XE0,0XFD,0XA0,0XFD,0X60,
0XFD,0X20,0XFC,0XE0,0XFC,0XE0,0XFC,0XA0,0XF4,0X60,0XD3,0X80,0XB2,0X40,0XA1,0X40,
0X68,0X40,0X81,0XC1,0XD4,0X21,0XB3,0X01,0XA2,0X01,0XB3,0X01,0XC3,0XC1,0XCC,0XA1,
0X93,0X01,0XBC,0X21,0X69,0X81,0X39,0X01,0X8A,0XC1,0X51,0X81,0X5A,0X01,0X92,0X81,
0XCB,0XC1,0XD4,0X61,0X89,0X41,0X89,0X81,0X71,0X81,0X38,0X41,0X30,0X41,0X10,0X00,
0X10,0X01,0X20,0X01,0X49,0X41,0X92,0XC1,0XC3,0XC1,0XD4,0X61,0XDC,0X21,0XEB,0XC1,
0XF4,0X60,0XF4,0XA0,0XF4,0XA0,0XF4,0XA0,0XF4,0XE0,0XF5,0X20,0XFD,0X60,0XF5,0X60,
0XCC,0X20,0XB2,0XC0,0XEC,0XA0,0XFD,0X61,0X51,0XC1,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X51,0XC1,0X8B,0X41,0XBC,0X62,0XED,0XA1,0XFE,0X60,0XFD,0XA0,
0XFD,0XA0,0XFD,0XE0,0XFD,0XE0,0XFD,0XE0,0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,0XFD,0X60,
0XFD,0X60,0XFD,0X60,0XFD,0X60,0XFD,0X60,0XFD,0X20,0XE4,0X20,0XBA,0X41,0X78,0X41,
0X70,0XC1,0X70,0XC1,0X48,0X81,0XB3,0X41,0XE4,0XA1,0X92,0X00,0X81,0X81,0XAB,0X01,
0X9A,0X81,0X41,0X02,0X72,0XC1,0XF5,0X61,0X51,0X01,0X28,0X41,0X81,0X81,0XD4,0X61,
0X92,0X41,0X48,0X41,0X38,0X41,0X10,0X01,0X20,0X41,0X18,0X01,0X38,0XC1,0X93,0X01,
0XD5,0X61,0XFE,0X61,0XFE,0XE0,0XFF,0X20,0XFF,0X20,0XFE,0X60,0XFC,0XA0,0XFC,0XE0,
0XFD,0X20,0XFC,0XE0,0XFD,0X20,0XF5,0X20,0XEC,0XE1,0XE4,0XA1,0XFE,0X20,0XE5,0X61,
0XA3,0X01,0XDC,0X20,0XFD,0X21,0X8A,0XC1,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X49,0XC2,0XFF,0X20,0XFE,0X20,0XED,0XA1,0XFD,0XA0,0XFD,0XA0,
0XFD,0XE0,0XFD,0XE0,0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,
0XFD,0XA0,0XFD,0X60,0XFD,0X60,0XFD,0X60,0XFD,0X20,0XE4,0X60,0XBA,0XC0,0X89,0X41,
0X60,0X81,0X40,0X41,0X51,0X01,0XC3,0XC1,0XB2,0XC1,0X81,0X41,0XAA,0XC1,0XBB,0X81,
0X8A,0X01,0XA3,0X41,0XB3,0X01,0X9A,0X81,0X99,0XC1,0X48,0XC1,0X7A,0XC1,0X51,0X41,
0X18,0X01,0X28,0X41,0X18,0X01,0X08,0X01,0X92,0XC1,0XFE,0X21,0XFE,0XE0,0XFE,0XE0,
0XFE,0XA0,0XFE,0XA0,0XFE,0X60,0XED,0X20,0XF5,0XA0,0XFD,0XE0,0XEC,0XE0,0XEC,0XA0,
0XF5,0X20,0XFD,0X20,0XFD,0X20,0XED,0X61,0XCC,0X61,0X93,0X01,0XBC,0XA1,0X9B,0X41,
0X51,0X41,0X20,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X42,0X01,0XB4,0XA1,0XEC,0XE1,0XE3,0XC0,0XDB,0X81,0XE4,0XA0,0XEC,0XE0,0XED,0X20,
0XF5,0X60,0XF5,0XA0,0XFD,0XE0,0XFD,0XE0,0XFE,0X20,0XFE,0X20,0XFD,0XE0,0XFD,0XA0,
0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,0XFD,0X60,0XF5,0X20,0XDC,0XA0,0XBA,0XC0,0X68,0X40,
0X50,0X81,0X40,0X41,0X28,0X01,0X61,0X41,0X92,0XC1,0XAA,0XC1,0X9A,0X01,0X71,0X41,
0X9A,0XC1,0X40,0XC1,0X38,0XC1,0X50,0XC1,0X20,0X41,0X08,0X01,0X20,0X41,0X28,0X41,
0X08,0X01,0X00,0X01,0X61,0X01,0XFC,0XE1,0XFD,0X60,0XF5,0XA0,0XFE,0X20,0XFE,0X20,
0XFE,0X20,0XFE,0X20,0XE4,0XE1,0XC3,0X41,0XDC,0X61,0XCB,0X80,0XC3,0X00,0XCB,0XC0,
0XD4,0X60,0XDC,0XA0,0XF5,0X60,0XFD,0XE0,0XBC,0X61,0XCC,0XA1,0XCC,0XE1,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X93,0X01,0XFD,0XE1,
0XFD,0X21,0XDB,0X41,0XDB,0X41,0XF3,0XC0,0XFC,0X60,0XF4,0X60,0XEC,0X60,0XEC,0X60,
0XEC,0XA0,0XEC,0XA0,0XEC,0XE0,0XF4,0XE0,0XF5,0X20,0XF5,0X60,0XFD,0X60,0XFD,0X60,
0XFD,0X60,0XFD,0X20,0XF4,0XE1,0XEC,0XE0,0XDC,0X60,0XBB,0X40,0X80,0XC0,0X38,0X01,
0X40,0X41,0X28,0X01,0X00,0X01,0X10,0X01,0X59,0X01,0X48,0XC1,0X18,0X01,0X20,0X41,
0X10,0X41,0X10,0X01,0X38,0XC1,0X41,0X01,0X28,0X41,0X30,0X41,0X08,0X01,0X28,0X81,
0X93,0X01,0XED,0X21,0XF4,0XE0,0XEC,0X21,0XDC,0X20,0XE4,0X20,0XEC,0X60,0XE4,0X60,
0XE4,0X60,0XDB,0XC0,0XC2,0X80,0XC2,0XC0,0XD3,0X80,0XCB,0X80,0XC3,0X40,0XBB,0X40,
0XBB,0X80,0XC4,0X20,0XCC,0X60,0XD4,0XE1,0XA4,0X22,0X10,0X81,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
};


unsigned char code pic5[]=
{/* 0X10,0X10,0X00,0X5F,0X00,0X1C,0X01,0X1B, */
0X75,0XFF,0X6D,0XBE,0X6D,0X7E,0X6D,0X7E,0X5D,0X3E,0X44,0XBD,0X23,0XDC,0X1A,0X54,
0X00,0X03,0X00,0X00,0X00,0X03,0X00,0X8D,0X09,0X12,0X08,0XCB,0X00,0X46,0X00,0X04,
0X08,0X41,0X31,0XC0,0X42,0X81,0X74,0X24,0X9D,0XA3,0XA6,0X21,0X85,0X60,0X74,0XE0,
0X6C,0XA0,0X6C,0XA0,0X64,0XA0,0X5C,0X20,0X5C,0X20,0X53,0XC0,0X4B,0X80,0X4B,0X40,
0X43,0X40,0X43,0X40,0X32,0XC2,0X43,0X02,0X4B,0XC0,0X64,0X62,0X8D,0X68,0X85,0X6B,
0X4B,0X82,0X33,0X00,0X53,0XC5,0X43,0X06,0X3A,0XC5,0X53,0XC6,0X4B,0X43,0X43,0X43,
0X43,0X04,0X5B,0XC8,0X5C,0X28,0X4B,0X47,0X21,0X02,0X00,0X00,0X00,0X02,0X00,0X04,
0X00,0X45,0X00,0X48,0X00,0X49,0X00,0XCD,0X01,0X10,0X01,0X0E,0X0A,0X12,0X0A,0XD5,
0X13,0X56,0X1B,0XD8,0X2C,0X79,0X3C,0XB8,0X2C,0X37,0X2C,0X37,0X2C,0X38,0X23,0XD6,
0X23,0XD7,0X13,0X97,0X0B,0X17,0X0A,0X13,0X00,0X89,0X00,0X01,0X10,0X40,0X39,0X41,
0X18,0X81,0X00,0X02,0X00,0X00,0X18,0X82,0X42,0X87,0X11,0XC2,0X19,0XC3,0X19,0XC3,
0X19,0XC3,0X1A,0X04,0X22,0X04,0X22,0X03,0X11,0XC2,0X11,0X81,0X19,0XC2,0X33,0XDA,
0X2B,0X59,0X23,0X5A,0X33,0XDC,0X2B,0X9B,0X01,0X93,0X19,0XD4,0X22,0XD4,0X3C,0X38,
0X44,0X7A,0X34,0X7C,0X1B,0XDE,0X02,0X5A,0X01,0X55,0X00,0XD2,0X08,0X8F,0X08,0X8B,
0X00,0X47,0X00,0X04,0X00,0X01,0X29,0X80,0X6C,0X22,0X95,0XA2,0X96,0X21,0X85,0XA1,
0X6C,0XE0,0X6C,0XA0,0X6C,0X60,0X5C,0X20,0X54,0X20,0X4B,0XC0,0X43,0X80,0X43,0X41,
0X43,0X81,0X43,0X01,0X1A,0X00,0X3B,0X42,0X6C,0XA4,0X5B,0XC6,0X74,0XAE,0X64,0X69,
0X32,0XC0,0X3B,0X03,0X3A,0XC7,0X53,0XC8,0X4B,0X84,0X33,0X02,0X4B,0X84,0X4B,0X46,
0X3B,0X04,0X4B,0X85,0X31,0XC3,0X00,0X00,0X00,0X01,0X00,0X04,0X00,0X05,0X00,0X47,
0X00,0X8A,0X08,0X8C,0X00,0XCD,0X09,0X8F,0X09,0XD1,0X02,0X54,0X02,0XD7,0X1B,0XD9,
0X2C,0X39,0X2C,0X79,0X34,0X38,0X34,0X38,0X34,0X38,0X2B,0XD7,0X23,0XD7,0X1B,0X15,
0X2A,0XD4,0X12,0X10,0X01,0X8F,0X08,0X88,0X00,0X01,0X10,0X81,0X28,0XC2,0X08,0X40,
0X10,0X81,0X00,0X00,0X00,0X00,0X11,0X03,0X2A,0X47,0X22,0X04,0X22,0X04,0X22,0X04,
0X22,0X03,0X11,0XC1,0X11,0X81,0X01,0X40,0X01,0X40,0X01,0X40,0X4C,0XFC,0X4C,0XFD,
0X44,0XFE,0X44,0XFE,0X12,0XD8,0X2B,0X59,0X6E,0X7F,0X76,0XBF,0X76,0X7F,0X66,0X7F,
0X4D,0XBF,0X35,0X7F,0X1C,0X7D,0X13,0X5C,0X0B,0X1B,0X02,0X17,0X01,0X14,0X00,0XD0,
0X00,0XCD,0X00,0X87,0X00,0X04,0X08,0X03,0X31,0X83,0X53,0X02,0X74,0XA1,0X8D,0XE2,
0X7D,0X61,0X5C,0X60,0X54,0X20,0X53,0XC0,0X4B,0XC3,0X53,0XC5,0X4B,0X84,0X53,0XC5,
0X5C,0X25,0X3B,0X42,0X2A,0X82,0X32,0X80,0X2A,0X80,0X33,0X01,0X4B,0X85,0X43,0X83,
0X22,0X81,0X43,0X46,0X53,0XC6,0X43,0X44,0X3B,0X03,0X43,0X44,0X4B,0XC7,0X5C,0X28,
0X39,0XC2,0X08,0X00,0X00,0X01,0X00,0X03,0X00,0X05,0X00,0X08,0X00,0X49,0X00,0XC9,
0X00,0XCA,0X09,0X4D,0X09,0XD1,0X02,0X53,0X02,0XD6,0X13,0X98,0X24,0X39,0X24,0X39,
0X2C,0X38,0X2C,0X38,0X2C,0X38,0X2C,0X38,0X2B,0XD7,0X24,0X38,0X23,0X97,0X32,0XD3,
0X09,0X8F,0X01,0X8F,0X08,0X86,0X00,0X00,0X31,0X42,0X18,0X81,0X00,0X00,0X10,0X80,
0X00,0X00,0X00,0X00,0X21,0X83,0X22,0X04,0X19,0XC3,0X11,0X82,0X09,0X41,0X09,0X81,
0X01,0X40,0X09,0X40,0X09,0X40,0X09,0X41,0X09,0X40,0X45,0X7F,0X5E,0X3F,0X4D,0XBF,
0X3C,0X3A,0X01,0XD4,0X3C,0XBF,0X5D,0XFF,0X65,0X7F,0X55,0X7F,0X45,0X3D,0X3D,0X3E,
0X2C,0XFE,0X24,0XFE,0X1C,0XFF,0X1D,0X3F,0X14,0XBF,0X13,0X1B,0X0A,0X16,0X01,0X93,
0X01,0X0F,0X00,0X8A,0X00,0X49,0X00,0X07,0X00,0X43,0X21,0X42,0X42,0X82,0X53,0XC1,
0X53,0XC1,0X54,0X20,0X4B,0XC0,0X4B,0X84,0X4B,0X86,0X43,0X43,0X43,0X44,0X4B,0X85,
0X43,0X42,0X4B,0X43,0X3A,0XC3,0X32,0XC1,0X43,0X81,0X3B,0X42,0X3B,0X02,0X32,0XC3,
0X3B,0X01,0X33,0X01,0X4B,0XC6,0X4B,0X86,0X4B,0X87,0X54,0X28,0X42,0X45,0X10,0X00,
0X00,0X01,0X00,0X04,0X00,0X05,0X00,0X47,0X08,0X49,0X00,0X4A,0X00,0XCA,0X09,0X4B,
0X09,0XCF,0X02,0X13,0X0A,0X55,0X13,0X16,0X23,0X98,0X2B,0XD8,0X23,0XD8,0X2B,0XD7,
0X2B,0XD5,0X2B,0XD6,0X2B,0X96,0X2C,0X37,0X2C,0X38,0X13,0X97,0X02,0X52,0X02,0X10,
0X09,0X8E,0X08,0X45,0X08,0X41,0X29,0X43,0X18,0XC2,0X39,0XC6,0X08,0X40,0X00,0X00,
0X00,0X40,0X11,0X82,0X11,0X81,0X01,0X00,0X01,0X00,0X01,0X00,0X01,0X00,0X09,0X40,
0X09,0X41,0X09,0X41,0X09,0X41,0X09,0X40,0X3C,0XBD,0X2C,0X7B,0X24,0X3C,0X33,0XDA,
0X44,0X7A,0X65,0X7E,0X5D,0X3E,0X55,0X3E,0X3C,0XBE,0X45,0X3E,0X55,0X7F,0X4D,0X7E,
0X34,0XFE,0X14,0X7E,0X03,0XDD,0X14,0X3D,0X14,0X7D,0X0B,0X5A,0X12,0XD8,0X0A,0X15,
0X09,0X94,0X01,0X11,0X00,0XCD,0X00,0X89,0X00,0X47,0X00,0X05,0X10,0XC3,0X29,0XC2,
0X42,0XC0,0X53,0XC2,0X4C,0X23,0X3B,0X82,0X32,0XC0,0X32,0XC0,0X33,0X01,0X3B,0X41,
0X43,0X41,0X3B,0X02,0X2A,0X41,0X3B,0X42,0X4B,0XC3,0X3B,0X03,0X3B,0X05,0X4B,0X83,
0X53,0XC7,0X64,0X2B,0X5C,0X2B,0X64,0X69,0X3A,0X42,0X08,0X00,0X00,0X01,0X00,0X44,
0X00,0X05,0X00,0X07,0X00,0X47,0X00,0X46,0X00,0X89,0X09,0X0D,0X09,0X8F,0X01,0XD1,
0X02,0X13,0X0A,0XD6,0X0B,0X56,0X1B,0XD7,0X2C,0X38,0X34,0X78,0X34,0X78,0X34,0X77,
0X2B,0X94,0X1B,0X12,0X22,0XD1,0X22,0X4F,0X09,0XCD,0X09,0XCE,0X09,0X4D,0X00,0X88,
0X00,0X00,0X18,0XC2,0X08,0X40,0X63,0X0B,0X9D,0X32,0X00,0X00,0X42,0X07,0X21,0X83,
0X01,0X00,0X09,0X41,0X11,0X41,0X11,0X41,0X09,0X00,0X09,0X40,0X09,0X40,0X09,0X40,
0X11,0X80,0X19,0XC0,0X22,0X01,0X1A,0X95,0X23,0XDA,0X3C,0XFD,0X6D,0XBE,0X86,0X7F,
0X7E,0X3E,0X86,0X7D,0X7E,0X3E,0X65,0X3C,0X55,0X3D,0X44,0XFD,0X34,0XFD,0X35,0X3F,
0X24,0XFF,0X14,0XBE,0X0B,0X9A,0X03,0X9B,0X0B,0X5A,0X0A,0X56,0X12,0X16,0X09,0XD5,
0X01,0X52,0X01,0X10,0X01,0X0F,0X00,0X8C,0X00,0X4A,0X10,0X87,0X00,0X04,0X10,0X81,
0X32,0X02,0X43,0X44,0X54,0X25,0X43,0X43,0X3B,0X02,0X3B,0X42,0X43,0X42,0X33,0X00,
0X3B,0X41,0X3B,0X01,0X2A,0X80,0X4B,0XC3,0X43,0X44,0X53,0XC8,0X54,0X28,0X53,0XC9,
0X5B,0XCB,0X64,0X6B,0X53,0X87,0X20,0XC1,0X08,0X01,0X00,0X03,0X00,0X04,0X00,0X05,
0X00,0X44,0X08,0X45,0X08,0X89,0X00,0XCC,0X01,0X0D,0X01,0X90,0X02,0X13,0X02,0X96,
0X03,0X17,0X13,0XD9,0X24,0X79,0X2C,0X79,0X34,0X78,0X34,0XB9,0X3C,0XB9,0X34,0XB9,
0X24,0X38,0X1B,0X55,0X12,0X10,0X09,0X09,0X08,0XC8,0X08,0X85,0X00,0X01,0X08,0X40,
0X21,0X02,0X00,0X00,0X4A,0X46,0X29,0X85,0X4A,0X07,0X7C,0X2C,0X08,0X81,0X09,0X00,
0X00,0XC0,0X09,0X01,0X09,0X00,0X01,0X00,0X01,0X00,0X09,0X40,0X11,0X81,0X1A,0X00,
0X22,0X41,0X2A,0X81,0X1C,0X7D,0X5D,0XFF,0X4D,0X7E,0X75,0XFE,0X8E,0X3D,0X7D,0XFE,
0X7D,0XFE,0X75,0XBE,0X7D,0XFD,0X76,0X3E,0X75,0XFD,0X5D,0X7E,0X3C,0XFD,0X34,0XBE,
0X24,0X7E,0X0B,0X9B,0X0B,0X5B,0X0B,0X9C,0X02,0XD9,0X0A,0X98,0X0A,0X97,0X02,0X15,
0X01,0X93,0X01,0X12,0X01,0X10,0X00,0XCE,0X00,0X8C,0X00,0X8A,0X00,0X88,0X00,0X43,
0X20,0XC3,0X31,0XC3,0X4B,0X86,0X4B,0XC5,0X43,0X42,0X43,0X42,0X32,0XC0,0X3B,0X43,
0X4B,0X83,0X3B,0X02,0X2A,0X82,0X43,0X05,0X64,0XAA,0X53,0XC8,0X53,0XC8,0X64,0X6C,
0X64,0X2B,0X21,0X03,0X08,0X01,0X00,0X02,0X00,0X04,0X00,0X42,0X00,0X42,0X08,0X88,
0X00,0X8A,0X00,0XCB,0X00,0XCC,0X01,0X0E,0X01,0X91,0X02,0X14,0X0A,0XD7,0X0B,0X58,
0X24,0X39,0X2C,0X79,0X2C,0X38,0X2C,0X79,0X34,0X79,0X34,0X38,0X2C,0X38,0X24,0X78,
0X1B,0XD8,0X0B,0X57,0X0A,0X53,0X01,0X0C,0X00,0X03,0X00,0X00,0X18,0XC2,0X29,0X42,
0X29,0X01,0X10,0X80,0X00,0X00,0X52,0X88,0X29,0XC3,0X00,0XC0,0X09,0X00,0X09,0X01,
0X09,0X00,0X09,0X00,0X01,0X00,0X01,0X00,0X11,0X80,0X1A,0X01,0X1A,0X40,0X22,0X41,
0X22,0X41,0X13,0XDC,0X85,0XBE,0XA6,0X3D,0X65,0XBE,0X6D,0XFF,0X75,0XFF,0X75,0XBE,
0X75,0XFE,0X6D,0XFF,0X6D,0XFF,0X6D,0X7E,0X6D,0X7D,0X54,0XFC,0X44,0X7B,0X34,0X3C,
0X2B,0XDB,0X1B,0X18,0X0A,0X56,0X0A,0X96,0X02,0X57,0X02,0X58,0X0A,0X57,0X0A,0X15,
0X01,0XD3,0X09,0X92,0X09,0X50,0X01,0X0D,0X00,0X8C,0X00,0X8B,0X00,0X47,0X08,0X46,
0X10,0X82,0X21,0X42,0X32,0X82,0X43,0X43,0X43,0X41,0X32,0XC1,0X43,0X46,0X4B,0X85,
0X64,0X68,0X19,0X43,0X08,0X81,0X53,0X87,0X64,0X69,0X4B,0X88,0X64,0X2A,0X52,0X87,
0X08,0X00,0X08,0X02,0X00,0X42,0X00,0X43,0X00,0X45,0X00,0X48,0X00,0X8A,0X00,0X8A,
0X00,0XCB,0X01,0X0D,0X01,0X91,0X01,0XD2,0X02,0X14,0X02,0X55,0X0B,0X16,0X13,0X96,
0X23,0XD7,0X24,0X37,0X2C,0X37,0X2C,0X37,0X2C,0X37,0X24,0X36,0X23,0XD5,0X23,0X95,
0X12,0XD5,0X02,0X12,0X01,0X0D,0X00,0X05,0X08,0X00,0X08,0X40,0X08,0X40,0X19,0X01,
0X00,0X40,0X08,0X41,0X10,0XC1,0X09,0X01,0X09,0X41,0X00,0XC0,0X09,0X01,0X09,0X01,
0X09,0X01,0X01,0X00,0X09,0X40,0X1A,0X01,0X1A,0X00,0X22,0X40,0X22,0X41,0X22,0X01,
0X12,0XD9,0X54,0X7B,0X8D,0XBD,0X4C,0XFD,0X55,0XBE,0X6E,0X3F,0X6D,0XBF,0X5D,0X3D,
0X55,0X3C,0X3C,0X7B,0X2B,0XDA,0X4C,0XFC,0X5D,0X3D,0X55,0X7E,0X4D,0X7E,0X45,0X3E,
0X3C,0XBD,0X23,0XDB,0X1B,0X19,0X12,0XD7,0X12,0X55,0X09,0X92,0X01,0X50,0X09,0X50,
0X09,0X10,0X09,0X0F,0X08,0XCD,0X00,0X8C,0X00,0X8B,0X00,0X4A,0X00,0X49,0X00,0X47,
0X08,0X44,0X20,0XC2,0X31,0XC3,0X42,0XC4,0X4B,0X85,0X43,0X45,0X4B,0X87,0X32,0X46,
0X39,0X84,0X29,0X03,0X08,0X41,0X32,0X46,0X54,0X69,0X5B,0X48,0X18,0X81,0X00,0X00,
0X00,0X40,0X00,0X02,0X00,0X06,0X00,0X4A,0X00,0X4A,0X00,0X89,0X08,0XCA,0X08,0XCC,
0X01,0X4E,0X09,0XD2,0X02,0X14,0X0A,0X54,0X0B,0X17,0X0B,0X98,0X1B,0XD7,0X24,0X38,
0X2C,0X78,0X34,0X37,0X2C,0X37,0X24,0X36,0X1B,0X96,0X1B,0X55,0X1B,0X15,0X0A,0X93,
0X01,0XD1,0X01,0X4D,0X08,0X44,0X08,0X40,0X00,0X00,0X00,0X00,0X08,0X41,0X00,0X00,
0X00,0X41,0X00,0X40,0X00,0X80,0X00,0X80,0X00,0X40,0X00,0X40,0X00,0X80,0X00,0XC0,
0X09,0X00,0X19,0XC1,0X19,0XC0,0X1A,0X00,0X1A,0X00,0X1A,0X00,0X1A,0X00,0X1B,0X5B,
0X0B,0XDD,0X04,0X7D,0X35,0X3F,0X44,0XFD,0X3C,0XBB,0X44,0X7B,0X44,0XBB,0X4C,0XBC,
0X54,0XFC,0X65,0XBE,0X6D,0XFF,0X5D,0XBE,0X4D,0X7E,0X45,0X3E,0X34,0XFE,0X2C,0XBE,
0X1C,0XBF,0X14,0XBF,0X14,0X3D,0X1B,0X59,0X11,0XD3,0X11,0X91,0X09,0X90,0X09,0X50,
0X11,0X0E,0X08,0XCC,0X00,0X49,0X00,0X47,0X00,0X88,0X00,0X49,0X00,0X47,0X00,0X06,
0X08,0X86,0X19,0X03,0X29,0X43,0X32,0X04,0X43,0XC5,0X33,0X06,0X10,0X41,0X31,0X44,
0X31,0X43,0X31,0X03,0X32,0X43,0X54,0X6A,0X4A,0X89,0X00,0X00,0X00,0X40,0X00,0X43,
0X00,0X47,0X00,0X48,0X08,0X88,0X08,0X49,0X08,0XCA,0X09,0X0B,0X09,0X0D,0X01,0X4F,
0X09,0XD1,0X0A,0X13,0X02,0X95,0X1B,0X15,0X1B,0X56,0X23,0X97,0X2B,0XD8,0X3C,0X79,
0X3C,0XB9,0X34,0XB9,0X2C,0XBA,0X2C,0X79,0X1B,0XD8,0X13,0X17,0X0A,0X52,0X01,0XCF,
0X00,0XCA,0X08,0X42,0X00,0X00,0X4A,0X48,0X63,0X09,0X00,0X00,0X00,0X00,0X00,0X40,
0X00,0X41,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,0X00,0X80,0X09,0X00,
0X11,0X81,0X11,0XC0,0X1A,0X00,0X22,0X01,0X1A,0X00,0X22,0X41,0X01,0XD6,0X0B,0X9E,
0X14,0X3D,0X1B,0X59,0X2B,0X9A,0X2C,0X3B,0X44,0XBC,0X6D,0XBF,0X75,0XBF,0X75,0XFF,
0X75,0XFF,0X6D,0XBF,0X6D,0XBE,0X5D,0XBE,0X5D,0XFF,0X55,0XFF,0X45,0X7E,0X2C,0X7C,
0X13,0X58,0X0A,0X55,0X02,0X97,0X0A,0XD8,0X0A,0X98,0X0A,0X97,0X0A,0X56,0X11,0XD5,
0X09,0X92,0X09,0X50,0X09,0X0E,0X08,0XCA,0X08,0X47,0X08,0X05,0X08,0X44,0X00,0X44,
0X00,0X45,0X18,0XC4,0X31,0X02,0X32,0X04,0X4B,0XC9,0X42,0X86,0X18,0XC0,0X10,0X80,
0X39,0X83,0X4A,0XC3,0X22,0X03,0X10,0X01,0X18,0X81,0X08,0X82,0X08,0X44,0X08,0X44,
0X00,0X43,0X00,0X44,0X08,0X45,0X08,0X88,0X00,0X8A,0X09,0X0C,0X09,0X8F,0X09,0X4F,
0X11,0XD3,0X12,0X12,0X09,0X09,0X1A,0X51,0X1A,0XD4,0X1A,0XD3,0X23,0X13,0X23,0X14,
0X2B,0X13,0X22,0XD2,0X23,0X54,0X1B,0X54,0X12,0XD5,0X12,0X53,0X09,0X4D,0X00,0X45,
0X00,0X00,0X00,0X00,0X73,0X8C,0X63,0X4B,0X08,0X41,0X42,0X07,0X10,0X82,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,0X00,0X40,0X00,0XC0,0X09,0X40,0X11,0XC1,
0X11,0XC0,0X22,0X00,0X22,0X42,0X22,0X41,0X2A,0X81,0X08,0X47,0X11,0X0E,0X1A,0X57,
0X1B,0X5B,0X2C,0XFF,0X3D,0X7F,0X4D,0X7E,0X6D,0XFE,0X75,0XFE,0X6D,0XFE,0X76,0X3F,
0X76,0X3F,0X76,0X3F,0X6E,0X3F,0X55,0XBD,0X44,0XBB,0X44,0XBB,0X44,0X7B,0X34,0X3A,
0X24,0X7B,0X1C,0X7C,0X0B,0XDB,0X03,0X19,0X01,0XD4,0X01,0X93,0X01,0X94,0X01,0X93,
0X01,0X92,0X09,0X92,0X09,0X50,0X09,0X0E,0X00,0XCD,0X00,0X8A,0X08,0X47,0X00,0X86,
0X08,0X84,0X21,0X04,0X20,0XC1,0X3A,0X05,0X3A,0X05,0X21,0X00,0X21,0X02,0X29,0X42,
0X29,0X00,0X18,0X81,0X10,0X40,0X08,0X82,0X00,0X42,0X00,0X02,0X00,0X03,0X00,0X45,
0X00,0X46,0X00,0X48,0X00,0X8C,0X00,0XCE,0X09,0X10,0X09,0X93,0X01,0XD5,0X0A,0XD8,
0X0A,0X55,0X0A,0X13,0X13,0X57,0X23,0XD9,0X23,0X97,0X23,0XD7,0X2B,0XD7,0X1B,0X13,
0X0A,0X50,0X0A,0X10,0X11,0X4B,0X10,0XC9,0X08,0XC9,0X00,0X43,0X00,0X00,0X00,0X00,
0X39,0XC5,0X29,0X83,0X00,0X00,0X41,0XC6,0X52,0X88,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X40,0X00,0X80,0X09,0X00,0X19,0XC1,0X11,0XC0,0X1A,0X00,
0X22,0X00,0X1A,0X00,0X22,0X40,0X22,0X40,0X08,0X00,0X10,0X08,0X0A,0XDF,0X0C,0XBF,
0X1C,0X7C,0X54,0XFC,0X55,0X7E,0X5D,0XBF,0X65,0XFE,0X6E,0X3F,0X7E,0XBF,0X6E,0X3F,
0X4C,0XFC,0X3C,0X7A,0X44,0X7B,0X4C,0XBC,0X55,0X3E,0X55,0X7F,0X4D,0XBF,0X35,0X7F,
0X2C,0XBD,0X13,0XDB,0X02,0XD8,0X02,0X15,0X01,0XD3,0X01,0X93,0X01,0X92,0X01,0X51,
0X01,0X50,0X01,0X51,0X01,0X50,0X01,0X0D,0X08,0XCC,0X08,0X8A,0X08,0XC6,0X10,0XC5,
0X10,0XC4,0X21,0X02,0X20,0X81,0X28,0XC1,0X21,0X02,0X08,0XC2,0X31,0X83,0X31,0X01,
0X29,0X02,0X29,0X83,0X00,0X43,0X00,0X45,0X00,0X47,0X08,0X88,0X08,0XC9,0X08,0X89,
0X08,0X89,0X08,0XCA,0X09,0X0B,0X01,0X0D,0X09,0X8F,0X12,0X12,0X12,0X52,0X1A,0XD4,
0X23,0X57,0X1B,0X57,0X34,0X7B,0X34,0X7B,0X34,0XBB,0X34,0XBA,0X2C,0X78,0X1B,0X96,
0X0A,0X94,0X09,0XD0,0X09,0X0C,0X08,0X45,0X00,0X00,0X00,0X00,0X08,0X00,0X20,0XC3,
0X10,0X82,0X39,0XC7,0X10,0XC2,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X40,0X00,0X80,0X00,0XC0,0X01,0X01,0X09,0X40,0X22,0X01,0X22,0X00,0X2A,0X81,
0X2A,0X81,0X2A,0X80,0X2A,0XC0,0X00,0X00,0X00,0X05,0X09,0XD5,0X12,0XDA,0X0A,0X97,
0X54,0X7B,0X65,0XFF,0X5E,0X3E,0X5E,0X7F,0X55,0XFE,0X44,0XBB,0X4C,0X7B,0X44,0XBB,
0X4C,0XFC,0X55,0X7E,0X5D,0XBF,0X4D,0X7F,0X3C,0XFE,0X34,0XBE,0X1C,0X3C,0X13,0XDB,
0X0B,0X9B,0X03,0X5A,0X0B,0X19,0X02,0X97,0X02,0X16,0X09,0XD5,0X09,0X92,0X09,0X4E,
0X09,0X0C,0X00,0X8B,0X08,0X48,0X08,0X46,0X00,0X46,0X00,0X45,0X00,0X45,0X00,0X45,
0X10,0XC4,0X31,0X44,0X31,0X01,0X21,0X01,0X21,0X03,0X19,0X01,0X31,0X81,0X42,0X04,
0X21,0X43,0X08,0X42,0X00,0X43,0X00,0X43,0X08,0X44,0X08,0X44,0X00,0X44,0X08,0X87,
0X08,0X89,0X08,0X89,0X00,0X89,0X08,0XCB,0X09,0X0D,0X09,0X4E,0X11,0X90,0X12,0X11,
0X12,0X12,0X22,0X53,0X22,0X51,0X22,0XD1,0X23,0X54,0X33,0XD5,0X23,0X94,0X12,0XD3,
0X0A,0X91,0X02,0X0F,0X00,0X87,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X40,
0X29,0X85,0X00,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,
0X00,0X80,0X01,0X00,0X09,0X80,0X11,0XC0,0X22,0X00,0X22,0X00,0X32,0XC1,0X3A,0XC1,
0X32,0XC0,0X33,0X00,0X08,0X00,0X00,0X00,0X08,0X09,0X12,0X16,0X0C,0X3E,0X1C,0XFF,
0X35,0XBF,0X4D,0X7D,0X44,0XBB,0X2B,0XD9,0X44,0X39,0X5D,0X3D,0X65,0XFF,0X65,0XFF,
0X5D,0XBE,0X65,0XBE,0X5D,0XBE,0X55,0X7E,0X4D,0X7E,0X3C,0XFE,0X2C,0XBD,0X1C,0XBD,
0X14,0X3C,0X0B,0X59,0X0A,0X55,0X09,0X92,0X11,0X50,0X09,0X0F,0X08,0XCE,0X09,0X0D,
0X00,0XCC,0X00,0XCC,0X08,0XCD,0X01,0X0C,0X00,0XCB,0X00,0XC8,0X08,0XC6,0X19,0X45,
0X39,0XC5,0X49,0XC4,0X19,0X01,0X10,0XC1,0X08,0X80,0X21,0X41,0X39,0X82,0X10,0X81,
0X00,0X00,0X00,0X01,0X00,0X02,0X00,0X04,0X00,0X07,0X00,0X49,0X08,0X8B,0X09,0X0D,
0X09,0X0D,0X01,0X0F,0X09,0X51,0X01,0X53,0X01,0X95,0X01,0XD6,0X01,0XD6,0X02,0X17,
0X01,0X95,0X01,0X52,0X09,0X50,0X09,0X0F,0X11,0X8E,0X19,0XCE,0X19,0XCD,0X11,0XCB,
0X09,0X8B,0X08,0XC5,0X00,0X00,0X00,0X00,0X08,0X41,0X00,0X00,0X21,0X04,0X18,0XC2,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X81,0X09,0X01,
0X09,0X40,0X22,0X01,0X2A,0X41,0X22,0X41,0X2A,0X81,0X2A,0X80,0X32,0XC0,0X43,0X40,
0X4B,0XC1,0X39,0XC4,0X31,0X02,0X00,0X02,0X01,0X53,0X1B,0X9F,0X1C,0XFF,0X0B,0X56,
0X1B,0X16,0X2C,0X3A,0X44,0XFD,0X76,0X3F,0X7E,0X7F,0X76,0X3E,0X75,0XFE,0X75,0XFE,
0X75,0XFE,0X76,0X3F,0X76,0X7F,0X76,0X7F,0X55,0XFF,0X35,0X3D,0X2B,0XDB,0X1B,0X18,
0X0B,0X18,0X13,0X59,0X12,0X97,0X02,0X16,0X0A,0X16,0X09,0XD5,0X09,0XD4,0X09,0X91,
0X09,0X0D,0X09,0X0B,0X08,0XC9,0X08,0XC7,0X11,0X07,0X21,0X46,0X00,0X42,0X21,0X04,
0X41,0XC5,0X18,0XC1,0X10,0XC1,0X18,0XC2,0X31,0X81,0X29,0X42,0X08,0X41,0X00,0X00,
0X00,0X01,0X00,0X03,0X00,0X07,0X00,0X4A,0X08,0X4B,0X00,0X4D,0X00,0X8D,0X08,0XCE,
0X08,0XCD,0X01,0X10,0X11,0X94,0X09,0XD5,0X01,0XD6,0X02,0X17,0X02,0X17,0X02,0X58,
0X0A,0X99,0X02,0X17,0X01,0XD5,0X01,0X50,0X01,0X10,0X01,0X0F,0X00,0X45,0X08,0X00,
0X08,0X40,0X00,0X00,0X08,0X00,0X41,0X03,0X08,0X00,0X52,0XCA,0X8C,0X2E,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XC1,0X09,0X41,0X11,0X80,
0X19,0XC0,0X22,0X40,0X2A,0X81,0X32,0XC1,0X32,0XC0,0X43,0X40,0X4B,0X81,0X5C,0X23,
0X20,0XC3,0X41,0X43,0X08,0X00,0X00,0X03,0X08,0X8D,0X12,0X13,0X22,0X94,0X24,0X7C,
0X35,0XBF,0X55,0XBF,0X5D,0XBE,0X6E,0X3F,0X5D,0XFE,0X65,0XBD,0X7E,0X3E,0X6E,0X7F,
0X6D,0XFE,0X55,0X3C,0X44,0XFC,0X3C,0X7A,0X34,0X3A,0X2B,0XDA,0X24,0X3B,0X25,0X3F,
0X2D,0X3F,0X24,0X3C,0X12,0X95,0X09,0X92,0X09,0X90,0X09,0X4D,0X09,0X0D,0X08,0XCC,
0X08,0XCA,0X00,0XC9,0X00,0X88,0X08,0X89,0X08,0X87,0X00,0X44,0X08,0X42,0X21,0X02,
0X29,0X42,0X19,0X01,0X20,0XC2,0X18,0X80,0X29,0X83,0X08,0X83,0X00,0X01,0X00,0X02,
0X00,0X05,0X00,0X07,0X00,0X48,0X08,0X8C,0X00,0X8D,0X00,0X8D,0X08,0XD1,0X08,0XCE,
0X01,0X0F,0X09,0X51,0X11,0XD4,0X12,0X57,0X0A,0X57,0X02,0X57,0X02,0X57,0X02,0X57,
0X01,0XD6,0X01,0XD4,0X09,0X92,0X01,0X52,0X01,0X52,0X00,0X46,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X18,0X41,0X08,0X00,0X08,0X41,0X31,0X43,0X00,0X01,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X81,0X11,0X41,0X11,0X40,0X22,0X02,0X22,0X41,
0X22,0X40,0X2A,0XC1,0X33,0X02,0X33,0X01,0X4B,0XC3,0X5C,0X25,0X5B,0XC5,0X39,0X43,
0X00,0X00,0X20,0XC2,0X18,0X80,0X08,0X00,0X08,0X0B,0X0A,0XDE,0X14,0XBE,0X35,0X7E,
0X45,0XBF,0X3D,0X3D,0X5D,0XFE,0X55,0XBE,0X55,0XFF,0X5D,0XFF,0X4C,0X79,0X33,0XD7,
0X4C,0X7A,0X4C,0XFC,0X55,0X3E,0X65,0XFF,0X6E,0XBF,0X5E,0X3F,0X44,0X3A,0X2A,0X52,
0X19,0X4D,0X11,0X8D,0X11,0XD1,0X11,0XD2,0X09,0XD4,0X09,0XD5,0X09,0XD3,0X09,0X4F,
0X08,0XCB,0X00,0X4A,0X00,0X49,0X00,0X08,0X00,0X06,0X00,0X43,0X11,0X05,0X21,0X44,
0X18,0X80,0X18,0X40,0X29,0X02,0X29,0X43,0X08,0X45,0X00,0X45,0X08,0X44,0X00,0X07,
0X08,0X49,0X00,0X49,0X00,0X8C,0X00,0XCC,0X00,0XCE,0X00,0XD0,0X09,0X0F,0X09,0X92,
0X01,0X51,0X01,0X52,0X09,0XD4,0X0A,0X15,0X0A,0X56,0X12,0X97,0X0A,0X16,0X09,0XD5,
0X09,0XD5,0X01,0XD3,0X01,0X10,0X00,0X8B,0X00,0X02,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X10,0X82,0X7B,0XCD,0X10,0X82,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X80,0X09,0X00,0X09,0X40,0X11,0XC0,0X32,0X83,0X2A,0X81,0X2A,0X81,
0X32,0XC2,0X2A,0XC1,0X33,0X01,0X43,0X83,0X64,0X66,0X64,0X66,0X41,0X82,0X08,0X00,
0X21,0X03,0X29,0X03,0X00,0X00,0X00,0X04,0X09,0XD7,0X0B,0XDE,0X24,0XFD,0X2D,0XBE,
0X35,0XBF,0X45,0XBF,0X44,0XFD,0X44,0X38,0X3B,0X96,0X2B,0X15,0X44,0XBB,0X66,0X3F,
0X7E,0X7F,0X7E,0XFF,0X5D,0XBD,0X54,0X78,0X3A,0XD3,0X19,0X8E,0X11,0XD0,0X12,0XD5,
0X0B,0X59,0X03,0X5B,0X0B,0X1A,0X0A,0X56,0X0A,0X13,0X09,0X50,0X08,0XCE,0X08,0XCE,
0X00,0XCC,0X00,0XCC,0X00,0X49,0X00,0X06,0X08,0XC7,0X00,0XC9,0X29,0X83,0X41,0XC2,
0X28,0XC1,0X31,0X02,0X39,0XC4,0X10,0XC8,0X00,0X06,0X08,0X85,0X08,0X8A,0X00,0X8B,
0X00,0X8B,0X00,0X8B,0X00,0XCC,0X01,0X0F,0X01,0X0F,0X01,0X0E,0X09,0XD3,0X01,0X93,
0X01,0X93,0X01,0XD3,0X01,0XD5,0X01,0XD5,0X0A,0X16,0X11,0XD5,0X09,0XD3,0X01,0X93,
0X01,0X94,0X09,0X12,0X00,0X47,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X00,0X00,0X00,0X01,0X00,0X00,0X41,0XC6,0X19,0X03,0X00,0X00,0X00,0X00,0X00,0X40,
0X08,0XC1,0X09,0X40,0X09,0X40,0X11,0XC0,0X1A,0X00,0X22,0X40,0X32,0XC2,0X3B,0X02,
0X3B,0X03,0X4B,0X83,0X4B,0X81,0X5C,0X24,0X64,0X66,0X10,0X40,0X28,0XC2,0X08,0X00,
0X00,0X00,0X10,0X01,0X18,0X83,0X08,0X8A,0X09,0X54,0X0B,0X9F,0X25,0X7F,0X35,0X3D,
0X2B,0XD9,0X33,0X55,0X33,0X55,0X44,0XBA,0X5D,0XBF,0X6E,0X7F,0X76,0XBF,0X6D,0XFD,
0X43,0X93,0X2A,0X51,0X29,0XD3,0X1A,0XD6,0X1C,0X7C,0X24,0XFF,0X14,0XBD,0X0B,0X9A,
0X12,0X98,0X0A,0X98,0X11,0XD2,0X11,0X51,0X09,0X94,0X01,0X53,0X01,0X51,0X01,0X4F,
0X00,0XCD,0X00,0X8B,0X10,0X8A,0X11,0X0C,0X00,0XCE,0X21,0X44,0X28,0XC0,0X20,0X80,
0X18,0X40,0X39,0X83,0X21,0X8A,0X00,0X48,0X08,0X45,0X10,0X8A,0X00,0X8B,0X00,0X8B,
0X00,0X8B,0X00,0XCD,0X09,0X0F,0X01,0X0F,0X01,0X10,0X01,0X52,0X11,0XD5,0X09,0XD4,
0X01,0XD4,0X01,0XD5,0X09,0XD5,0X01,0X93,0X01,0X95,0X01,0X95,0X01,0X51,0X08,0XCF,
0X08,0XCB,0X00,0X03,0X00,0X00,0X00,0X00,0X00,0X01,0X18,0X41,0X10,0X41,0X00,0X00,
0X08,0X00,0X00,0X00,0X00,0X00,0X00,0X40,0X00,0X01,0X00,0X00,0X00,0X80,0X09,0X01,
0X11,0XC1,0X32,0X84,0X2A,0X43,0X1A,0X00,0X32,0XC1,0X3B,0X01,0X3B,0X01,0X4B,0X82,
0X53,0XC3,0X5C,0X23,0X5C,0X22,0X6C,0X64,0X00,0X00,0X08,0X00,0X28,0X81,0X42,0X06,
0X20,0XC3,0X10,0X41,0X00,0X00,0X00,0X08,0X11,0X94,0X12,0X56,0X12,0X52,0X23,0X14,
0X2C,0XBC,0X35,0X7F,0X5E,0X7F,0X66,0X7F,0X45,0X7C,0X54,0X35,0X4A,0XD2,0X3A,0X53,
0X43,0X9B,0X24,0XFF,0X14,0XFF,0X1C,0X7D,0X1B,0X99,0X1B,0X58,0X13,0X9A,0X0B,0X9A,
0X13,0X18,0X12,0X55,0X0A,0X17,0X09,0XD8,0X09,0XD5,0X09,0X93,0X01,0X51,0X01,0X10,
0X09,0X10,0X08,0XCB,0X09,0X0D,0X01,0X11,0X21,0X89,0X28,0XC1,0X20,0X40,0X28,0XC1,
0X41,0XC5,0X29,0XCB,0X00,0X8A,0X00,0X4A,0X08,0X89,0X08,0XCB,0X00,0X8D,0X00,0XCD,
0X00,0XCE,0X09,0X10,0X01,0X11,0X01,0X52,0X01,0X52,0X09,0X93,0X09,0XD5,0X09,0XD5,
0X01,0XD5,0X02,0X14,0X02,0X14,0X01,0XD3,0X01,0X93,0X09,0X53,0X00,0XD0,0X00,0X47,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X02,0X20,0X41,0X30,0XC1,0X61,0X01,0X10,0X40,
0X18,0XC3,0X31,0X86,0X00,0X00,0X00,0X00,0X08,0X80,0X08,0XC0,0X01,0X00,0X1A,0X00,
0X32,0XC4,0X32,0X84,0X22,0X40,0X32,0XC1,0X3B,0X42,0X43,0X43,0X53,0XC3,0X53,0XC4,
0X53,0XC4,0X64,0X23,0X74,0XA3,0X00,0X00,0X00,0X00,0X00,0X00,0XC5,0XB3,0X6A,0XC7,
0X10,0X41,0X10,0X01,0X00,0X00,0X00,0X00,0X00,0X49,0X0A,0X55,0X24,0XFE,0X2D,0XBF,
0X35,0XFF,0X35,0X7E,0X2B,0X94,0X3A,0X50,0X4A,0X53,0X53,0X58,0X44,0XBE,0X24,0XBF,
0X24,0X7C,0X2C,0X3B,0X24,0X7C,0X24,0XBC,0X1C,0XBC,0X15,0X3E,0X14,0XBC,0X12,0X96,
0X0A,0X98,0X02,0XDA,0X0A,0X16,0X09,0XD6,0X01,0X55,0X01,0X94,0X09,0X93,0X09,0X55,
0X09,0X0D,0X01,0X0E,0X01,0X12,0X21,0XCB,0X39,0XC4,0X18,0XC2,0X19,0X03,0X42,0X05,
0X32,0X0C,0X00,0XCD,0X00,0XCD,0X08,0XCB,0X11,0X0B,0X09,0X0E,0X01,0X50,0X01,0X0F,
0X01,0X50,0X01,0X51,0X01,0X52,0X01,0X94,0X01,0X54,0X01,0X94,0X09,0XD5,0X09,0XD5,
0X09,0X93,0X11,0XD4,0X09,0XD4,0X01,0X50,0X01,0X4F,0X09,0X12,0X08,0X8B,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X38,0XC2,0X89,0X42,0X00,0X00,0X7C,0X2F,
0X84,0X2E,0X00,0X00,0X00,0X40,0X19,0X82,0X2A,0X44,0X19,0XC2,0X22,0X40,0X22,0X40,
0X1A,0X00,0X22,0X80,0X32,0XC1,0X3B,0X03,0X43,0X44,0X4B,0X84,0X53,0XC5,0X53,0XC4,
0X64,0X63,0X74,0XE1,0X21,0X83,0X8C,0X2C,0X49,0XC5,0X00,0X00,0X30,0X80,0X49,0X84,
0X10,0X00,0X00,0X00,0X00,0X00,0X08,0X06,0X0A,0X16,0X1D,0X3F,0X25,0X7F,0X1A,0XD2,
0X29,0XCB,0X52,0X4E,0X6B,0X15,0X53,0X9B,0X2C,0XBF,0X24,0X3D,0X23,0XD9,0X44,0X7A,
0X4D,0X3D,0X3D,0XBE,0X2D,0XFF,0X15,0XBF,0X1D,0X3E,0X13,0X19,0X0B,0X19,0X13,0X5B,
0X02,0XD9,0X0A,0X97,0X0A,0X17,0X01,0XD7,0X0A,0X16,0X09,0X96,0X09,0X55,0X11,0X4F,
0X01,0X93,0X01,0X97,0X19,0X8F,0X3A,0X04,0X21,0X44,0X21,0X44,0X41,0XC4,0X2A,0X0B,
0X01,0X4F,0X01,0X0E,0X11,0X91,0X09,0X4F,0X00,0X8C,0X09,0X91,0X09,0XD3,0X01,0X92,
0X01,0X93,0X09,0X93,0X01,0X54,0X09,0X95,0X09,0XD5,0X01,0XD5,0X01,0XD5,0X09,0XD3,
0X09,0X92,0X09,0X93,0X09,0X93,0X09,0X51,0X00,0XCE,0X00,0X04,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X01,0X08,0X00,0X00,0X00,0X00,0X00,0X18,0XC3,0X00,0X00,
0X08,0X81,0X09,0X01,0X11,0XC1,0X19,0XC2,0X11,0X81,0X22,0X40,0X22,0X80,0X32,0XC1,
0X3B,0X03,0X3B,0X03,0X43,0X43,0X4B,0X85,0X53,0XC6,0X5C,0X25,0X5C,0X25,0X64,0X64,
0X74,0XE1,0X33,0X01,0X7D,0X29,0X63,0X07,0X52,0X07,0X62,0X07,0X08,0X00,0X08,0X00,
0X10,0X00,0X20,0X00,0X08,0X03,0X00,0XCC,0X1A,0X91,0X19,0X88,0X20,0X00,0X51,0X88,
0X63,0X58,0X33,0X5B,0X34,0X3F,0X24,0X7D,0X23,0XD9,0X3C,0XBB,0X4E,0X3F,0X46,0X3F,
0X2D,0XBF,0X25,0X7F,0X1C,0XBD,0X0C,0X3B,0X03,0X9B,0X14,0X7E,0X1B,0XDB,0X02,0X58,
0X0A,0XDA,0X0A,0X99,0X02,0X17,0X09,0X97,0X01,0XD8,0X09,0X92,0X09,0X0D,0X09,0X95,
0X01,0XD8,0X11,0XD1,0X42,0X46,0X31,0X43,0X29,0X44,0X39,0XC3,0X2A,0X4B,0X01,0X91,
0X01,0X10,0X12,0X14,0X09,0XD3,0X00,0X8D,0X09,0X0E,0X11,0XD3,0X09,0X92,0X01,0XD3,
0X0A,0X14,0X01,0X93,0X01,0X94,0X0A,0X15,0X0A,0X15,0X01,0XD4,0X01,0X93,0X01,0X93,
0X09,0X51,0X01,0X51,0X09,0X95,0X00,0X8C,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X4A,0X47,0X29,0X44,0X00,0X00,0X08,0XC1,
0X01,0X00,0X09,0X40,0X1A,0X02,0X21,0XC2,0X3A,0XC2,0X53,0XC4,0X3B,0X02,0X32,0XC2,
0X3B,0X02,0X43,0X44,0X5C,0X25,0X64,0XA5,0X6C,0XA5,0X74,0XE7,0X74,0XA5,0X63,0XC1,
0X2A,0X80,0X11,0XC0,0X09,0X80,0X64,0X29,0X5B,0X47,0X11,0X01,0X19,0X01,0X21,0X00,
0X31,0X01,0X19,0X02,0X42,0X44,0X39,0X00,0X10,0X00,0X38,0X40,0X31,0X4A,0X22,0XDC,
0X13,0X9E,0X1B,0X59,0X24,0X39,0X2D,0XBE,0X25,0XBF,0X35,0X7E,0X45,0XFF,0X25,0X7F,
0X14,0XBD,0X1C,0X7D,0X0C,0XBD,0X04,0X7D,0X14,0XBF,0X1B,0X9A,0X02,0X97,0X0B,0X1B,
0X03,0X1B,0X02,0X59,0X01,0XD8,0X0A,0X5A,0X09,0XD2,0X09,0X51,0X09,0XD5,0X01,0XD8,
0X0A,0X14,0X3A,0X49,0X31,0X42,0X29,0X03,0X39,0X84,0X32,0X4C,0X02,0X13,0X01,0X51,
0X09,0XD4,0X12,0X57,0X01,0X52,0X01,0X50,0X09,0X8F,0X09,0X90,0X01,0X51,0X09,0XD2,
0X09,0XD3,0X0A,0X15,0X0A,0X96,0X0A,0XD6,0X0A,0X15,0X09,0X93,0X01,0X12,0X09,0X10,
0X00,0XCD,0X08,0XCE,0X08,0X88,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X52,0X88,0X31,0X84,0X00,0X00,0X00,0X40,0X09,0X01,
0X1A,0X02,0X22,0X42,0X3A,0XC2,0X4B,0X42,0X53,0XC4,0X4B,0X42,0X43,0X82,0X4B,0X83,
0X4B,0XC4,0X54,0X25,0X74,0XE6,0X84,0XE4,0X74,0XA3,0X4B,0X41,0X2A,0X00,0X1A,0X00,
0X1A,0X00,0X1A,0X00,0X01,0X80,0X01,0X40,0X1A,0X01,0X22,0X02,0X19,0XC1,0X11,0XC0,
0X32,0X83,0X73,0X08,0X20,0X82,0X08,0X01,0X28,0X40,0X28,0X83,0X19,0X0F,0X09,0XD4,
0X24,0X39,0X2D,0XBF,0X14,0XFF,0X0C,0XBD,0X1C,0XBF,0X24,0XFF,0X24,0XBC,0X24,0XBC,
0X14,0XFE,0X0C,0XFE,0X04,0XBF,0X14,0X7E,0X0B,0X57,0X03,0X5A,0X03,0X9D,0X03,0X5D,
0X0A,0XDC,0X0B,0X5E,0X12,0XD8,0X09,0X94,0X0A,0X99,0X0A,0X16,0X0A,0X5A,0X02,0X58,
0X32,0X0B,0X39,0X83,0X31,0X85,0X41,0XC4,0X2A,0X0C,0X02,0X55,0X01,0X51,0X0A,0X13,
0X1B,0X1B,0X02,0X17,0X01,0XD3,0X01,0X4F,0X0A,0X13,0X09,0XD3,0X01,0X51,0X09,0X93,
0X12,0X16,0X0A,0XD7,0X0A,0XD7,0X09,0XD5,0X01,0X52,0X01,0X11,0X01,0X10,0X08,0X8A,
0X00,0X04,0X00,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X41,0X08,0X81,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X00,0X80,0X19,0XC2,0X1A,0X02,
0X1A,0X00,0X33,0X02,0X43,0X42,0X32,0XC0,0X4B,0XC3,0X64,0XA6,0X64,0XA6,0X6C,0XA7,
0X74,0XE7,0X7C,0XA5,0X53,0X41,0X2A,0X40,0X22,0X00,0X19,0XC1,0X32,0XC4,0X43,0X06,
0X2A,0X83,0X19,0X80,0X19,0XC1,0X11,0X80,0X11,0X80,0X11,0X80,0X09,0X81,0X52,0X85,
0X18,0X41,0X08,0X00,0X10,0X00,0X08,0X00,0X20,0X00,0X18,0X04,0X13,0X5A,0X15,0X3F,
0X13,0XDE,0X0C,0X3E,0X14,0X7E,0X1C,0XBF,0X1C,0X3B,0X24,0XBC,0X14,0XFE,0X14,0XFF,
0X14,0XBE,0X14,0X7F,0X13,0XDB,0X03,0X99,0X0C,0X3D,0X03,0XDE,0X0B,0XDF,0X04,0X3E,
0X14,0X7E,0X12,0X53,0X0A,0X19,0X12,0X9C,0X12,0X56,0X0A,0X99,0X02,0X9B,0X22,0X0E,
0X39,0XC3,0X29,0X44,0X42,0X04,0X2A,0X0B,0X02,0X55,0X01,0X92,0X12,0X54,0X13,0X5A,
0X02,0X17,0X0A,0X56,0X09,0X92,0X12,0X55,0X13,0X17,0X01,0XD4,0X09,0X94,0X01,0XD5,
0X0A,0X16,0X0A,0X15,0X09,0X93,0X09,0X52,0X01,0X50,0X09,0X0E,0X08,0XCE,0X00,0X46,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X10,0X82,0X28,0X81,0X28,0X81,0X00,0X00,
0X00,0X00,0X00,0X40,0X00,0X00,0X08,0X82,0X19,0X82,0X09,0X40,0X09,0X80,0X2A,0X82,
0X3B,0X42,0X43,0X42,0X4B,0X83,0X74,0XA7,0X7D,0X28,0X85,0X67,0X84,0XE6,0X63,0X83,
0X32,0X40,0X22,0X00,0X2A,0X40,0X2A,0X40,0X19,0XC0,0X2A,0X43,0X4B,0X49,0X32,0X84,
0X19,0X81,0X22,0X02,0X11,0X80,0X11,0X80,0X01,0X00,0X3A,0X45,0X41,0X04,0X00,0X00,
0X10,0X41,0X20,0X81,0X08,0X00,0X00,0X00,0X11,0X0B,0X1B,0X9F,0X03,0X9F,0X14,0X3D,
0X1C,0X7E,0X24,0X7F,0X2C,0X7D,0X24,0X7A,0X0C,0XBD,0X04,0X7E,0X14,0X7F,0X24,0X7E,
0X14,0X7C,0X0B,0XDB,0X0C,0X7E,0X0C,0X7E,0X03,0X9E,0X0B,0XDF,0X0D,0XBF,0X0B,0X58,
0X09,0X95,0X0B,0X9E,0X13,0X1C,0X12,0X98,0X0A,0X98,0X0B,0X1D,0X12,0X53,0X31,0X84,
0X39,0X43,0X52,0X45,0X2A,0X0B,0X02,0X56,0X01,0XD2,0X12,0X55,0X13,0X5B,0X02,0X99,
0X0A,0X56,0X01,0X93,0X12,0X55,0X13,0X9A,0X0A,0XD8,0X01,0XD4,0X01,0XD3,0X01,0XD5,
0X01,0X54,0X08,0XCD,0X09,0X0F,0X01,0X52,0X09,0X10,0X08,0XCF,0X00,0X04,0X00,0X00,
0X00,0X00,0X00,0X00,0X10,0X40,0X08,0X80,0X58,0XC2,0X28,0X41,0X31,0X86,0X39,0XC6,
0X00,0X40,0X00,0X00,0X08,0XC1,0X19,0XC2,0X1A,0X02,0X32,0X83,0X43,0X43,0X4B,0X83,
0X5B,0XC4,0X7C,0XA7,0X8D,0X27,0X7C,0XA5,0X63,0XC3,0X42,0X80,0X22,0X00,0X22,0X00,
0X2A,0X40,0X3A,0X80,0X2A,0X40,0X11,0X80,
};

unsigned char code pic6[]=
{/* 0X10,0X10,0X00,0X5F,0X00,0X1C,0X01,0X1B, */
0X6B,0X1D,0X73,0X9D,0X63,0X9E,0X53,0X9E,0X3B,0X9E,0X33,0XDE,0X2C,0X3E,0X1B,0X9F,
0X23,0X9E,0X23,0X9F,0X2B,0X9E,0X2B,0XDE,0X3C,0X3E,0X3C,0X3E,0X2B,0XDE,0X0B,0X1E,
0XB6,0XBC,0XFF,0XF2,0XFE,0XAA,0XF6,0X69,0XFE,0X27,0XFE,0X69,0XFE,0X69,0XFE,0X26,
0XF5,0XE5,0XFF,0XFF,0XEE,0X7C,0XD8,0X43,0XEC,0X32,0XE4,0X31,0XC8,0X83,0XE2,0X8B,
0XD9,0XC8,0XE6,0XBD,0XF7,0XBB,0XF5,0X28,0XFD,0X27,0XFD,0X27,0XFD,0XA9,0XFF,0XF5,
0X7D,0XBE,0X0B,0X5E,0X34,0X3E,0X2C,0X3E,0X2B,0XDE,0X34,0X3E,0X3C,0X7E,0X34,0X3E,
0X34,0X7E,0X3C,0XBE,0X3C,0XBD,0X34,0X7E,0X3C,0X3F,0X33,0XDE,0X23,0X5E,0X23,0X9F,
0X2C,0X3F,0XAC,0X2B,0XB3,0X45,0X49,0X84,0X18,0XC2,0X10,0XC4,0X10,0X41,0X39,0X03,
0XA3,0X8C,0XFD,0X71,0XFC,0XEE,0X94,0X33,0X44,0X38,0X33,0XD4,0X85,0XBB,0XEE,0XFB,
0XED,0X31,0XFD,0X71,0XED,0X31,0X73,0X8F,0X5B,0X8D,0X3B,0X96,0XB6,0XBF,0XE6,0X77,
0XCC,0X6E,0XE5,0X30,0XE5,0X31,0X6A,0X48,0X20,0X82,0X08,0X41,0X19,0X04,0X21,0X03,
0X62,0X04,0X9A,0XC2,0X63,0X94,0X1B,0X9F,0X14,0X3F,0X83,0X92,0XF2,0XC0,0XC5,0XBE,
0XC5,0X3C,0XC4,0XFD,0XC4,0XFC,0XAC,0X7C,0X9C,0X3D,0X83,0XDD,0X5B,0X5D,0X43,0XDE,
0X2C,0X3E,0X24,0X7E,0X2C,0X7E,0X3C,0XBE,0X3C,0X7E,0X0B,0X1E,0X5C,0XFE,0XFF,0XF6,
0XFE,0XEB,0XFE,0X69,0XFE,0X69,0XFE,0X69,0XFE,0X68,0XFE,0X28,0XFD,0XE4,0XFE,0XA8,
0XEF,0X3C,0XD9,0X09,0XD9,0X06,0XF7,0XFF,0XF7,0XFF,0XE5,0XB8,0XF7,0XFF,0XDA,0X09,
0XDB,0X0D,0XEF,0XFF,0XF5,0XED,0XF5,0X26,0XF5,0X69,0XFD,0X27,0XFE,0XAD,0XE7,0X3A,
0X23,0X9E,0X23,0XDF,0X2B,0XDE,0X2B,0XDF,0X33,0XDE,0X3C,0X7E,0X34,0X3E,0X34,0X3E,
0X34,0X3E,0X34,0X3E,0X24,0X3E,0X23,0XDE,0X2C,0X3D,0X1B,0X9E,0X23,0XDF,0X24,0X3F,
0X93,0XCE,0XB3,0X02,0X59,0X83,0X21,0X03,0X19,0X05,0X00,0X01,0X20,0X82,0X9B,0X0A,
0XFE,0X32,0XFE,0X74,0X94,0X72,0X53,0X0C,0X4B,0X0B,0X54,0XB8,0XEF,0XBF,0XFE,0XB5,
0XFE,0X33,0XFD,0XF3,0X52,0X49,0X00,0X43,0X1B,0X13,0XAE,0XBF,0XEE,0XF9,0XE4,0XEF,
0XF5,0X71,0XE5,0X71,0X61,0XC6,0X39,0X03,0X82,0XC9,0X8B,0X0B,0X52,0X07,0X69,0XC0,
0X93,0X48,0X3B,0XDD,0X1B,0X9F,0X13,0X9F,0X7B,0X92,0XF3,0X82,0XCE,0XFD,0XCE,0XBC,
0XBE,0XFC,0XC6,0X7B,0XD6,0X3C,0XD5,0XFD,0XD5,0X7D,0XC4,0XBC,0XAC,0X7C,0X83,0XDC,
0X53,0X9D,0X33,0X9E,0X2B,0XDD,0X23,0XDF,0X13,0X1F,0XCF,0X3B,0XFF,0XAF,0XFE,0X6A,
0XFE,0X6A,0XFE,0X69,0XFE,0X68,0XFE,0X26,0XFE,0X26,0XFD,0XE5,0XF6,0X25,0XEE,0XF3,
0XDB,0XD2,0XE5,0X76,0XFF,0XFF,0XEF,0XFF,0XF7,0XFF,0XF7,0XFF,0XE4,0X33,0XC0,0X85,
0XE6,0XBD,0XF6,0X6E,0XF4,0XE4,0XF5,0XAB,0XFD,0X69,0XFD,0XAB,0XFF,0XF7,0X7D,0XBE,
0X0B,0X1E,0X2B,0XDF,0X2B,0XDF,0X2B,0XDE,0X3C,0X3E,0X34,0X3E,0X2C,0X3E,0X1C,0X7F,
0X0C,0X3F,0X3C,0X7D,0X95,0XFC,0XA6,0XBD,0X65,0X7C,0X34,0X7D,0X24,0X7F,0X64,0X77,
0XB3,0X04,0X82,0X02,0X31,0X43,0X21,0X44,0X31,0X04,0X28,0X82,0X82,0X89,0XFE,0X75,
0XFF,0X77,0XB5,0X73,0X00,0X04,0X00,0XC7,0X4C,0X76,0XF7,0X3C,0XFE,0XB5,0XFE,0X33,
0XFE,0X32,0XBC,0X6F,0X51,0XCA,0X2B,0XD5,0XAE,0XFF,0XF6,0XF9,0XF5,0X70,0XFD,0X71,
0XE5,0X30,0X41,0X44,0X72,0X88,0XBC,0X2D,0XB3,0XCD,0XCC,0X6C,0X72,0X86,0X4B,0X97,
0X23,0X9F,0X23,0X9F,0X13,0X9F,0X73,0X93,0XE3,0X40,0XC3,0X94,0XED,0XB8,0X96,0XBB,
0X46,0XBB,0X66,0XFB,0X86,0XFB,0XAE,0XFC,0XBE,0XBC,0XD6,0X3C,0XDD,0X7C,0XC4,0X7D,
0X9B,0XDC,0X73,0X5D,0X22,0X9E,0X5C,0XBF,0XFF,0XF5,0XFE,0XAB,0XFE,0X69,0XFE,0X29,
0XFE,0X29,0XFE,0X68,0XFE,0XA9,0XFE,0XEA,0XFE,0XEB,0XFE,0X68,0XFE,0XAA,0XFF,0X70,
0XFF,0X30,0XFE,0XF1,0XFF,0X32,0XFF,0X35,0XF7,0XBA,0XEE,0XB7,0XDD,0X35,0XE6,0X35,
0XF5,0X65,0XFC,0XA4,0XFD,0X69,0XF5,0XAB,0XF5,0XAC,0XFF,0X74,0XE7,0X7D,0X23,0XDD,
0X23,0XDF,0X34,0X3E,0X34,0X3E,0X44,0XBD,0X34,0X7E,0X2C,0XFF,0X54,0X3B,0X5C,0X39,
0XA6,0X3C,0XC5,0XF4,0XB5,0X31,0XEF,0X3A,0X6D,0X7C,0X24,0X3E,0X2C,0X7F,0X74,0X32,
0XA2,0XC1,0X59,0XC2,0X72,0XC9,0XDC,0XB0,0XAB,0X0A,0X61,0X85,0XF5,0XF3,0XFF,0X36,
0XDE,0XB6,0X1A,0X90,0X22,0XD0,0XD6,0XB6,0XFE,0XB4,0XFE,0X73,0XFE,0X74,0XFE,0X73,
0XFE,0XF5,0XFE,0XF5,0XD5,0XF5,0XCE,0X7A,0XE6,0X76,0XFD,0XB1,0XFD,0XF2,0XDC,0XAF,
0X39,0X03,0XA3,0X8C,0XB3,0XCD,0XA3,0X08,0XE4,0XAE,0X5C,0X3A,0X1B,0X5F,0X2B,0X9E,
0X2B,0X9E,0X23,0XDF,0X4C,0X3C,0X93,0X48,0XD2,0X90,0XBA,0X0C,0X74,0X77,0X26,0X3E,
0X25,0XFD,0X36,0X3C,0X46,0X7C,0X56,0X7C,0X7E,0XFC,0XAE,0XFC,0XD6,0X7D,0XDD,0XFC,
0XD4,0XFD,0X8B,0X5C,0XB5,0XFB,0XFF,0XF2,0XFE,0X6A,0XF6,0X6A,0XFE,0XEB,0XFE,0XEC,
0XFE,0X68,0XF5,0XA7,0XDD,0X68,0XD5,0X28,0XD4,0XA6,0XDC,0X63,0XDC,0X61,0XE4,0X61,
0XE4,0XA1,0XEC,0XE2,0XF5,0X24,0XFD,0XA6,0XFE,0X2A,0XFF,0X31,0XFD,0XE9,0XFD,0X24,
0XFC,0XE6,0XFC,0XE6,0XF5,0X6A,0XFE,0X2E,0XFE,0XF4,0XFF,0XFC,0X6D,0X7D,0X24,0X3D,
0X3C,0XBD,0X44,0XBD,0X4C,0XFD,0X35,0X7F,0X6C,0X7A,0XE0,0XC5,0XF9,0X85,0XBC,0XB2,
0X8B,0X4D,0X83,0XCE,0XD6,0XBA,0X6D,0X7D,0X23,0XDE,0X2C,0X3E,0X34,0X7F,0X6B,0X91,
0XA3,0X88,0XDC,0XAE,0XC4,0X2E,0XE4,0XEF,0X61,0X02,0XD5,0X30,0XFF,0X36,0XFE,0XF6,
0X85,0XF9,0XBE,0XB9,0XFF,0X76,0XFF,0X35,0XF6,0XF6,0XFE,0XF5,0XFE,0XB5,0XF6,0X74,
0XFE,0X32,0XFE,0X33,0XF6,0X34,0XF5,0XF3,0XFD,0XF2,0XFE,0X74,0XCC,0XAF,0X41,0X85,
0XAB,0X8C,0XA3,0X4B,0XBB,0X8A,0XD4,0X6F,0X4C,0X7E,0X23,0X9F,0X33,0XDE,0X33,0XDD,
0X3C,0X7E,0X34,0XBF,0X4C,0XBB,0XCD,0X38,0X6A,0X95,0X43,0X9C,0X2C,0XBF,0X2C,0XBF,
0X2D,0X3E,0X2D,0X7E,0X25,0X7D,0X1D,0XFC,0X36,0X7B,0X6E,0XBB,0X9E,0XBC,0XCE,0X7C,
0XCD,0XBD,0XF7,0X3A,0XFF,0XB1,0XFF,0X70,0XFF,0X6F,0XFE,0XAB,0XE4,0XE5,0XBB,0X41,
0XAB,0X02,0XA2,0XC2,0X9A,0X82,0X9A,0X82,0X8A,0X40,0X92,0X40,0X9A,0X40,0XA2,0X80,
0XAA,0X80,0XB2,0XC0,0XBB,0X00,0XC3,0X40,0XD3,0XC1,0XEC,0XA2,0XFD,0X65,0XFD,0XA8,
0XFD,0X68,0XF5,0X29,0XF6,0XB2,0XFF,0X77,0XFF,0XFB,0X95,0XFD,0X1B,0XDD,0X34,0X7E,
0X3C,0X7E,0X3C,0XBF,0X3D,0X3F,0XBA,0X09,0XF8,0X00,0XF8,0X82,0XC0,0X41,0X99,0X45,
0XC5,0X73,0XAE,0X3A,0X34,0X7E,0X24,0X3F,0X2B,0XDE,0X23,0XDF,0X1B,0XDF,0X7C,0XF9,
0XFD,0XB1,0XAB,0X4A,0XD4,0XAF,0X79,0XC5,0XAB,0XCC,0XFF,0X78,0XFE,0XF5,0XF6,0XF7,
0XFE,0XF7,0XFF,0X35,0XF7,0X78,0XFF,0X37,0XFE,0XF5,0XFE,0XB4,0XFE,0X33,0XFD,0XF2,
0XFD,0XF2,0XFD,0XF3,0XF5,0XB1,0XFD,0XB2,0XFE,0XB6,0XD4,0XF0,0X51,0X85,0X9B,0X4A,
0X93,0X0A,0XDC,0X2C,0XC4,0X70,0X3B,0XDE,0X1B,0X9F,0X23,0X9F,0X23,0X9F,0X2B,0XDE,
0X3C,0X7E,0X24,0X7F,0X34,0X3D,0X13,0X9F,0X2B,0XDF,0X33,0X9F,0X2B,0XDF,0X34,0X3F,
0X3C,0XBE,0X2C,0XBF,0X2D,0X3E,0X2D,0XBD,0X36,0X3B,0X56,0XBB,0X86,0XFC,0XD7,0XBF,
0XFF,0XF8,0XFF,0XF2,0XFF,0X70,0XED,0X66,0XC3,0X01,0X9A,0X00,0X8A,0X01,0X8A,0X44,
0X61,0XC6,0X51,0X85,0X6A,0X04,0X8A,0X83,0X8A,0X42,0X92,0X83,0X92,0X82,0X92,0X41,
0X92,0X81,0X92,0X40,0X8A,0X00,0X92,0X41,0X9A,0X82,0XB3,0X02,0XCB,0XC3,0XE4,0XA5,
0XFD,0XAA,0XFF,0XB8,0XFF,0XFA,0XFF,0XF9,0XB6,0X7C,0X13,0X9E,0X2C,0X3F,0X2B,0XDE,
0X24,0X7F,0X63,0X97,0XD8,0X41,0XF8,0X40,0XE0,0X00,0XA1,0X86,0X80,0XC4,0XB9,0X84,
0X84,0X35,0X24,0XBF,0X2C,0X3F,0X2B,0XDF,0X23,0X9F,0X1B,0XDF,0X44,0X7D,0XFE,0X35,
0XCC,0X6D,0XB4,0X2D,0XAB,0X09,0X93,0X0A,0XFF,0XF9,0XFF,0X36,0XFE,0XF6,0XFE,0XF5,
0XF6,0XF5,0XFE,0XF6,0XFE,0XF6,0XF6,0XB5,0XFE,0X73,0XFD,0XF2,0XFD,0XF2,0XFD,0XB1,
0XFD,0XB2,0XFD,0X71,0XFD,0X72,0X9B,0X4A,0X72,0XC9,0X8A,0XC9,0XA3,0X4B,0X8A,0XC9,
0XEC,0X6C,0XB4,0X71,0X23,0XDF,0X23,0XDF,0X2B,0XDF,0X2B,0XDF,0X2B,0XDF,0X34,0X3E,
0X2B,0XDF,0X4C,0XBD,0X2B,0XDE,0X23,0X9F,0X23,0X9F,0X23,0X9F,0X33,0XDE,0X3C,0X3E,
0X33,0XDF,0X3C,0X3F,0X3C,0XFE,0X45,0X7E,0X3D,0XFE,0X8E,0XFA,0XF6,0XF0,0XF5,0XA9,
0XED,0X28,0XBB,0X83,0X89,0XC0,0X71,0XC1,0X8A,0X84,0X82,0X86,0X39,0X04,0X10,0X84,
0X10,0X83,0X10,0X42,0X7A,0X88,0XB3,0X8A,0X93,0X08,0X93,0X07,0X92,0XC7,0X92,0XC6,
0X8A,0X84,0X8A,0X83,0X8A,0X83,0X8A,0X43,0X92,0XC4,0X9A,0X82,0X9A,0X80,0XBB,0X42,
0XEE,0X70,0XFF,0XFB,0XFF,0XF7,0XCE,0XBA,0X23,0X9E,0X23,0X9F,0X23,0XDF,0X2C,0XBF,
0X92,0X8F,0XD8,0X00,0XC0,0X00,0XCA,0X05,0XDE,0XF8,0XA3,0X4B,0XFC,0XAB,0XBE,0X3A,
0X1C,0X7D,0X34,0X7F,0X34,0X3F,0X2C,0X3F,0X2C,0X7F,0X2C,0X7D,0XCD,0XB5,0XFD,0XF1,
0XAC,0X2D,0XBC,0X2D,0X7A,0X89,0XAC,0X6E,0XEE,0X33,0XFF,0X78,0XFE,0XF5,0XF6,0X73,
0XFE,0XB4,0XFE,0XB4,0XFE,0X73,0XFE,0X33,0XFD,0XB2,0XFD,0XB1,0XFD,0X70,0XFD,0XF2,
0XD4,0XAF,0X61,0XC6,0X00,0X00,0X41,0X86,0XCC,0XAF,0XA3,0X8C,0X92,0X89,0XFC,0XAB,
0X9C,0XB6,0X14,0X3F,0X2C,0X3F,0X2C,0X3F,0X2C,0X3F,0X2B,0XDF,0X34,0X3E,0X2B,0X9F,
0XFF,0XFE,0XA5,0XFC,0X13,0X5E,0X2B,0XDF,0X2B,0XDF,0X34,0X3F,0X34,0X3E,0X2B,0XDF,
0X2B,0XDF,0X2B,0XDF,0X24,0X3F,0X54,0XFC,0XD5,0X2B,0XCB,0X42,0X8A,0X03,0X40,0XC1,
0X30,0X80,0X38,0XC2,0X82,0X87,0XB3,0XCB,0X51,0X85,0X39,0X45,0X8B,0X09,0X8B,0X09,
0X39,0X45,0X28,0XC3,0XB4,0X2C,0XC4,0X2C,0XB3,0XCB,0XB3,0XCB,0XAB,0X8A,0XB3,0XCB,
0X93,0X09,0X49,0X85,0X39,0X45,0X41,0X44,0X7A,0X43,0X9A,0XC2,0X92,0X40,0XA2,0X40,
0XE5,0XF0,0XFF,0XFA,0XD6,0XBA,0X34,0X3E,0X24,0X3F,0X2C,0XBF,0X6C,0X7A,0XA8,0X82,
0XD1,0X03,0XBA,0XC9,0X79,0XC4,0XF6,0X33,0X9B,0XCC,0X72,0X06,0X84,0XB7,0X35,0X3F,
0X34,0XBE,0X34,0XBE,0X2C,0XBE,0X3C,0XFE,0X1C,0X7F,0X85,0X79,0XFF,0XB6,0XAC,0X6E,
0XC5,0X30,0XB4,0X6D,0X08,0X01,0X30,0XC3,0X8B,0X8B,0XFE,0XF7,0XFE,0X73,0XFE,0X32,
0XFE,0X32,0XFD,0XF2,0XFD,0XB1,0XFD,0XB1,0XFD,0X70,0XFD,0X70,0XE5,0X30,0X31,0X03,
0X00,0X41,0X29,0X46,0X49,0XC7,0XAB,0XCD,0XAB,0X8C,0XE4,0X6C,0XED,0X30,0X4C,0X7D,
0X1C,0X3F,0X34,0X3F,0X2C,0X3F,0X2B,0XDF,0X2B,0XDF,0X3C,0X7E,0X34,0X3F,0XFF,0XBD,
0X74,0XFB,0X13,0X9E,0X2B,0XDF,0X2B,0XDF,0X34,0X3F,0X3C,0X7E,0X2B,0XDF,0X2B,0XDF,
0X2B,0XDF,0X13,0X9F,0X7C,0X76,0XCB,0X84,0X7A,0X02,0X20,0XC3,0X10,0X83,0X28,0X40,
0X6A,0X04,0XD4,0XAE,0XC4,0X2C,0X8A,0XC8,0XC4,0X6D,0XF5,0X2E,0XF5,0X2E,0XD4,0XAD,
0X30,0XC2,0X82,0XC8,0XE4,0XEE,0XC4,0X2C,0XC4,0X2B,0XCC,0X6C,0XB4,0X2C,0X39,0X05,
0X10,0X83,0X29,0X04,0X10,0X83,0X39,0X44,0X82,0X84,0X92,0X82,0X9A,0X40,0XAB,0X01,
0XFF,0XB8,0XE7,0XBF,0X24,0X3D,0X24,0X7E,0X2C,0XBF,0X6B,0XD6,0X90,0X00,0X99,0X82,
0XFF,0XB7,0XE5,0X70,0XFD,0XAF,0XF5,0XF1,0X91,0XC6,0X4A,0XD6,0X24,0XFF,0X2C,0XBE,
0X2C,0XBF,0X24,0XBF,0X3C,0XFE,0X24,0XFF,0X34,0XBC,0XF6,0XF6,0XF6,0XB3,0XBC,0XEF,
0XAC,0X2D,0X31,0X45,0X31,0X46,0X00,0X00,0XAC,0X2E,0XFF,0X36,0XFD,0XB0,0XFD,0XB1,
0XFD,0XB1,0XFD,0X70,0XF5,0X2F,0XEC,0XEE,0XFD,0XF2,0X7A,0XC7,0X08,0X42,0X39,0X87,
0X41,0XC8,0X41,0X86,0X82,0XC9,0XC3,0XCA,0XFD,0X70,0X7C,0XB8,0X1C,0X3F,0X2B,0XDF,
0X2C,0X3F,0X2B,0XDF,0X2B,0XDF,0X2C,0X3F,0X3C,0X7E,0X34,0X7F,0X54,0XBB,0X23,0XDD,
0X34,0X7E,0X34,0X7E,0X34,0X7E,0X3C,0X7E,0X44,0XBE,0X34,0X7F,0X34,0X7E,0X34,0X7F,
0X24,0X7F,0X84,0X75,0XC3,0X43,0X41,0X00,0X00,0X83,0X39,0X44,0X30,0X80,0X9A,0XC8,
0XF5,0X2F,0XD4,0X6D,0XE4,0XEE,0XE4,0XED,0XC4,0X2C,0XBC,0X2D,0XE4,0XEE,0XB3,0X8A,
0XA3,0X4A,0XE4,0XEF,0XD4,0X6C,0XD4,0X6C,0XDC,0XAE,0X59,0XC6,0X39,0X03,0X93,0X09,
0XAB,0X8A,0X62,0X06,0X20,0XC3,0X82,0XC9,0X72,0X45,0X69,0XC1,0X92,0X41,0XDC,0XA8,
0XF7,0XBB,0X5D,0XBF,0X24,0X3E,0X3C,0XBE,0X44,0XBF,0X5B,0XD8,0X4A,0X4D,0X7A,0XC7,
0X9B,0X8A,0X9B,0X8D,0XFD,0X2E,0XEB,0X8C,0X53,0XD9,0X1C,0XBF,0X34,0XBE,0X34,0XFE,
0X24,0XFF,0X2D,0X3F,0X3D,0X3F,0X1C,0XBE,0X85,0X39,0XFF,0X76,0XE5,0X70,0X6A,0X06,
0X49,0X86,0X83,0X8D,0X62,0X8B,0X41,0X86,0XCC,0XF1,0XFE,0X74,0XFD,0XB0,0XFD,0X2F,
0XEC,0XEE,0XEC,0XEE,0XFD,0XB0,0X9B,0X8B,0X18,0X83,0X39,0X46,0X41,0XC7,0X31,0X87,
0X39,0X85,0X82,0XC9,0X9C,0X30,0X74,0XF9,0X2C,0X7F,0X3C,0X7F,0X34,0X7E,0X3C,0X7E,
0X34,0X7E,0X34,0X7E,0X3C,0X7E,0X44,0XBE,0X3C,0XBE,0X34,0X7E,0X3C,0XBF,0X44,0XBE,
0X3C,0XBE,0X3C,0X7E,0X44,0XBE,0X3C,0XBE,0X1B,0XDD,0X23,0XDE,0X34,0XBE,0X34,0XBF,
0X74,0XB9,0X92,0X82,0X38,0XC0,0X18,0XC3,0X51,0X84,0X48,0X80,0XBB,0XCC,0XFE,0X74,
0XED,0X2F,0XEC,0XAD,0XBB,0XCB,0XAC,0XB2,0XC5,0XF6,0XC5,0XB5,0XE5,0X2F,0XE4,0XED,
0XDC,0XEE,0XDC,0XAD,0XDC,0XAD,0XCC,0X6C,0X93,0X08,0XC4,0X6B,0XDC,0XAD,0XDC,0XAD,
0XC4,0X6D,0X59,0XC5,0X93,0X49,0X9B,0X09,0X38,0XC1,0X39,0X01,0X92,0X83,0XD4,0X67,
0XDE,0X33,0X65,0X7E,0X3C,0XBE,0X2C,0XBE,0X1D,0X3F,0X54,0XBC,0X88,0X42,0X98,0X00,
0X51,0X8D,0X82,0X4E,0XA2,0X4C,0X5C,0X79,0X45,0X3E,0X2C,0XFF,0X3C,0XFF,0X6D,0X3A,
0X7C,0XF8,0X4C,0XFD,0X2C,0XFF,0X24,0XBF,0X95,0X39,0XED,0XB3,0X93,0X4A,0X41,0X86,
0X5A,0X49,0X8B,0X8E,0X73,0X0C,0X62,0X49,0X9B,0XCD,0XDC,0XEE,0XE5,0X2F,0XD4,0XEE,
0XC4,0XAD,0X8B,0X0A,0X21,0X03,0X31,0X05,0X41,0X87,0X31,0X86,0X18,0XC3,0X49,0XC6,
0X4A,0X4A,0X44,0X7C,0X2C,0XBF,0X44,0XBF,0X44,0XFE,0X3C,0XBE,0X44,0XBE,0X3C,0XBE,
0X3C,0XBE,0X3C,0XBE,0X4C,0XBE,0X44,0XFE,0X4C,0XFE,0X24,0X3E,0X2C,0X7F,0X24,0X3F,
0X13,0X9E,0X13,0XDE,0X34,0X7C,0X7D,0X7D,0X7D,0XBE,0X34,0X7E,0X1C,0X3F,0X34,0X3C,
0XBD,0X31,0XE5,0XB1,0XA3,0X8C,0X61,0X44,0X71,0X42,0XD5,0X71,0XFF,0X77,0XFE,0X74,
0XED,0X2F,0XD5,0XF6,0XFF,0XFE,0XAD,0XFC,0X6C,0XBD,0XA4,0XB4,0XE4,0XED,0XE4,0XEE,
0XE4,0XEE,0XDC,0XEE,0XDC,0XAC,0XDC,0XEE,0XBD,0X31,0XAC,0XAF,0XAB,0XCB,0XD4,0XAD,
0XC4,0X6D,0XBC,0X2B,0XB3,0XCB,0X51,0X83,0X10,0X40,0X31,0X03,0X9A,0XC4,0XD3,0XC5,
0X8D,0X77,0X1C,0X7F,0X6D,0XBD,0XAE,0XBE,0XC2,0XCD,0XF8,0X00,0XF8,0X00,0XD8,0X85,
0X7A,0XCF,0X84,0XB3,0X2A,0XD8,0X3C,0X3E,0X2C,0XFF,0X3C,0X7C,0XA3,0X08,0XD3,0X46,
0X6C,0X78,0X1C,0XBF,0X24,0X7F,0X1C,0X3E,0X4C,0XFC,0X6C,0X34,0X41,0X85,0X18,0X41,
0X31,0X46,0X52,0X09,0X39,0XC7,0X20,0XC4,0X29,0X04,0X41,0X85,0X51,0XC5,0X29,0X03,
0X00,0X00,0X29,0X04,0X29,0X05,0X10,0X82,0X10,0X82,0X72,0X88,0X9C,0X71,0X22,0X0C,
0X34,0X7D,0X2C,0XBF,0X3C,0XBE,0X3C,0XBE,0X2C,0X7F,0X34,0X7E,0X2C,0X7E,0X2C,0X7F,
0X2C,0X7E,0X34,0XBE,0X2C,0X7E,0X1C,0X3D,0X13,0XDD,0X0B,0XDD,0X44,0XBD,0X9E,0X7D,
0X95,0XFD,0XCF,0X3E,0XFF,0XFF,0XFF,0XBC,0X84,0XF9,0X03,0XDE,0X6D,0X7C,0XFD,0XF2,
0XFD,0XF0,0XDD,0X31,0X69,0X85,0X92,0X05,0XEE,0X33,0XFE,0XF6,0XFE,0X33,0XED,0XF3,
0XFF,0XFF,0XC6,0XFE,0X23,0X56,0X2B,0X54,0X4B,0XD7,0XD4,0XB0,0XF5,0X2D,0XE4,0XEE,
0XEC,0XED,0XBC,0X6E,0X64,0X38,0X6C,0XBA,0XAD,0XB8,0XB5,0X33,0XBC,0X2C,0XE4,0XEE,
0XE5,0X2F,0XCC,0XAD,0X59,0X42,0X28,0XC2,0X18,0XC2,0X6A,0X04,0XB3,0X45,0X6C,0X74,
0X76,0X3F,0XFF,0XFF,0XFF,0XFF,0XF6,0X38,0X89,0XCC,0X78,0XC7,0X98,0X03,0X4A,0X53,
0X2B,0X57,0X1A,0X58,0X22,0X9A,0X33,0X5D,0X2A,0XD9,0X59,0X85,0XA2,0X42,0X6C,0XB7,
0X24,0XFF,0X34,0XBE,0X2C,0XFF,0X24,0XFF,0X24,0X3B,0X63,0X0C,0X9B,0XCC,0X41,0X04,
0X18,0X81,0X10,0X82,0X21,0X04,0X49,0XC7,0X83,0X0A,0XA3,0XCD,0X93,0XCD,0X73,0X8D,
0X39,0X86,0X41,0X85,0X7A,0XC9,0X9B,0X4A,0XFD,0XF2,0XA4,0X70,0X1A,0XD3,0X3C,0XFF,
0X34,0XBF,0X3C,0XBE,0X44,0XFE,0X34,0XBF,0X34,0XBE,0X34,0XBE,0X34,0XBE,0X44,0XFD,
0X55,0X3D,0X3C,0XBD,0X6D,0XBD,0XB6,0XBE,0X85,0XFC,0XD7,0X7D,0XFF,0XFF,0XFF,0XBD,
0XFF,0XFE,0XE7,0X3C,0XB5,0XB6,0XAC,0XF3,0X3C,0XBC,0XAD,0XFA,0XFC,0X6A,0XFD,0X70,
0XC4,0XAF,0X69,0X44,0X89,0XC4,0XED,0XF2,0XFE,0XF5,0XFD,0XF1,0XFE,0XB7,0XFF,0XFF,
0X4C,0XBB,0X1A,0X8E,0X6B,0X4B,0X33,0X53,0XD5,0XF6,0XFD,0XF0,0XED,0X2E,0XF4,0XAB,
0X6B,0XD4,0X1B,0X98,0X23,0X98,0X54,0X7A,0XD6,0XBB,0XCD,0X31,0XDC,0XAC,0XF5,0XB0,
0XD4,0XAD,0X59,0X42,0X28,0XC3,0X19,0X04,0X71,0XC1,0X9B,0X47,0X4C,0XFB,0X9D,0XF9,
0XEE,0XB7,0XFF,0X7A,0XB6,0XBB,0X1D,0X7F,0X2C,0XBE,0X11,0X90,0X0A,0X17,0X1A,0X59,
0X22,0X58,0X11,0XD4,0X11,0X93,0X0A,0X18,0X49,0X8B,0X92,0X85,0X55,0X3C,0X2C,0XFF,
0X3C,0XFE,0X3C,0XFE,0X34,0XFE,0X35,0X3F,0X3B,0X52,0XF6,0X74,0XFE,0X33,0XB3,0XCB,
0X9B,0X4A,0X72,0X47,0X7B,0X4D,0XAC,0XF2,0X9C,0X2F,0X8B,0X8E,0X73,0X0C,0X28,0X83,
0XAB,0X4A,0XFD,0XB2,0XFD,0X71,0XFD,0X6F,0X52,0X48,0X2B,0XDA,0X35,0X3F,0X34,0XBE,
0X44,0XFE,0X44,0XFE,0X2C,0XBF,0X34,0XBE,0X5D,0X7E,0X85,0XFE,0X96,0X3D,0XA6,0X7E,
0X95,0XFD,0XFF,0XFF,0XFF,0XFF,0XF7,0X7D,0XFF,0XFF,0XEF,0XBE,0XB5,0XB6,0X94,0XF3,
0X9C,0XB3,0X9B,0X0D,0XC3,0X4D,0XBB,0XD1,0XD4,0X6F,0XFD,0XF2,0XFE,0XF5,0XC3,0XCC,
0X58,0XC2,0X69,0X82,0XFE,0XF4,0XFF,0XB8,0XF6,0X32,0XFE,0XB7,0XF7,0XFF,0X44,0XFA,
0X09,0X4C,0X30,0X88,0X94,0XB1,0XFF,0X38,0XFE,0XF5,0XFE,0X73,0XF6,0X33,0X53,0X0E,
0X3A,0X8A,0X5B,0XD0,0X1B,0X97,0XBE,0X7D,0XE5,0XB3,0XDC,0XAC,0XFD,0XF2,0XC4,0X6D,
0X40,0XC1,0X41,0X85,0X39,0X43,0X71,0XC0,0X7C,0XB3,0X24,0XFF,0X4C,0XBA,0X8C,0XF4,
0XC5,0XF7,0X85,0XBB,0X14,0XFF,0X35,0X7F,0X22,0X93,0X11,0X92,0X22,0X56,0X11,0X92,
0X19,0XD2,0X1A,0X94,0X01,0X92,0X40,0XC4,0X8B,0X8C,0X4D,0XFF,0X35,0X3F,0X3D,0X3E,
0X3D,0X3D,0X3D,0X3E,0X3D,0XBF,0X2B,0XD6,0X7B,0X0A,0XFE,0XF5,0XFE,0X74,0XFE,0X34,
0XCC,0X2D,0X20,0X42,0X28,0X83,0X28,0X43,0X28,0X42,0X20,0X01,0X40,0XC4,0XE4,0XEF,
0XE4,0XEF,0XFD,0XB1,0XB3,0X89,0X2A,0X0C,0X3D,0X7F,0X34,0XFF,0X34,0XFE,0X45,0X3E,
0X45,0X3E,0X34,0XFF,0X3C,0XFD,0X86,0X3E,0XB6,0XFE,0XC6,0XFD,0XD7,0X3D,0XCF,0X3D,
0XFF,0XFF,0XCE,0XFB,0XAD,0X75,0XDF,0X3C,0XB5,0XF8,0X8C,0XF3,0X29,0X45,0X91,0X87,
0XEA,0X8A,0XFA,0X8A,0XCA,0X47,0XA9,0XC3,0XED,0X30,0XFD,0XB1,0XBB,0X49,0X58,0X81,
0XAC,0X2C,0XFF,0X78,0XBC,0XF0,0XFF,0X37,0XFE,0XB5,0XFF,0XFF,0X55,0X3B,0X2A,0X93,
0XD5,0XB6,0XFF,0XF8,0XFF,0X37,0XFE,0XF6,0XFE,0XF6,0XFF,0X37,0XE6,0X33,0X7B,0X0C,
0X19,0X89,0X2C,0X78,0XBE,0X7D,0XE5,0XB2,0XDC,0XAC,0XFE,0X32,0XB4,0X2B,0X30,0X40,
0X82,0XC9,0XE4,0XED,0X94,0X6F,0X34,0XFD,0X2C,0XFF,0X2C,0XFE,0X3C,0XFD,0X3C,0XBC,
0X2C,0XBE,0X1D,0X3F,0X45,0XFF,0X2A,0XD5,0X08,0XCC,0X09,0X0D,0X1A,0X11,0X3C,0XFD,
0X3D,0XBF,0X34,0X7B,0X43,0X52,0X5C,0XF8,0X2D,0X7F,0X1C,0XBD,0X24,0XFD,0X3D,0X3E,
0X45,0X3D,0X35,0X7E,0X45,0XBF,0X32,0X4B,0XBB,0XCC,0XFE,0XB4,0XFE,0X32,0XFE,0X74,
0X92,0X89,0X48,0X83,0X59,0X47,0X61,0X46,0X40,0X43,0XB3,0XCD,0XFD,0XB2,0XE4,0XAE,
0XED,0X2F,0X51,0X83,0X2B,0X54,0X3D,0X7F,0X34,0XFE,0X34,0XFD,0X45,0X3E,0X45,0X3E,
0X2C,0XBD,0X55,0X7D,0X96,0X7E,0XAE,0XBE,0XBE,0XFE,0XCE,0XFD,0XD7,0X3D,0XCE,0XFB,
0XAD,0XB7,0X63,0X4D,0X63,0X0B,0X9C,0X71,0X7A,0X8A,0X88,0XC4,0XF1,0XC8,0XFA,0X09,
0XF2,0X8A,0X81,0X44,0X58,0X00,0XA1,0XC5,0XFD,0XB1,0XC4,0X2C,0X61,0X42,0XFF,0XB9,
0XAC,0XB0,0X10,0X01,0XA4,0X6E,0XFF,0X77,0XFF,0XBA,0XC6,0X7B,0XCE,0XB8,0XFF,0XF8,
0XFF,0X79,0XFF,0X39,0XFF,0X37,0XFE,0XF6,0XFE,0X74,0XFE,0XB5,0XFE,0XB6,0X64,0XB4,
0X3C,0XFB,0XCE,0X7B,0XD4,0XEF,0XEC,0XED,0XFE,0X73,0XA3,0X08,0X30,0X81,0X93,0X4A,
0XFD,0X2D,0XBD,0XF7,0X35,0X3F,0X45,0X3E,0X45,0X3E,0X4D,0X3E,0X35,0X3F,0X2D,0X3F,
0X4C,0XFB,0X3B,0XD8,0X09,0XD2,0X08,0XCD,0X00,0X8B,0X3B,0XD9,0X4E,0X7F,0X35,0X7E,
0X45,0XBF,0X3D,0XFF,0X2D,0X7F,0X45,0X3C,0X7D,0XFC,0X6D,0XBB,0X34,0XFD,0X45,0X7E,
0X45,0X7D,0X4D,0XFF,0X4C,0XB8,0X4A,0X08,0XDD,0X2E,0XFE,0X33,0XFD,0XF3,0XFE,0X33,
0XCC,0X6F,0XB3,0X4D,0XA2,0XCB,0XC4,0X70,0XFE,0X34,0XE4,0XEE,0XFD,0X30,0X8A,0X87,
0X32,0XCE,0X4D,0XBF,0X45,0X3E,0X45,0X3E,0X45,0X3E,0X55,0X7E,0X4D,0X7E,0X3D,0X3D,
0X55,0X7D,0X86,0X7E,0XA6,0XBE,0XB6,0XBE,0XC6,0XFE,0XC6,0XFD,0XA3,0XCF,0X9B,0XCF,
0X89,0XC7,0X98,0X83,0XC9,0X86,0XD8,0XC3,0XFA,0X09,0XFC,0X30,0XFD,0X35,0XDB,0X4D,
0X68,0X41,0X50,0X40,0X68,0X40,0XE3,0X8B,0XC4,0XEF,0XB4,0XEF,0XFE,0XF7,0X5A,0X48,
0X41,0XC8,0X31,0X45,0X93,0X8C,0XD5,0X30,0XFE,0XB4,0XFF,0X77,0XFF,0X37,0XFF,0X38,
0XFF,0X37,0XFE,0XF6,0XFE,0XB4,0XFE,0X33,0XFD,0XF3,0XFE,0X33,0XEE,0XB7,0XAD,0XF8,
0XCD,0X73,0XE4,0XED,0XFD,0XB0,0XFE,0X33,0X82,0X46,0X40,0XC2,0XB3,0XCC,0XDB,0XC8,
0XAC,0XB2,0X45,0X7F,0X3D,0X3E,0X45,0X3E,0X45,0X3E,0X2C,0XFE,0X45,0XBF,0X94,0X2E,
0X41,0X08,0X01,0X53,0X01,0X10,0X09,0XD2,0X45,0X3E,0X3D,0XBF,0X3D,0X7E,0X25,0X3E,
0X0C,0XBE,0X45,0X3D,0XE7,0XBE,0XFF,0XFF,0XFF,0XFD,0X7D,0XBA,0X2C,0XFD,0X45,0X7F,
0X4D,0X7D,0X4D,0XFF,0X3C,0X78,0X63,0X0C,0XDC,0XEE,0XFD,0XF2,0XFE,0X33,0XFE,0X74,
0XFD,0XF3,0XFE,0X34,0XFE,0XB4,0XF5,0X30,0XDC,0XAE,0X9B,0X4B,0X3B,0X52,0X45,0XBF,
0X45,0XBF,0X45,0X7D,0X45,0X7E,0X45,0X7E,0X5D,0XBD,0X86,0X3E,0X7E,0X3D,0X6D,0XBC,
0X86,0X3D,0XA6,0XBE,0XB6,0XBD,0XC6,0XFE,0XBE,0XFE,0XE2,0X08,0XD9,0X86,0XF1,0X86,
0XFA,0X49,0XFA,0XCC,0XFC,0X71,0XF4,0XF4,0XF6,0X79,0XF6,0XBA,0XDB,0X0C,0X60,0X41,
0X58,0XC2,0X68,0X41,0X99,0X02,0XCC,0XF0,0XFF,0XB8,0XE5,0XB1,0X31,0X45,0X52,0X49,
0X5A,0X49,0X29,0X45,0X18,0XC2,0XB4,0X6E,0XFF,0X37,0XFE,0XB5,0XFE,0XB5,0XF6,0XB4,
0XFE,0X74,0XFE,0X33,0XFD,0XF2,0XFD,0XF2,0XFD,0X71,0XFE,0X32,0XFE,0XB6,0XFD,0XB1,
0XEC,0XEF,0X6A,0X47,0XA4,0X6F,0X93,0X8A,0X49,0X02,0XCC,0X2D,0XE4,0X2A,0X8C,0XF4,
0X2D,0X3F,0X34,0XFF,0X34,0XFE,0X5D,0XBE,0X6D,0XFE,0X7E,0XBF,0XB5,0X31,0X82,0X06,
0X19,0XD5,0X1A,0X56,0X45,0X3D,0X2D,0XBF,0X2D,0X3F,0X24,0XFE,0X3D,0X3C,0X5D,0X7C,
0XB6,0XBC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X6D,0XBC,0X24,0XFE,0X3D,0X7E,
0X3D,0X3E,0X3D,0XFF,0X3D,0X7F,0X4B,0XD4,0XA3,0XCD,0XED,0X30,0XFD,0XB2,0XFD,0XB1,
0XED,0X30,0XDC,0XAE,0XBB,0XCC,0X7A,0X89,0X43,0X4F,0X55,0XBE,0X4D,0XBF,0X3D,0X7F,
0X2D,0X7F,0X2D,0X7F,0X2D,0X3E,0X6D,0XFE,0XA6,0XFF,0XA6,0XBE,0XA6,0XBE,0XA6,0X7D,
0XAE,0XBE,0XB6,0XBE,0XBE,0XFF,0XBE,0XBD,0XFA,0XCC,0XFB,0X4E,0XFC,0X72,0XF5,0X34,
0XF5,0XB6,0XF6,0X38,0XF4,0XB2,0XEA,0XCB,0XFA,0X49,0XF2,0X07,0X78,0XC3,0X58,0X82,
0X68,0X82,0X78,0X40,0XCB,0XCC,0XFF,0X36,0XFE,0X73,0X72,0X89,0X08,0X83,0X41,0XC7,
0X5A,0X4A,0X21,0X05,0X93,0X8C,0XFE,0XF5,0XFE,0X32,0XFE,0X33,0XFE,0X33,0XFE,0X33,
0XFD,0XF2,0XFD,0XB2,0XFD,0X71,0XF5,0X2F,0XFE,0X32,0XC4,0X6E,0X72,0X88,0X51,0XC6,
0X10,0X83,0X73,0X4D,0XAC,0X6E,0X69,0X43,0XCC,0X2B,0XE4,0XAC,0X6D,0X7A,0X2D,0X3F,
0X2D,0X3E,0X4D,0XBE,0XB6,0XFE,0XDF,0X7E,0XD7,0XBF,0XC6,0X79,0X9A,0X43,0X6A,0X4A,
0X9E,0X3D,0X8E,0XFF,0X14,0XFE,0X1C,0XFC,0X8E,0X7D,0XEF,0XBE,0XFF,0XFE,0XC5,0XF7,
0XDF,0X3C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XAE,0X7C,0X2D,0X3E,0X45,0X7E,0X3D,0X7F,
0X45,0X7E,0X4D,0XBB,0X3C,0XF3,0X7B,0X87,0XAB,0X47,0X93,0X0A,0X92,0XC9,0X82,0XC9,
0X72,0X89,0X7A,0XC8,0X7A,0X87,0X42,0X88,0X33,0X09,0X3B,0X4B,0X6C,0XB3,0X6D,0X39,
0X55,0X3B,0X4D,0X3C,0X8E,0X3F,0XAE,0XFF,0X9E,0XFF,0XA6,0XFF,0XAE,0XFF,0XAE,0XBF,
0XA6,0XFF,0XBE,0XBD,0XD5,0XAC,0XF4,0XB3,0XF4,0XF3,0XF4,0XF2,0XF4,0X31,0XF3,0X4E,
0XF2,0X8A,0XF2,0X48,0XFA,0X08,0XFA,0X48,0XFA,0X47,0X91,0X03,0X50,0XC2,0X68,0XC2,
0X78,0X41,0XCB,0X4B,0XFE,0XB4,0XFE,0X73,0XF5,0XF2,0X6A,0X47,0X29,0X04,0X4A,0X09,
0X41,0XC7,0X5A,0X08,0XFD,0XB2,0XFD,0XF2,0XFD,0XB2,0XFD,0XB2,0XFD,0XB1,0XF5,0XB1,
0XF5,0X70,0XE5,0X2F,0XFD,0X6F,0XFD,0XF2,0X39,0X45,0X00,0X42,0X29,0X85,0X31,0X46,
0X5A,0X8A,0XAC,0XB0,0X8A,0XC8,0XEC,0X2A,0XC5,0X32,0X45,0XBE,0X35,0X7E,0X35,0X7E,
0X8E,0X7E,0XD7,0X7E,0XDF,0X7E,0XDF,0XBF,0XD7,0X7E,0X79,0XC2,0X92,0X85,0XDF,0XFF,
0XAE,0XFF,0X5D,0XBC,0XA6,0XBC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XDE,0XFB,0X7B,0XD0,
0XD6,0XBB,0XF7,0XFF,0XB5,0XF6,0X8C,0X31,0X8C,0X74,0XAC,0X72,0X9D,0X35,0X5D,0X2E,
0X24,0X25,0X0B,0X02,0X9C,0X64,0XF5,0XA6,0XAC,0X26,0X8B,0XCB,0X6A,0X82,0X72,0X40,
0X9B,0XC4,0X93,0X45,0X42,0X83,0X1B,0X45,0X03,0X04,0X84,0X24,0XED,0X26,0XCD,0X29,
0XBD,0X2B,0XBD,0X2D,0XBD,0X72,0XAD,0XF5,0XA6,0X39,0XA6,0X7D,0XA6,0XBF,0XB6,0X79,
0XDD,0XAB,0XE5,0X22,0XF3,0X4D,0XF2,0XCB,0XF2,0X49,0XF2,0X48,0XFA,0X08,0XFA,0X07,
0XFA,0X07,0XF2,0X07,0XFA,0X06,0XFA,0X06,0XA9,0X43,0X58,0X82,0X70,0XC3,0X80,0X41,
0XAA,0XCB,0XF6,0X76,0XFD,0XF1,0XFE,0X74,0XFE,0X73,0X9B,0X09,0X21,0X05,0X39,0XC8,
0X29,0X04,0X7A,0XC8,0XFD,0XB1,0XFD,0XB0,0XF5,0X2F,0XED,0X2E,0XE4,0XEE,0XE4,0XEE,
0XED,0X2E,0XFE,0X32,0X83,0X4A,0X10,0XC4,0X31,0X86,0X29,0X46,0X10,0X83,0X62,0X48,
0XE6,0X35,0XCC,0X2C,0XEC,0XAC,0X75,0X7A,0X25,0X7F,0X35,0X7D,0X55,0XBE,0XB6,0XFE,
0XC7,0X3D,0XBE,0XFD,0XCF,0X3E,0XCF,0X7F,0XA5,0X75,0XA5,0XB6,0XB7,0X3E,0XBF,0X3D,
0XFF,0XFE,0XFF,0XFE,0XE7,0X3C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X9C,0XF3,0X9B,0X8D,
0XBD,0X32,0XA3,0XCD,0XBB,0X4A,0XEB,0XCC,0XE3,0X8C,0XE4,0XE9,0X54,0XE3,0X03,0XC2,
0X03,0X83,0X84,0X23,0XFD,0XE4,0XFE,0X28,0XFF,0XFB,0XEF,0X37,0XDD,0XAA,0XCC,0XA3,
0XDD,0X25,0X7C,0XA7,0X14,0X66,0X04,0X67,0X64,0X66,0XFD,0XA5,0XF5,0X64,0XED,0X23,
0XDD,0X23,0XD4,0XE4,0XCC,0XA5,0XCC,0XA8,0XBC,0XEB,0XBD,0X70,0XD5,0X6B,0XDD,0X27,
0XD5,0X67,0XF2,0X49,0XFA,0X48,0XFA,0X48,0XF2,0X48,0XF2,0X07,0XF2,0X06,0XF2,0X06,
0XF2,0X06,0XF2,0X06,0XF2,0X06,0XC9,0XC5,0X68,0XC2,0X68,0XC3,0X80,0X81,0X8A,0X8C,
0XD6,0X36,0XFD,0XF1,0XFD,0XF1,0XFE,0X72,0XFD,0XB0,0X52,0X07,0X21,0X04,0X21,0X05,
0X18,0XC4,0X72,0X89,0XD4,0XAD,0XE5,0X2E,0XED,0X2E,0XED,0X2E,0XED,0X2F,0XDD,0X2F,
0X83,0X0A,0X19,0X04,0X29,0X45,0X29,0X45,0X21,0X05,0X49,0X85,0XD4,0XEF,0XFE,0XB5,
0XFD,0X2D,0XAD,0X33,0X25,0XBF,0X3D,0X7E,0X6D,0XFE,0XA6,0XBE,0XBF,0X3E,0XB6,0XFD,
0XAE,0XFD,0XBF,0X3D,0XBE,0XFD,0XC7,0XBF,0XBF,0X7F,0XC6,0XFD,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XE7,0X3C,0XF7,0XBF,0XFF,0XFF,0XE7,0XBF,0XE6,0X78,0XDC,0X2D,0XD3,0X4B,
0XBB,0X09,0XCB,0X4A,0XEB,0XCB,0XDB,0X0A,0XB3,0XC8,0X2C,0XA4,0X0C,0X65,0X0B,0XC4,
0X8C,0X64,0XFD,0XE5,0XE5,0XA5,0XEE,0XF7,0XF7,0XFF,0XFF,0XFE,0XF6,0XF3,0XFD,0XE8,
0X9D,0X27,0X04,0X27,0X04,0X67,0X24,0X27,0XCD,0X27,0XF5,0XA6,0XDD,0X67,0XDD,0X67,
0XD5,0X67,0XD5,0X68,0XDD,0XA8,0XDD,0XE7,0XEE,0X27,0XEE,0X68,0XE6,0XA9,0XE6,0X6A,
0XF2,0X48,0XEA,0X47,0XEA,0X47,0XEA,0X07,0XE2,0X07,0XE2,0X06,0XDA,0X06,0XD2,0X06,
0XDA,0X06,0XD2,0X06,0XD2,0X47,0X99,0X44,0X68,0X82,0X88,0X81,0X8B,0X0D,0X85,0XFA,
0XFD,0XB0,0XFD,0XAF,0XFD,0XB0,0XFD,0XF1,0XE4,0XEE,0X92,0XC8,0X9B,0X4B,0X62,0X49,
0X00,0X42,0X29,0X45,0X49,0XC5,0X62,0X47,0X72,0X88,0X62,0X48,0X31,0X46,0X00,0X42,
0X19,0X04,0X18,0XC3,0X6A,0X48,0XC4,0X6D,0XE4,0XEF,0XFD,0XF1,0XED,0XB1,0XAD,0X74,
0X55,0XFD,0X3D,0XFF,0X76,0X3E,0XB6,0XFE,0XC7,0X3E,0XB6,0XFE,0XB6,0XFD,0XB6,0XFE,
0XBF,0X3E,0XBE,0XFE,0XAE,0XFE,0XCF,0X3E,0XFF,0XFF,0XEF,0XBD,0XF7,0XFF,0XFF,0XFF,
0XE7,0X3D,0XE7,0X3D,0XFF,0XFF,0XD7,0X3D,0XC4,0XF2,0XD3,0X08,0XDB,0X4A,0X92,0X47,
0X8A,0X47,0XAA,0X87,0XAA,0X47,0X93,0X8A,0X34,0XA6,0X14,0XA5,0X0C,0X25,0X84,0X66,
0XFE,0X28,0XED,0XA5,0XE6,0X2E,0XEF,0X7D,0XEF,0X7D,0XFF,0XFF,0XFF,0X37,0XA4,0XE9,
0X5C,0XAA,0X5C,0XEA,0X1C,0X29,0X74,0X68,0XE5,0X68,0XD5,0X28,0XD5,0X2A,0XE5,0XEA,
0XF6,0X67,0XF6,0XA4,0XFE,0XA3,0XFE,0XA2,0XF6,0XA1,0XFE,0X61,0XFE,0X62,0XDA,0X47,
0XDA,0X47,0XDA,0X47,0XD2,0X07,0XCA,0X07,0XC2,0X07,0XC2,0X07,0XBA,0X07,0XC2,0X47,
0XBA,0X06,0XC2,0X47,0XC2,0X07,0X91,0X03,0XA0,0XC1,0X8B,0X4F,0X2E,0X3F,0X9D,0X76,
0XFD,0X6E,0XFD,0XB0,0XF5,0X70,0XFD,0XB0,0XFD,0XB0,0XE5,0X2E,0XC4,0X6D,0X6A,0X48,
0X39,0X86,0X49,0XC7,0X39,0X45,0X08,0X83,0X00,0X83,0X5A,0X07,0X83,0X09,0X52,0X06,
0X7A,0XC9,0XE4,0XEF,0XFD,0XB0,0XF4,0XED,0XF5,0XB0,0X75,0XBA,0X2D,0XBE,0X3D,0XFE,
0X4D,0XBD,0X8E,0X7E,0XB6,0XFE,0XBE,0XFD,0XBF,0X3E,0XBE,0XFE,0XAE,0XFD,0XAE,0XFE,
0XB6,0XFE,0XB6,0XFD,0XE7,0XBE,0XFF,0XFF,0XCE,0XBA,0XDF,0X3C,0XFF,0XFF,0XEF,0X7E,
0XD6,0XFB,0XDF,0X3D,0XC6,0XBB,0XA4,0XB0,0XA2,0X88,0X92,0X47,0X9A,0XC8,0XA2,0XC9,
0X92,0X48,0X9A,0X47,0XCB,0XCC,0X4C,0XA8,0X14,0XA5,0X14,0X66,0X7C,0X66,0XFE,0X29,
0XF5,0XE9,0XE5,0XA9,0XDE,0X74,0XE6,0XFB,0XF7,0X3C,0XDE,0X35,0XC4,0X28,0XFC,0XE7,
0XFC,0XA8,0XC4,0XEB,0X94,0XAB,0XAC,0XA8,0XC4,0XE9,0XEE,0XAA,0XFE,0XE4,0XF6,0X60,
0XF6,0X20,0XF6,0X20,0XEE,0X20,0XF6,0X20,0XF5,0XE0,0XF5,0XE0,0XCA,0X48,0XC2,0X48,
0XC2,0X47,0XBA,0X47,0XBA,0X47,0XBA,0X47,0XB2,0X48,0XB2,0X48,0XBA,0X89,0XBA,0X88,
0XB2,0X47,0XBA,0X07,0XB9,0X85,0XC9,0X83,0X9C,0XF3,0X36,0XBF,0X35,0X3C,0X9B,0XCD,
0XFD,0X30,0XFD,0XB0,0XF5,0X6F,0XFD,0XF1,0XFD,0XF2,0XF5,0XB1,0XE5,0X2F,0XC4,0X2B,
0XCC,0XAD,0XBC,0X2D,0X82,0XC9,0X82,0XC8,0XD4,0XAE,0XF5,0X70,0XE5,0X30,0XF5,0XB0,
0XED,0X6F,0XD4,0X6C,0XE4,0X6A,0XAD,0X75,0X5D,0XFF,0X6E,0X3F,0X6E,0X3E,0X7E,0X3E,
0X96,0XBE,0XA6,0XFE,0XB6,0XFE,0XC7,0X3F,0XCF,0X3F,0XBE,0XFE,0XAE,0XFD,0XAE,0XFE,
0XBE,0XFE,0XF7,0XBF,0XFF,0XFF,0XEF,0X7F,0XDE,0XFC,0XEF,0XBF,0XEF,0XBF,0XCE,0XBB,
0X9D,0X35,0X9D,0X76,0X8C,0XB1,0XAB,0X0A,0X92,0X48,0XC3,0X4A,0XEB,0X8A,0XB3,0X09,
0X92,0X47,0XBB,0X0A,0X6C,0X2A,0X1C,0X26,0X0C,0X26,0X6C,0X66,0XFD,0XE9,0XED,0XEA,
0XE5,0XE9,0XD5,0XAA,0XDE,0XB5,0XE6,0X73,0XC5,0X72,0X9B,0X4B,0XFC,0X66,0XFC,0X64,
0XFC,0X25,0XF4,0X2B,0XBD,0X2C,0XDE,0XEA,0XFF,0X25,0XE6,0XA0,0XEE,0XA0,0XEE,0XA0,
0XEE,0XE0,0XEE,0XE1,0XEE,0XA1,0XEE,0XA1,0XEE,0XA1,0XBA,0X49,0XB2,0X48,0XB2,0X48,
0XAA,0X48,0XB2,0X89,0XAA,0XCA,0XAA,0XCA,0XA2,0XCB,0X82,0XCA,0X8A,0XCB,0X9A,0X8A,
0X9A,0X8A,0XA3,0X4D,0XAB,0X49,0XCD,0X2B,0XCE,0X31,0XA6,0X75,0X9C,0XEE,0XA3,0X89,
0XDD,0X30,0XFD,0XB1,0XF5,0X6F,0XFD,0XF1,0XFE,0X32,0XFD,0XF1,0XED,0XB0,0XCC,0XAD,
0XCC,0X6D,0XDC,0XAE,0XDC,0XEF,0XE5,0X2F,0XE5,0X2F,0XED,0X2F,0XE4,0XEE,0XCC,0X2B,
0XCC,0XEF,0XE6,0X36,0XBE,0XFD,0XC7,0X3F,0XCF,0X3E,0XAE,0XFD,0XB6,0XFE,0XBE,0XFE,
0XA6,0XBE,0X9E,0XBE,0XB6,0XFE,0XCF,0X3F,0XC7,0X3E,0XAE,0XFD,0X9E,0XBE,0X9E,0XBB,
0XE7,0XBE,0XFF,0XFF,0XF7,0XBF,0XDF,0X3D,0XDF,0X3D,0XE7,0X7E,0XBE,0X39,0X73,0XD0,
0X73,0XD0,0X84,0XB2,0XAB,0X8C,0X92,0X48,0X92,0X89,0X9A,0XC9,0X9A,0XC9,0XA2,0XC9,
0XC3,0X0A,0X73,0X89,0X0B,0X44,0X0B,0X86,0X63,0XC6,0XED,0X67,0XE6,0X29,0XDD,0X6D,
0XD5,0X2F,0XF7,0XB0,0XFF,0XB0,0XCE,0XB9,0X8B,0XCF,0XEB,0XC7,0XC3,0X45,0XB3,0X06,
0XB2,0X45,0XF4,0XEB,0XFF,0X71,0XE7,0X34,0XF7,0X73,0XEF,0X2F,0XEF,0X2D,0XEE,0XE3,
0XEE,0XE0,0XEE,0XE1,0XE6,0XE1,0XE6,0XE2,
};